@@ -2,9 +2,10 @@ var index =
 [
     [ "Introduction", "index.html#Algebraic_foundationsIntroduction", null ],
     [ "Algebraic Structures", "index.html#Algebraic_foundationsAlgebraic", [
-      [ "Tags in Algebraic Structure Traits", "index.html#Algebraic_foundationsTagsinAlgebraicStructure", null ],
-      [ "Algebraic Category", "index.html#Algebraic_foundationsAlgebraicCategory", null ],
-      [ "Exact and Numerical Sensitive", "index.html#Algebraic_foundationsExactandNumericalSensitive", null ]
+      [ "Tags in Algebraic Structure Traits", "index.html#Algebraic_foundationsTagsinAlgebraicStructure", [
+        [ "Algebraic Category", "index.html#Algebraic_foundationsAlgebraicCategory", null ],
+        [ "Exact and Numerical Sensitive", "index.html#Algebraic_foundationsExactandNumericalSensitive", null ]
+      ] ]
     ] ],
     [ "Real Embeddable", "index.html#Algebraic_foundationsRealE", null ],
     [ "Real Number Types", "index.html#Algebraic_foundationsRealN", null ],
