@@ -246,8 +246,8 @@ var NAVTREEINDEX0 =
 "index.html":[0],
 "index.html":[],
 "index.html#Algebraic_foundationsAlgebraic":[0,1],
-"index.html#Algebraic_foundationsAlgebraicCategory":[0,1,1],
+"index.html#Algebraic_foundationsAlgebraicCategory":[0,1,0,0],
 "index.html#Algebraic_foundationsDesign":[0,6],
-"index.html#Algebraic_foundationsExactandNumericalSensitive":[0,1,2],
+"index.html#Algebraic_foundationsExactandNumericalSensitive":[0,1,0,1],
 "index.html#Algebraic_foundationsExamples":[0,4,0]
 };
