@@ -1,6 +1,5 @@
 var NAVTREEINDEX1 =
 {
-"index.html#Algebraic_foundationsExamples":[0,4,0],
 "index.html#Algebraic_foundationsExamples_1":[0,5,0],
 "index.html#Algebraic_foundationsFractions":[0,5],
 "index.html#Algebraic_foundationsInteroperability":[0,4],
@@ -8,12 +7,7 @@ var NAVTREEINDEX1 =
 "index.html#Algebraic_foundationsRealE":[0,2],
 "index.html#Algebraic_foundationsRealN":[0,3],
 "index.html#Algebraic_foundationsTagsinAlgebraicStructure":[0,1,0],
-"models.html":[3],
 "modules.html":[1],
-"namespaceAlgebraicStructureTraits__.html":[6,0],
-"namespaceCGAL.html":[6,1],
-"namespaceFractionTraits__.html":[6,2],
-"namespaceRealEmbeddableTraits__.html":[6,3],
 "pages.html":[],
 "structCGAL_1_1Coercion__traits.html":[1,0,10],
 "structCGAL_1_1Coercion__traits.html#a1abfb24cfc2de1f449627fc2fb7488dd":[1,0,10,0],
