@@ -1,161 +1,5 @@
 var group__PkgAlgebraicKernelDConceptsBi =
 [
-    [ "ApproximateAbsoluteX_2", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a0f2feb72d3b38573aa0f83034d48476e", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a9fd06079f7182fa9ebcfe518cb8a4886", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a55486c71e683615c88bca7b6b3794728", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a2c03c9e094ea3a67cb35f43cf3db9a7a", null ]
-    ] ],
-    [ "ApproximateAbsoluteY_2", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#ab41275e73ac841b16f52e0c4e0b31834", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#a355bef23e07fd0ce6f5fb8874d7bd6de", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#abda2c350167b0f5a22d67e4f28d5bfd3", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#adeb8a3e707309326695cec5fc78c0f22", null ]
-    ] ],
-    [ "ApproximateRelativeX_2", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#ae9e636d3d161cdfcb53841070791c57d", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#aaa348cc58ee7b9ece284b5f30566392b", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#ae56fbd468c756260cdd1790cd89c8ffe", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#a4d0c796a5c986ad70cec9aa5af0b5662", null ]
-    ] ],
-    [ "ApproximateRelativeY_2", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#aa608c33fa5f2525a36751c0813419d40", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#a6c1fddb591caddc3c19a9e2a97a0dbf4", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#a1e1b8ebae9a62224019de9ff99904cb3", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#afe4ab03e1acf746bfedf08541eb70ab6", null ]
-    ] ],
-    [ "BoundBetweenX_2", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#ad3404f667abc68ba0d6ad79bc260e691", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#ad99b6eae0277d645fb473252aa35fd1d", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#afefa71ecc6f35ee1895165daecf9e367", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#a566e7bd322ba004ccb97dfa932b14da5", null ]
-    ] ],
-    [ "BoundBetweenY_2", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a207fafe3494322b3904f4dbda18f2328", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a9a2185e30d47762eb31c02f225cb1956", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a5c18b3c6b7d376f2ce13996023ef94d6", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a4e3ee7ca720c366f98f6b56e55bade12", null ]
-    ] ],
-    [ "CompareX_2", "classAlgebraicKernel__d__2_1_1CompareX__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a0d24cc96a94142ec97761c1738911088", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1CompareX__2.html#add265cdfbdbc0daf0deadbee8358fb64", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a069873faa8ff3d37c0a56730c7728a00", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a2a48e0ed8eeed8c0b3cf32cef9eae968", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a3ca26ea86eefbbdb808cdb20e2bdc2dd", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a85a5885ba6dc6c5573db320b0dcc4ee5", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#ab32b76f2cece1e7459929e4463095385", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a719252e5c6779bcaf8c5adb804ef6506", null ]
-    ] ],
-    [ "CompareXY_2", "classAlgebraicKernel__d__2_1_1CompareXY__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a3c90d2322dbb5042c1675b2add6c175a", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a5975727de0eac2636d0ed083131d1936", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#afffc46d70f7e376190528af293857449", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a8402f6fb253cea9112569a0dd039f49f", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#ac7a8cbb58420780d96a63e27f74447a6", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a43e538b7ac94badd2d0dbe0507201d89", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a5c499c6a6b1e68b152edfb8a705928d4", null ]
-    ] ],
-    [ "CompareY_2", "classAlgebraicKernel__d__2_1_1CompareY__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1CompareY__2.html#add6437be8ace35cda867eeb412a97fa7", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a227ea2da0e8c7946cc8d3f8d1aefeb2b", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1CompareY__2.html#aff88141e2853cd78b27c19760a7cfc9f", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a32803b1275f272daeb7c1b8518510e47", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a3804dfaf3e0b326d6b24362139eb308f", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a1b47f095d00fe83ef374a776332a4b33", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a3f9e5529234767d39eb881c57d51fc12", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a76897427be2c1fa463160a9553a924b5", null ]
-    ] ],
-    [ "ComputePolynomialX_2", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html", [
-      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html#ab8f428363e36113ddc77b0f9a4d269dd", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html#a5997ad6ece8bae15a98aed927688011a", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html#aef6ca2082e80790e4416cbf17bb54f29", null ]
-    ] ],
-    [ "ComputePolynomialY_2", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html", [
-      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html#ab7cfaeae520c3e799671ad1c8ec74f72", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html#a8034c3c1967b3489e648e6a2544f14a3", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html#ae1fca8a9f3ea9e346f25ab558b54520b", null ]
-    ] ],
-    [ "ComputeX_2", "classAlgebraicKernel__d__2_1_1ComputeX__2.html", [
-      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputeX__2.html#a5c88f2c6ba460bb3e01c94e286dda6e3", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputeX__2.html#a8ba7779e8f6e810de2a29ea6985ac3cb", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputeX__2.html#aa02046cd2b64b5c8324ddca12e1eb624", null ]
-    ] ],
-    [ "ComputeY_2", "classAlgebraicKernel__d__2_1_1ComputeY__2.html", [
-      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputeY__2.html#a77fb0e205b57887b5362ef9a92fff0e6", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputeY__2.html#a030607cc057fef94422eca67571c7390", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputeY__2.html#a142f8cff0c7458e2be20e76894cbe306", null ]
-    ] ],
-    [ "ConstructAlgebraicReal_2", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html", [
-      [ "result_type", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#afcf2b866fa86798eec82df44eb81131d", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#ab195914d2072e48892922a5a07e15af2", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#ac57902047388920b0e8eaf22c3c9aa94", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#abb3d80f57a61a77996566bcc8064590a", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#ac1faf797abd4259798ba4091305acbc7", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#af6a5912cf3cf33e4bd15a224d7b4befa", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#a336040f0baabe8b2a537eeba14375a9b", null ]
-    ] ],
-    [ "IsCoprime_2", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#a909104a5a2f17d5b567fd5e287031ef7", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#af503cd09aa7b97dae568264fd1f9298d", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#a64728591a3bbb6e33b5c93dd9e226c9e", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#a090739fa50812c67afbb1404d57a4efc", null ]
-    ] ],
-    [ "Isolate_2", "classAlgebraicKernel__d__2_1_1Isolate__2.html", [
-      [ "result_type", "classAlgebraicKernel__d__2_1_1Isolate__2.html#a3c19a694fa697309163bdab52b313007", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1Isolate__2.html#a902cd224f8f72400869dac62b3cf002f", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1Isolate__2.html#a9e8d933037199ef327578fa158f1ca65", null ]
-    ] ],
-    [ "IsolateX_2", "classAlgebraicKernel__d__2_1_1IsolateX__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#ad1eff8a1874e2e9534783b09ed295b5e", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#ab7c6ea4e7be633e8d4bc5c0516afe549", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#af64615dcf2f92b425707f4611f8f635a", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#a17d5ddb4e2735ad3894b62c2a2d25770", null ]
-    ] ],
-    [ "IsolateY_2", "classAlgebraicKernel__d__2_1_1IsolateY__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#aacbce87512dfdd3bf16eace0cb2e0cd7", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#a825c7ff4cffc0296de1185b54c939c39", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#a82ad5dd28a28af5f2bfa0f2fe7b5f4bc", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#a4adc29ba2e69a8ece3420ccc96bb9d0c", null ]
-    ] ],
-    [ "IsSquareFree_2", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html", [
-      [ "argument_type", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html#a68c51b79862840acd010251c68013ded", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html#a9e882751c27e35e20f0a59b374bc1111", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html#a50482c6e301119f529ead8c47015831c", null ]
-    ] ],
-    [ "IsZeroAt_2", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a2a3aedfe1d972865d9f982b13627f38f", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a994b983fd6b45366bff578f309c3fa84", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a66dbe3156f3e8ce85a3e8678d2941d98", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a04ca017106b60cfe6c4f57eca11436b8", null ]
-    ] ],
-    [ "MakeCoprime_2", "classAlgebraicKernel__d__2_1_1MakeCoprime__2.html", [
-      [ "result_type", "classAlgebraicKernel__d__2_1_1MakeCoprime__2.html#a09d129e979f69ab0d1db417d3683b26e", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1MakeCoprime__2.html#ac464b05870526933f83a5c048c0bd881", null ]
-    ] ],
-    [ "MakeSquareFree_2", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html", [
-      [ "argument_type", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html#a89169a5207b3d44f95569fea4b00ecc0", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html#ad69d61bb4ad676e886b1571766262182", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html#a2acdc4cd7a436621829cabd7b2895362", null ]
-    ] ],
-    [ "NumberOfSolutions_2", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#a63b533be863262d787c60168b87ac68d", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#a6be16f0f2da771011675867172003d73", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#aa93f8fb1a9fe7229c8fbe5030329c5fc", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#accf9c52cfbcd43e8b6e66af6f2c6c73a", null ]
-    ] ],
-    [ "SignAt_2", "classAlgebraicKernel__d__2_1_1SignAt__2.html", [
-      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a7b968a95322be66cc294f2ca71003477", null ],
-      [ "result_type", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a67a331d620299d082f8f06697fb94516", null ],
-      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a4781083223961032b9cf7c86f44143f0", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a9d7df92d198f989d38d49225aa68dd3e", null ]
-    ] ],
-    [ "Solve_2", "classAlgebraicKernel__d__2_1_1Solve__2.html", [
-      [ "operator()", "classAlgebraicKernel__d__2_1_1Solve__2.html#a38ca9c46ab9010173be9cf359f824a5f", null ],
-      [ "operator()", "classAlgebraicKernel__d__2_1_1Solve__2.html#a018e952909c222963e4bff4b70d94e00", null ]
-    ] ],
-    [ "SquareFreeFactorize_2", "classAlgebraicKernel__d__2_1_1SquareFreeFactorize__2.html", [
-      [ "operator()", "classAlgebraicKernel__d__2_1_1SquareFreeFactorize__2.html#a69a2c5c3cb5c7d1c1b869380ea9c458d", null ]
-    ] ],
     [ "AlgebraicKernel_d_2", "classAlgebraicKernel__d__2.html", [
       [ "Algebraic_real_2", "classAlgebraicKernel__d__2.html#a2b5054fdea67366f4933ecc68d2c85f9", null ],
       [ "Approximate_absolute_x_2", "classAlgebraicKernel__d__2.html#abc1026203f0c9c806785048e249a5e80", null ],
@@ -183,5 +27,161 @@ var group__PkgAlgebraicKernelDConceptsBi =
       [ "Solve_2", "classAlgebraicKernel__d__2.html#a2683e9debd98ce490be3a43f59db616f", null ],
       [ "Square_free_factorize_2", "classAlgebraicKernel__d__2.html#aacbbb6fc718d6d7b29ca1f32a794af2f", null ],
       [ "bound_between_x_2_object", "classAlgebraicKernel__d__2.html#afdcccfe9982622adf84dd6008a530f57", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ApproximateAbsoluteX_2", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a0f2feb72d3b38573aa0f83034d48476e", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a9fd06079f7182fa9ebcfe518cb8a4886", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a55486c71e683615c88bca7b6b3794728", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteX__2.html#a2c03c9e094ea3a67cb35f43cf3db9a7a", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ApproximateRelativeX_2", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#ae9e636d3d161cdfcb53841070791c57d", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#aaa348cc58ee7b9ece284b5f30566392b", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#ae56fbd468c756260cdd1790cd89c8ffe", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateRelativeX__2.html#a4d0c796a5c986ad70cec9aa5af0b5662", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::BoundBetweenX_2", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#ad3404f667abc68ba0d6ad79bc260e691", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#ad99b6eae0277d645fb473252aa35fd1d", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#afefa71ecc6f35ee1895165daecf9e367", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1BoundBetweenX__2.html#a566e7bd322ba004ccb97dfa932b14da5", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::CompareX_2", "classAlgebraicKernel__d__2_1_1CompareX__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a0d24cc96a94142ec97761c1738911088", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1CompareX__2.html#add265cdfbdbc0daf0deadbee8358fb64", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a069873faa8ff3d37c0a56730c7728a00", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a719252e5c6779bcaf8c5adb804ef6506", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a85a5885ba6dc6c5573db320b0dcc4ee5", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#ab32b76f2cece1e7459929e4463095385", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a3ca26ea86eefbbdb808cdb20e2bdc2dd", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareX__2.html#a2a48e0ed8eeed8c0b3cf32cef9eae968", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::CompareY_2", "classAlgebraicKernel__d__2_1_1CompareY__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1CompareY__2.html#add6437be8ace35cda867eeb412a97fa7", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a227ea2da0e8c7946cc8d3f8d1aefeb2b", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1CompareY__2.html#aff88141e2853cd78b27c19760a7cfc9f", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a76897427be2c1fa463160a9553a924b5", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a1b47f095d00fe83ef374a776332a4b33", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a3f9e5529234767d39eb881c57d51fc12", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a3804dfaf3e0b326d6b24362139eb308f", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareY__2.html#a32803b1275f272daeb7c1b8518510e47", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ComputePolynomialY_2", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html", [
+      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html#ab7cfaeae520c3e799671ad1c8ec74f72", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html#a8034c3c1967b3489e648e6a2544f14a3", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputePolynomialY__2.html#ae1fca8a9f3ea9e346f25ab558b54520b", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ComputeY_2", "classAlgebraicKernel__d__2_1_1ComputeY__2.html", [
+      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputeY__2.html#a77fb0e205b57887b5362ef9a92fff0e6", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputeY__2.html#a030607cc057fef94422eca67571c7390", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputeY__2.html#a142f8cff0c7458e2be20e76894cbe306", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::IsCoprime_2", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#a909104a5a2f17d5b567fd5e287031ef7", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#af503cd09aa7b97dae568264fd1f9298d", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#a64728591a3bbb6e33b5c93dd9e226c9e", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1IsCoprime__2.html#a090739fa50812c67afbb1404d57a4efc", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::IsolateX_2", "classAlgebraicKernel__d__2_1_1IsolateX__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#ad1eff8a1874e2e9534783b09ed295b5e", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#ab7c6ea4e7be633e8d4bc5c0516afe549", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#af64615dcf2f92b425707f4611f8f635a", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1IsolateX__2.html#a17d5ddb4e2735ad3894b62c2a2d25770", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::IsSquareFree_2", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html", [
+      [ "argument_type", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html#a68c51b79862840acd010251c68013ded", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html#a9e882751c27e35e20f0a59b374bc1111", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1IsSquareFree__2.html#a50482c6e301119f529ead8c47015831c", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::MakeCoprime_2", "classAlgebraicKernel__d__2_1_1MakeCoprime__2.html", [
+      [ "result_type", "classAlgebraicKernel__d__2_1_1MakeCoprime__2.html#a09d129e979f69ab0d1db417d3683b26e", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1MakeCoprime__2.html#ac464b05870526933f83a5c048c0bd881", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::NumberOfSolutions_2", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#a63b533be863262d787c60168b87ac68d", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#a6be16f0f2da771011675867172003d73", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#aa93f8fb1a9fe7229c8fbe5030329c5fc", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#accf9c52cfbcd43e8b6e66af6f2c6c73a", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::Solve_2", "classAlgebraicKernel__d__2_1_1Solve__2.html", [
+      [ "operator()", "classAlgebraicKernel__d__2_1_1Solve__2.html#a018e952909c222963e4bff4b70d94e00", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1Solve__2.html#a38ca9c46ab9010173be9cf359f824a5f", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ApproximateAbsoluteY_2", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#ab41275e73ac841b16f52e0c4e0b31834", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#a355bef23e07fd0ce6f5fb8874d7bd6de", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#abda2c350167b0f5a22d67e4f28d5bfd3", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateAbsoluteY__2.html#adeb8a3e707309326695cec5fc78c0f22", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::BoundBetweenY_2", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a207fafe3494322b3904f4dbda18f2328", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a9a2185e30d47762eb31c02f225cb1956", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a5c18b3c6b7d376f2ce13996023ef94d6", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1BoundBetweenY__2.html#a4e3ee7ca720c366f98f6b56e55bade12", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ComputePolynomialX_2", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html", [
+      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html#ab8f428363e36113ddc77b0f9a4d269dd", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html#a5997ad6ece8bae15a98aed927688011a", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputePolynomialX__2.html#aef6ca2082e80790e4416cbf17bb54f29", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ConstructAlgebraicReal_2", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html", [
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#afcf2b866fa86798eec82df44eb81131d", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#ac1faf797abd4259798ba4091305acbc7", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#ac57902047388920b0e8eaf22c3c9aa94", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#abb3d80f57a61a77996566bcc8064590a", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#a336040f0baabe8b2a537eeba14375a9b", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#af6a5912cf3cf33e4bd15a224d7b4befa", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ConstructAlgebraicReal__2.html#ab195914d2072e48892922a5a07e15af2", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::IsolateY_2", "classAlgebraicKernel__d__2_1_1IsolateY__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#aacbce87512dfdd3bf16eace0cb2e0cd7", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#a825c7ff4cffc0296de1185b54c939c39", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#a82ad5dd28a28af5f2bfa0f2fe7b5f4bc", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1IsolateY__2.html#a4adc29ba2e69a8ece3420ccc96bb9d0c", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::MakeSquareFree_2", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html", [
+      [ "argument_type", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html#a89169a5207b3d44f95569fea4b00ecc0", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html#ad69d61bb4ad676e886b1571766262182", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1MakeSquareFree__2.html#a2acdc4cd7a436621829cabd7b2895362", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::SquareFreeFactorize_2", "classAlgebraicKernel__d__2_1_1SquareFreeFactorize__2.html", [
+      [ "operator()", "classAlgebraicKernel__d__2_1_1SquareFreeFactorize__2.html#a69a2c5c3cb5c7d1c1b869380ea9c458d", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ApproximateRelativeY_2", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#aa608c33fa5f2525a36751c0813419d40", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#a6c1fddb591caddc3c19a9e2a97a0dbf4", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#a1e1b8ebae9a62224019de9ff99904cb3", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ApproximateRelativeY__2.html#afe4ab03e1acf746bfedf08541eb70ab6", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::ComputeX_2", "classAlgebraicKernel__d__2_1_1ComputeX__2.html", [
+      [ "argument_type", "classAlgebraicKernel__d__2_1_1ComputeX__2.html#a5c88f2c6ba460bb3e01c94e286dda6e3", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1ComputeX__2.html#a8ba7779e8f6e810de2a29ea6985ac3cb", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1ComputeX__2.html#aa02046cd2b64b5c8324ddca12e1eb624", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::IsZeroAt_2", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a2a3aedfe1d972865d9f982b13627f38f", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a994b983fd6b45366bff578f309c3fa84", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a66dbe3156f3e8ce85a3e8678d2941d98", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1IsZeroAt__2.html#a04ca017106b60cfe6c4f57eca11436b8", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::CompareXY_2", "classAlgebraicKernel__d__2_1_1CompareXY__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a3c90d2322dbb5042c1675b2add6c175a", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a5975727de0eac2636d0ed083131d1936", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#afffc46d70f7e376190528af293857449", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a43e538b7ac94badd2d0dbe0507201d89", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a5c499c6a6b1e68b152edfb8a705928d4", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#ac7a8cbb58420780d96a63e27f74447a6", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1CompareXY__2.html#a8402f6fb253cea9112569a0dd039f49f", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::SignAt_2", "classAlgebraicKernel__d__2_1_1SignAt__2.html", [
+      [ "first_argument_type", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a7b968a95322be66cc294f2ca71003477", null ],
+      [ "result_type", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a67a331d620299d082f8f06697fb94516", null ],
+      [ "second_argument_type", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a4781083223961032b9cf7c86f44143f0", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1SignAt__2.html#a9d7df92d198f989d38d49225aa68dd3e", null ]
+    ] ],
+    [ "AlgebraicKernel_d_2::Isolate_2", "classAlgebraicKernel__d__2_1_1Isolate__2.html", [
+      [ "result_type", "classAlgebraicKernel__d__2_1_1Isolate__2.html#a3c19a694fa697309163bdab52b313007", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1Isolate__2.html#a902cd224f8f72400869dac62b3cf002f", null ],
+      [ "operator()", "classAlgebraicKernel__d__2_1_1Isolate__2.html#a9e8d933037199ef327578fa158f1ca65", null ]
     ] ]
 ];
\ No newline at end of file
