@@ -25,18 +25,6 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Algebraic__kernel__d__2.html#a56464cc4a40d5a3164c84f4dde2bfbd6":[1,0,1,1,3],
 "classCGAL_1_1Algebraic__kernel__d__2.html#ae2a0173a781c1569be3814f3ebae6393":[1,0,1,1,0],
 "classCGAL_1_1Algebraic__kernel__d__2.html#ae4eb6a9c1525552ae219b72d4572b676":[1,0,1,1,4],
-"classCGAL_1_1Algebraic__kernel__rs__gmpq__d__1.html":[1,0,1,2],
-"classCGAL_1_1Algebraic__kernel__rs__gmpq__d__1.html#a2e7dcc853ab07447c1c4ebbf89ae8d86":[1,0,1,2,4],
-"classCGAL_1_1Algebraic__kernel__rs__gmpq__d__1.html#a345688d5dc507f745842eacf20a3eeeb":[1,0,1,2,1],
-"classCGAL_1_1Algebraic__kernel__rs__gmpq__d__1.html#a3570fa6371f5f48380018bda5741177e":[1,0,1,2,0],
-"classCGAL_1_1Algebraic__kernel__rs__gmpq__d__1.html#aa921c1231d45e8fa7d9de73fd6f6b060":[1,0,1,2,2],
-"classCGAL_1_1Algebraic__kernel__rs__gmpq__d__1.html#acb4203300435fd6101f48c630f4e7a44":[1,0,1,2,3],
-"classCGAL_1_1Algebraic__kernel__rs__gmpz__d__1.html":[1,0,1,3],
-"classCGAL_1_1Algebraic__kernel__rs__gmpz__d__1.html#a574aecf1ff8d6c1824a367afe332d0a4":[1,0,1,3,2],
-"classCGAL_1_1Algebraic__kernel__rs__gmpz__d__1.html#a68472d5cee1209caf0af7c97ee48bf5f":[1,0,1,3,3],
-"classCGAL_1_1Algebraic__kernel__rs__gmpz__d__1.html#aed1ed0ebb766c8b168098cf663cc3e9a":[1,0,1,3,1],
-"classCGAL_1_1Algebraic__kernel__rs__gmpz__d__1.html#af61d9170d7e237876515e848ce53c470":[1,0,1,3,0],
-"classCGAL_1_1Algebraic__kernel__rs__gmpz__d__1.html#aff5fd16c46ddef8f0f414540c7d998ed":[1,0,1,3,4],
 "examples.html":[4],
 "group__PkgAlgebraicKernelDConcepts.html":[1,0,0],
 "group__PkgAlgebraicKernelDConceptsBi.html":[1,0,0,0],
@@ -46,7 +34,6 @@ var NAVTREEINDEX1 =
 "index.html":[0],
 "index.html":[],
 "index.html#Algebraic_kernel_dAlgebraic":[0,1],
-"index.html#Algebraic_kernel_dAlgebraicKernelsBasedon":[0,2,1],
 "index.html#Algebraic_kernel_dAuxiliaryFunctionality":[0,1,5],
 "index.html#Algebraic_kernel_dBivariateAlgebraicKernel":[0,1,7],
 "index.html#Algebraic_kernel_dComparisonandApproximation":[0,1,3],
