@@ -1,6 +1,5 @@
 var classCGAL_1_1Arr__conic__traits__2 =
 [
-    [ "Approximate_2", "classCGAL_1_1Arr__conic__traits__2_1_1Approximate__2.html", "classCGAL_1_1Arr__conic__traits__2_1_1Approximate__2" ],
     [ "Construct_bbox_2", "classCGAL_1_1Arr__conic__traits__2_1_1Construct__bbox__2.html", "classCGAL_1_1Arr__conic__traits__2_1_1Construct__bbox__2" ],
     [ "Construct_curve_2", "classCGAL_1_1Arr__conic__traits__2_1_1Construct__curve__2.html", "classCGAL_1_1Arr__conic__traits__2_1_1Construct__curve__2" ],
     [ "Construct_x_monotone_curve_2", "classCGAL_1_1Arr__conic__traits__2_1_1Construct__x__monotone__curve__2.html", "classCGAL_1_1Arr__conic__traits__2_1_1Construct__x__monotone__curve__2" ],
@@ -13,7 +12,6 @@ var classCGAL_1_1Arr__conic__traits__2 =
     [ "Approximate_number_type", "classCGAL_1_1Arr__conic__traits__2.html#a4029ac5a0c0e371b669be0ea3c77033e", null ],
     [ "Approximate_point_2", "classCGAL_1_1Arr__conic__traits__2.html#ae7a6d72cf6757bbbc649862c82bab0db", null ],
     [ "Rational", "classCGAL_1_1Arr__conic__traits__2.html#a780cff469d9fa49c6179ae9ae6eefd9e", null ],
-    [ "approximate_2_object", "classCGAL_1_1Arr__conic__traits__2.html#ab427b07d13ca36c6b458802a1d4e9963", null ],
     [ "construct_bbox_2_object", "classCGAL_1_1Arr__conic__traits__2.html#afd15e5f123a92932fbcce7722e0c7de8", null ],
     [ "construct_curve_2_object", "classCGAL_1_1Arr__conic__traits__2.html#a2d93f78f17c40db02eed007a93dee3b1", null ],
     [ "construct_x_monotone_curve_2_object", "classCGAL_1_1Arr__conic__traits__2.html#a83ea5b15083555c95d7972f6374e0296", null ],
