@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0.3 - 2D Arrangements", "index.html", [
+  [ "CGAL 6.1 - 2D Arrangements", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Deprecated List", "deprecated.html", null ],
@@ -37,12 +37,13 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Arrangement_on_surface_2_2Bezier_curves_8cpp-example.html",
-"classArrangementDcelFace.html#a996569d42ff78b6202a70b4ee9cf78b2",
-"classArrangementTopSideTraits__2.html",
-"classCGAL_1_1Arr__circle__segment__traits__2_1_1Curve__2.html#a5a1ee07a6b96caf47947b164a5785023",
-"classCGAL_1_1Arr__linear__traits__2_1_1X__monotone__curve__2.html#a114883fdc3602ebd7b24ca4b6c2e9953",
-"classCGAL_1_1Arr__trapezoid__ric__point__location.html#a57d2e24039949c304b289a0dc7af4cde",
-"classCGAL_1_1Arrangement__with__history__2.html#ad368cff686575c0a5104f580c1f66d6d"
+"classAosDcelIsolatedVertex.html#aae9a2f235cd1299ff3d7e32fb9ab8d05",
+"classAosTraits_1_1IsVertical__2.html",
+"classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#ad9e26e2c2fb67e0d8a4ba9ac1849c2e4",
+"classCGAL_1_1Arr__face__index__map.html#aca9b0c1a03ab484c85cdbea9382a4488",
+"classCGAL_1_1Arr__rational__function__traits__2_1_1Curve__2.html#a635a7d11463a202fa00533f32d2aecae",
+"classCGAL_1_1Arrangement__on__surface__2.html#a43113edb82930474c25b57b9a8e2143f",
+"group__PkgArrangementOnSurface2Insert.html#ga92e366673e866d93370d61a828f8e5e2"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
