@@ -1,61 +1,68 @@
 var NAVTREEINDEX2 =
 {
-"classArrangementTopSideTraits__2.html":[1,0,0,4,25],
-"classArrangementTopologyTraits.html":[1,0,0,0,1],
-"classArrangementTopologyTraits.html#a173aeb993324e69816a7eebfabf45c79":[1,0,0,0,1,3],
-"classArrangementTopologyTraits.html#a4301698adfa5ac8eab2a8227ffb3fb93":[1,0,0,0,1,0],
-"classArrangementTopologyTraits.html#a66aded62b4a6b55ed490dbbfbc5a0161":[1,0,0,0,1,4],
-"classArrangementTopologyTraits.html#a8f00a048d9d3127cdbf624d953eb9ab3":[1,0,0,0,1,1],
-"classArrangementTopologyTraits.html#ad526e859401de869c46403d515e63443":[1,0,0,0,1,2],
-"classArrangementTraits__2.html":[1,0,0,4,26],
-"classArrangementTraits__2.html#a2cb306c890ab7d32f397b5d246e0271f":[1,0,0,4,26,0],
-"classArrangementTraits__2.html#ad1e498a469a16101f14d72f9b6181229":[1,0,0,4,26,2],
-"classArrangementTraits__2.html#ae7fb20dc627766bd122192d6e5c1da57":[1,0,0,4,26,1],
-"classArrangementVerticalRayShoot__2.html":[1,0,0,8],
-"classArrangementVerticalRayShoot__2.html#a1236b3ea3284af441f542f3ca36f0392":[1,0,0,8,5],
-"classArrangementVerticalRayShoot__2.html#a33d0c9190d4a9bfd11bb410f14722577":[1,0,0,8,1],
-"classArrangementVerticalRayShoot__2.html#a8f9dc418f3682f40f2b6d27c75c169a7":[1,0,0,8,6],
-"classArrangementVerticalRayShoot__2.html#a90e95f5355e662a81b288a43f92b9a7a":[1,0,0,8,3],
-"classArrangementVerticalRayShoot__2.html#ab5c80d9b290a309278ba1296857e11f1":[1,0,0,8,7],
-"classArrangementVerticalRayShoot__2.html#ac76ed5933ac3d26189ca846d96de9c4e":[1,0,0,8,0],
-"classArrangementVerticalRayShoot__2.html#ace4034f248df76e4f5ddc57e51536428":[1,0,0,8,2],
-"classArrangementVerticalRayShoot__2.html#aec9ef5dd1cd6a450906b299a833668f8":[1,0,0,8,4],
-"classArrangementVerticalSideTraits__2.html":[1,0,0,4,27],
-"classArrangementVerticalSideTraits__2.html#a251a37ce317905cf67106959bf098c29":[1,0,0,4,27,2],
-"classArrangementVerticalSideTraits__2.html#a4c3194c1e03aa351ccb19a820ff3fcc9":[1,0,0,4,27,0],
-"classArrangementVerticalSideTraits__2.html#a5cb419bcfb3a09a574a6949a9fdf1011":[1,0,0,4,27,3],
-"classArrangementVerticalSideTraits__2.html#aa5f28542a43863ce2d5d5d02d40b9b31":[1,0,0,4,27,1],
-"classArrangementWithHistoryInputFormatter.html":[1,0,0,9],
-"classArrangementWithHistoryInputFormatter.html#a6a6c68723954b2321155cb79a1fb8833":[1,0,0,9,4],
-"classArrangementWithHistoryInputFormatter.html#a6dbb3a67e080100588760d1613f40d06":[1,0,0,9,5],
-"classArrangementWithHistoryInputFormatter.html#a7c69853ff127627bfe71d292ab0e587f":[1,0,0,9,6],
-"classArrangementWithHistoryInputFormatter.html#a90d1cdf99e72a82465589fff11a834d1":[1,0,0,9,7],
-"classArrangementWithHistoryInputFormatter.html#a945882f367881313ae945248306717a5":[1,0,0,9,3],
-"classArrangementWithHistoryInputFormatter.html#aaa367d81dcf709bfb7470deeac5fc7ad":[1,0,0,9,1],
-"classArrangementWithHistoryInputFormatter.html#aca539e46cd309172eeecee67bacfc733":[1,0,0,9,0],
-"classArrangementWithHistoryInputFormatter.html#ad40d42488ce495f945541c27ffd3e4c7":[1,0,0,9,2],
-"classArrangementWithHistoryInputFormatter.html#ae3369e00a811735957677eb2807e124c":[1,0,0,9,8],
-"classArrangementWithHistoryOutputFormatter.html":[1,0,0,10],
-"classArrangementWithHistoryOutputFormatter.html#a0c2df1ddc83219db94e52e133736c9bd":[1,0,0,10,3],
-"classArrangementWithHistoryOutputFormatter.html#a21df39922752efe445ae70db9d28e5ab":[1,0,0,10,8],
-"classArrangementWithHistoryOutputFormatter.html#a5d6b72e1058a5b137f0e4e5977f69838":[1,0,0,10,7],
-"classArrangementWithHistoryOutputFormatter.html#a6d6f3eb3592cf831b850db6dd7659aa0":[1,0,0,10,4],
-"classArrangementWithHistoryOutputFormatter.html#ad6a354d43dc422cffb4662825e5ef109":[1,0,0,10,0],
-"classArrangementWithHistoryOutputFormatter.html#adabfe631712fa6459308d75899bb1a4a":[1,0,0,10,5],
-"classArrangementWithHistoryOutputFormatter.html#add4b9cc50a92d4c610710595cf5977d1":[1,0,0,10,2],
-"classArrangementWithHistoryOutputFormatter.html#adfc77f1707dc4f101c312548fd75e9c1":[1,0,0,10,6],
-"classArrangementWithHistoryOutputFormatter.html#af046909104225bcb04b229aeb18e7b0f":[1,0,0,10,1],
-"classArrangementXMonotoneTraits__2.html":[1,0,0,4,28],
-"classArrangementXMonotoneTraits__2.html#a02971c1a638cb1a051c32ef70faef907":[1,0,0,4,28,1],
-"classArrangementXMonotoneTraits__2.html#a1c0bd5c994b6bb9fdab1ffa2e8749ab9":[1,0,0,4,28,8],
-"classArrangementXMonotoneTraits__2.html#a1d639595401e0c12a9c605c8da835bee":[1,0,0,4,28,9],
-"classArrangementXMonotoneTraits__2.html#a2966f1d49ebda07d2de23a749259283f":[1,0,0,4,28,5],
-"classArrangementXMonotoneTraits__2.html#a3d7c4f0cb7c04aa4cf124c10e556b066":[1,0,0,4,28,0],
-"classArrangementXMonotoneTraits__2.html#a52bad98a97d6c02f8ea18e4a8eb78c2a":[1,0,0,4,28,2],
-"classArrangementXMonotoneTraits__2.html#a5fe8859feff75f588bf2000d72087fc9":[1,0,0,4,28,3],
-"classArrangementXMonotoneTraits__2.html#a797dac14c34f82bee82669633618f8e4":[1,0,0,4,28,4],
-"classArrangementXMonotoneTraits__2.html#a7d74339ce15211da1182e745d9585079":[1,0,0,4,28,7],
-"classArrangementXMonotoneTraits__2.html#ad05bade70a956a268137c80b89dde032":[1,0,0,4,28,6],
+"classAosTraits_1_1IsVertical__2.html":[1,0,0,3,20],
+"classAosTraits_1_1IsVertical__2.html#a38a57654e030ad06da2100f23f4c5805":[1,0,0,3,20,0],
+"classAosTraits_1_1MakeXMonotone__2.html":[1,0,0,3,21],
+"classAosTraits_1_1MakeXMonotone__2.html#ac718466c7a951d67622a55190f7f711c":[1,0,0,3,21,0],
+"classAosTraits_1_1Merge__2.html":[1,0,0,3,22],
+"classAosTraits_1_1Merge__2.html#a0e6de52b7791ca3cac710a35224a683b":[1,0,0,3,22,0],
+"classAosTraits_1_1ParameterSpaceInX__2.html":[1,0,0,3,23],
+"classAosTraits_1_1ParameterSpaceInX__2.html#ae2f360b74ae6e978ec395bc59d8822c2":[1,0,0,3,23,0],
+"classAosTraits_1_1ParameterSpaceInY__2.html":[1,0,0,3,24],
+"classAosTraits_1_1ParameterSpaceInY__2.html#ae233756ede512a855b890c638bb68899":[1,0,0,3,24,0],
+"classAosTraits_1_1Point__2.html":[1,0,0,2,1],
+"classAosTraits_1_1Split__2.html":[1,0,0,3,25],
+"classAosTraits_1_1Split__2.html#a810810232ab62b6d3bf7c0afde643671":[1,0,0,3,25,0],
+"classAosTraits_1_1XMonotoneCurve__2.html":[1,0,0,2,2],
+"classAosTraits__2.html":[1,0,0,4,27],
+"classAosTraits__2.html#a7ac63c51d66284c140e17fac721557a9":[1,0,0,4,27,1],
+"classAosTraits__2.html#acf24211255901a72ce361b39acb8a715":[1,0,0,4,27,2],
+"classAosTraits__2.html#af32cd6122b1cc88bd028c906861d5999":[1,0,0,4,27,0],
+"classAosVerticalRayShoot__2.html":[1,0,0,8],
+"classAosVerticalRayShoot__2.html#a2853ae520da317c3dc04c7544297933e":[1,0,0,8,4],
+"classAosVerticalRayShoot__2.html#a3be7a6ad2cb674dd9162b2d9167ba4da":[1,0,0,8,3],
+"classAosVerticalRayShoot__2.html#a558bc5ce322078eb21f229e7ae59affb":[1,0,0,8,6],
+"classAosVerticalRayShoot__2.html#a5bb6faba6dbb01aa933de41dce25cdd9":[1,0,0,8,2],
+"classAosVerticalRayShoot__2.html#a686a1fbe7d71c960ecc5c74e5f01c632":[1,0,0,8,5],
+"classAosVerticalRayShoot__2.html#a9cf3a207bfb988df0b9ec23b43706c9c":[1,0,0,8,0],
+"classAosVerticalRayShoot__2.html#ad8787e2399b9adde7a06761e16a80351":[1,0,0,8,1],
+"classAosVerticalRayShoot__2.html#ae78037c9084ac7578d1f380b0c38e5de":[1,0,0,8,7],
+"classAosVerticalSideTraits__2.html":[1,0,0,4,28],
+"classAosVerticalSideTraits__2.html#a78b158ce34d53fa3939758735667ae84":[1,0,0,4,28,3],
+"classAosVerticalSideTraits__2.html#ac6765e845d2f4f7b990a8475af1e5483":[1,0,0,4,28,1],
+"classAosVerticalSideTraits__2.html#ae4ecc3b5e645e2b42fc0f98d41d296ec":[1,0,0,4,28,2],
+"classAosVerticalSideTraits__2.html#aed35e331bbef3d45b490d2e68254b532":[1,0,0,4,28,0],
+"classAosWithHistoryInputFormatter.html":[1,0,0,9],
+"classAosWithHistoryInputFormatter.html#a408b37d0764c04ff03722c227cf2a86e":[1,0,0,9,6],
+"classAosWithHistoryInputFormatter.html#a4f00734a75da0a79e687f697b3e75acf":[1,0,0,9,0],
+"classAosWithHistoryInputFormatter.html#a5798687c9f0fc6b67e6f1f672b609b1f":[1,0,0,9,4],
+"classAosWithHistoryInputFormatter.html#a5ce1753a4df6ad5699c15c02171c8fe7":[1,0,0,9,2],
+"classAosWithHistoryInputFormatter.html#a728d08c7fc6fc9cd502d5947e75d3b6e":[1,0,0,9,7],
+"classAosWithHistoryInputFormatter.html#a87f81c8923062b885fa563726f84cb70":[1,0,0,9,3],
+"classAosWithHistoryInputFormatter.html#a95ab74cb9f26e89d9cc28ef3f7ebe39b":[1,0,0,9,1],
+"classAosWithHistoryInputFormatter.html#aa21f7262c8f324ef864249e6f7826d1c":[1,0,0,9,8],
+"classAosWithHistoryInputFormatter.html#ab8dd94a222c1532831a061b21e145b9e":[1,0,0,9,5],
+"classAosWithHistoryOutputFormatter.html":[1,0,0,10],
+"classAosWithHistoryOutputFormatter.html#a09777b2536b64fe42bc43d36c59a47f8":[1,0,0,10,3],
+"classAosWithHistoryOutputFormatter.html#a0f87bbccd761cb6b56e80157b10fae00":[1,0,0,10,8],
+"classAosWithHistoryOutputFormatter.html#a111f6ec49d6e9a388a254973defa05bf":[1,0,0,10,2],
+"classAosWithHistoryOutputFormatter.html#a15709eef6512ed69aa6243d3ef10792a":[1,0,0,10,4],
+"classAosWithHistoryOutputFormatter.html#a240f0bd0db62993acd6ef3e6170df1a0":[1,0,0,10,1],
+"classAosWithHistoryOutputFormatter.html#a2e92473d63f10387b80aca9c9e504550":[1,0,0,10,0],
+"classAosWithHistoryOutputFormatter.html#a3ba61f99de355040fee4f27fdef0fa20":[1,0,0,10,6],
+"classAosWithHistoryOutputFormatter.html#a61e2ecc118091ed9bbc1fcff66aaf56a":[1,0,0,10,5],
+"classAosWithHistoryOutputFormatter.html#ace1ff7940f1299d6821b2cd044923e8f":[1,0,0,10,7],
+"classAosXMonotoneTraits__2.html":[1,0,0,4,29],
+"classAosXMonotoneTraits__2.html#a1b41c489f0d709ab3cc8425e7f73fe8b":[1,0,0,4,29,8],
+"classAosXMonotoneTraits__2.html#a22f0d8bc867a1103fdbbbff72e455a22":[1,0,0,4,29,5],
+"classAosXMonotoneTraits__2.html#a28aa47467c7c598f76e243d4cdc2bd45":[1,0,0,4,29,2],
+"classAosXMonotoneTraits__2.html#a4bfcdbfdeff229331dfd9ab2bdb301a8":[1,0,0,4,29,1],
+"classAosXMonotoneTraits__2.html#a55c00c86b5236e65d898d1f432f38dac":[1,0,0,4,29,7],
+"classAosXMonotoneTraits__2.html#a6184867682b01f4135ab9ffb90edcc55":[1,0,0,4,29,6],
+"classAosXMonotoneTraits__2.html#a848574fa9229fa770b3c8f3c8b24c1aa":[1,0,0,4,29,0],
+"classAosXMonotoneTraits__2.html#a8b4f42c7d2f07e242785ecf1bfe5edf3":[1,0,0,4,29,9],
+"classAosXMonotoneTraits__2.html#ab81acb830ebbeaca36887e4d71f6dd15":[1,0,0,4,29,4],
+"classAosXMonotoneTraits__2.html#acaeea5e598b92a704d74cb903273024b":[1,0,0,4,29,3],
 "classCGAL_1_1Aos__observer.html":[1,0,11],
 "classCGAL_1_1Aos__observer.html#a004bfc01d6e86cd8f584ba649dc01725":[1,0,11,69],
 "classCGAL_1_1Aos__observer.html#a07ba48b15931eb9ef5a1f927416b4b2b":[1,0,11,40],
@@ -132,10 +139,10 @@ var NAVTREEINDEX2 =
 "classCGAL_1_1Arr__Bezier__curve__traits__2.html#a156904cec80f52a59169d74e0b7f5645":[1,0,1,1,5],
 "classCGAL_1_1Arr__Bezier__curve__traits__2.html#a50dc9b97db140ae45d31891a503713d9":[1,0,1,1,4],
 "classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html":[1,0,1,1,0],
+"classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#a27820faaad7aa563a315772c253e2a1e":[1,0,1,1,0,2],
 "classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#a2858f5fa7d4ed39441365536ff6f72ca":[1,0,1,1,0,5],
-"classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#a4890447562d2abc3e146c9ec3ac02bce":[1,0,1,1,0,2],
-"classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#a48dc2584f047c6c9abccde97ce23d70c":[1,0,1,1,0,3],
 "classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#ab241dee7867c581f7e17f7b35fdc5a2b":[1,0,1,1,0,0],
+"classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#ad79a9aef614b375a5247c7c34b7d42e8":[1,0,1,1,0,3],
 "classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#adcfd7b5eaf35779cb3b00837696fc28b":[1,0,1,1,0,4],
 "classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Curve__2.html#af990930e984b99207d21fefe033975a6":[1,0,1,1,0,1],
 "classCGAL_1_1Arr__Bezier__curve__traits__2_1_1Point__2.html":[1,0,1,1,1],
@@ -242,12 +249,5 @@ var NAVTREEINDEX2 =
 "classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#a98173ee0895ca5463ecc000cb7c96074":[1,0,13,13],
 "classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#a9bbe9d66739dc4e6f27cfd68ae1f18b6":[1,0,13,9],
 "classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#aa9e1a8f7b4f01664c5d9acc0d0b20bcb":[1,0,13,6],
-"classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#ad1568d2035dad225d5dd11348875db70":[1,0,13,11],
-"classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#ad9e26e2c2fb67e0d8a4ba9ac1849c2e4":[1,0,13,0],
-"classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#af8f00f4cf1b15f96623e24c2c79103db":[1,0,13,5],
-"classCGAL_1_1Arr__circle__segment__traits__2.html":[1,0,1,2],
-"classCGAL_1_1Arr__circle__segment__traits__2_1_1Curve__2.html":[1,0,1,2,0],
-"classCGAL_1_1Arr__circle__segment__traits__2_1_1Curve__2.html#a1521e16b2127fe14d2bb191eed16a503":[1,0,1,2,0,13],
-"classCGAL_1_1Arr__circle__segment__traits__2_1_1Curve__2.html#a4eb8872a865eac890ef37c56cbb234e1":[1,0,1,2,0,0],
-"classCGAL_1_1Arr__circle__segment__traits__2_1_1Curve__2.html#a4eba41f9a9ac9c9bc3559882f3ac37f8":[1,0,1,2,0,8]
+"classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#ad1568d2035dad225d5dd11348875db70":[1,0,13,11]
 };
