@@ -15,24 +15,25 @@ var NAVTREEINDEX0 =
 "BGL_polyhedron_3_2polyhedron_partition_8cpp-example.html":[5,12],
 "BGL_polyhedron_3_2range_8cpp-example.html":[5,13],
 "BGL_polyhedron_3_2transform_iterator_8cpp-example.html":[5,14],
-"BGL_surface_mesh_2connected_components_8cpp-example.html":[5,25],
+"BGL_surface_mesh_2connected_components_8cpp-example.html":[5,26],
 "BGL_surface_mesh_2gwdwg_8cpp-example.html":[5,21],
 "BGL_surface_mesh_2prim_8cpp-example.html":[5,20],
 "BGL_surface_mesh_2seam_mesh_8cpp-example.html":[5,22],
-"BGL_surface_mesh_2surface_mesh_dual_8cpp-example.html":[5,24],
-"BGL_surface_mesh_2surface_mesh_partition_8cpp-example.html":[5,26],
-"BGL_surface_mesh_2write_inp_8cpp-example.html":[5,23],
+"BGL_surface_mesh_2shortest_path_8cpp-example.html":[5,23],
+"BGL_surface_mesh_2surface_mesh_dual_8cpp-example.html":[5,25],
+"BGL_surface_mesh_2surface_mesh_partition_8cpp-example.html":[5,27],
+"BGL_surface_mesh_2write_inp_8cpp-example.html":[5,24],
 "BGL_triangulation_2_2dijkstra_8cpp-example.html":[5,15],
 "BGL_triangulation_2_2dijkstra_with_internal_properties_8cpp-example.html":[5,16],
 "BGL_triangulation_2_2emst_8cpp-example.html":[5,17],
 "BGL_triangulation_2_2emst_cdt_plus_hierarchy_8cpp-example.html":[5,19],
 "BGL_triangulation_2_2emst_regular_8cpp-example.html":[5,18],
-"Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html":[5,29],
-"Polyhedron_2poly_derivation_8cpp-example.html":[5,32],
-"Property_map_2dynamic_properties_8cpp-example.html":[5,30],
-"Surface_mesh_2sm_derivation_8cpp-example.html":[5,31],
-"Surface_mesh_segmentation_2extract_segmentation_into_mesh_example_8cpp-example.html":[5,28],
-"Surface_mesh_skeletonization_2simple_mcfskel_example_8cpp-example.html":[5,27],
+"Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html":[5,30],
+"Polyhedron_2poly_derivation_8cpp-example.html":[5,33],
+"Property_map_2dynamic_properties_8cpp-example.html":[5,31],
+"Surface_mesh_2sm_derivation_8cpp-example.html":[5,32],
+"Surface_mesh_segmentation_2extract_segmentation_into_mesh_example_8cpp-example.html":[5,29],
+"Surface_mesh_skeletonization_2simple_mcfskel_example_8cpp-example.html":[5,28],
 "annotated.html":[4],
 "citelist.html":[3],
 "classCGAL_1_1Dual.html":[1,0,10,3],
@@ -159,14 +160,15 @@ var NAVTREEINDEX0 =
 "classVertexListGraph.html#a77e742c910da6a8230a45273186b130b":[1,0,2,7,0],
 "deprecated.html":[2],
 "examples.html":[5],
-"graph__traits__inheritance__macros_8h.html":[1,0,14],
+"graph__traits__inheritance__macros_8h.html":[1,0,15],
 "group__BGLGraphExternalIndices.html":[1,0,5],
 "group__BGLGraphExternalIndices.html#ga0660924a1aa87e8be5cccbc261e931c7":[1,0,5,8],
 "group__BGLGraphExternalIndices.html#ga1a22cf8bdde32fcdf1a4a78966eed630":[1,0,5,9],
 "group__PkgBGLAdaptors.html":[1,0,10],
 "group__PkgBGLConcepts.html":[1,0,2],
 "group__PkgBGLEulerOperations.html":[1,0,11],
-"group__PkgBGLEulerOperations.html#ga01dc93c57ad0079240dd9554de46a176":[1,0,11,17],
+"group__PkgBGLEulerOperations.html#ga01dc93c57ad0079240dd9554de46a176":[1,0,11,18],
+"group__PkgBGLEulerOperations.html#ga0c5f86e550583b25e9daa477315ab919":[1,0,11,7],
 "group__PkgBGLEulerOperations.html#ga12e0a6376e2755b48356b186e1344fdb":[1,0,11,9],
 "group__PkgBGLEulerOperations.html#ga174af506cebf3def60b56a3501843864":[1,0,11,10],
 "group__PkgBGLEulerOperations.html#ga1760f0f8e7bf35de6f396b6b86a0b9bb":[1,0,11,13],
@@ -178,15 +180,15 @@ var NAVTREEINDEX0 =
 "group__PkgBGLEulerOperations.html#ga8af4fd79178c66fef7091614c0bc4a01":[1,0,11,8],
 "group__PkgBGLEulerOperations.html#gaa305bfc634d2aa7bca376d0550d8363e":[1,0,11,14],
 "group__PkgBGLEulerOperations.html#gaa386d0cdef3b5d6ef43d6b503392dbcd":[1,0,11,2],
-"group__PkgBGLEulerOperations.html#gaaf9abf3f088f97463ede1ccfaa93b9d3":[1,0,11,7],
-"group__PkgBGLEulerOperations.html#gab86d0b0c959a8103ae58dc5ba23fb40d":[1,0,11,20],
+"group__PkgBGLEulerOperations.html#gab3455663b7db4624529e54ae3ce2387c":[1,0,11,16],
+"group__PkgBGLEulerOperations.html#gab86d0b0c959a8103ae58dc5ba23fb40d":[1,0,11,21],
 "group__PkgBGLEulerOperations.html#gaced3c3f58b5ac310e04e26b0b72c4aa0":[1,0,11,12],
-"group__PkgBGLEulerOperations.html#gacfae7ff8e782da55b941e4487e86c738":[1,0,11,16],
-"group__PkgBGLEulerOperations.html#gadc29dd4ad63e653e4eedf02220bb48da":[1,0,11,18],
+"group__PkgBGLEulerOperations.html#gacfae7ff8e782da55b941e4487e86c738":[1,0,11,17],
+"group__PkgBGLEulerOperations.html#gadc29dd4ad63e653e4eedf02220bb48da":[1,0,11,19],
 "group__PkgBGLEulerOperations.html#gaddf9d21ebb0ad54d9502e9ea507aa5db":[1,0,11,0],
 "group__PkgBGLEulerOperations.html#gaf98d4e129e7540001c030cbda75570e9":[1,0,11,11],
 "group__PkgBGLEulerOperations.html#gafa44d3b18f6492b95bb64c137d2ec18d":[1,0,11,15],
-"group__PkgBGLEulerOperations.html#gafbcf6ce6bf656f5e927ff9ea3c22a105":[1,0,11,19],
+"group__PkgBGLEulerOperations.html#gafbcf6ce6bf656f5e927ff9ea3c22a105":[1,0,11,20],
 "group__PkgBGLGeneratorFct.html":[1,0,7],
 "group__PkgBGLGeneratorFct.html#ga021bca7693efee1d05492ee52583793a":[1,0,7,0],
 "group__PkgBGLGeneratorFct.html#ga03d4d6b1b7cb4ef6c460487240e6bb10":[1,0,7,3],
@@ -225,29 +227,27 @@ var NAVTREEINDEX0 =
 "group__PkgBGLHelperFct.html#gae04c8044cf1eee6a84baa5b79ab99fef":[1,0,6,9],
 "group__PkgBGLHelperFct.html#gaefeddba3015a9723bfcacb904709bad0":[1,0,6,14],
 "group__PkgBGLHelperFct.html#gafa3bc673513c8750321bf062afd5e6b7":[1,0,6,23],
-"group__PkgBGLIOFct.html":[1,0,13],
-"group__PkgBGLIOFct.html#ga49f5b5e6fbfcbfaaac7604c88e10915c":[1,0,13,9],
-"group__PkgBGLIOFct.html#gafa143949a33371dc6df8307be1ab8a66":[1,0,13,10],
-"group__PkgBGLIOFctDeprecated.html":[1,0,13,8],
-"group__PkgBGLIOFctDeprecated.html#ga0ab5404e4eeb4ec0b53ef0a8f8c76b0f":[1,0,13,8,5],
-"group__PkgBGLIOFctDeprecated.html#ga382b858c3f029ac72d03e5b70663db6b":[1,0,13,8,0],
-"group__PkgBGLIOFctDeprecated.html#ga3cf109df96aa2f604d007ab7ac41d1dd":[1,0,13,8,3],
-"group__PkgBGLIOFctDeprecated.html#ga57572d046d6cf2455f74c94c9573ee09":[1,0,13,8,1],
-"group__PkgBGLIOFctDeprecated.html#gad89556470b08deb158c20526ccdaa069":[1,0,13,8,2],
-"group__PkgBGLIOFctDeprecated.html#gaf330d668dfb89f38cbf3c27c298a5e25":[1,0,13,8,4],
-"group__PkgBGLIoFuncs3MF.html":[1,0,13,7],
-"group__PkgBGLIoFuncs3MF.html#gae98865101af5e4ce88243e96a66fc4af":[1,0,13,7,0],
-"group__PkgBGLIoFuncsGOCAD.html":[1,0,13,5],
-"group__PkgBGLIoFuncsGOCAD.html#ga0c410551c039ae0d17e174f4bcf8abf2":[1,0,13,5,2],
-"group__PkgBGLIoFuncsGOCAD.html#ga5e9358f4bff9d3241c47fa2c4b2b8789":[1,0,13,5,0],
-"group__PkgBGLIoFuncsGOCAD.html#gacdeb673a394fde627d561f0e76307f34":[1,0,13,5,4],
-"group__PkgBGLIoFuncsGOCAD.html#gad6ba9ef0b9b83b454b73dae1f7ac1a0d":[1,0,13,5,1],
-"group__PkgBGLIoFuncsGOCAD.html#gaf820010477649ec0ed0fc88281095d32":[1,0,13,5,3],
-"group__PkgBGLIoFuncsOBJ.html":[1,0,13,2],
-"group__PkgBGLIoFuncsOBJ.html#ga2870507971728c2b871f42a15ba74e7a":[1,0,13,2,0],
-"group__PkgBGLIoFuncsOBJ.html#ga28e1caa147b4e44e0870f7ba02f34ec2":[1,0,13,2,1],
-"group__PkgBGLIoFuncsOBJ.html#ga6354f94dfd862ef741f5b3cccf95f35c":[1,0,13,2,2],
-"group__PkgBGLIoFuncsOBJ.html#ga71c52dff3021f71894a12563f80602a9":[1,0,13,2,3],
-"group__PkgBGLIoFuncsOFF.html":[1,0,13,3],
-"group__PkgBGLIoFuncsOFF.html#ga577755cd808352de3844bd9fc9208788":[1,0,13,3,2]
+"group__PkgBGLIOFct.html":[1,0,14],
+"group__PkgBGLIOFct.html#ga49f5b5e6fbfcbfaaac7604c88e10915c":[1,0,14,10],
+"group__PkgBGLIOFct.html#gafa143949a33371dc6df8307be1ab8a66":[1,0,14,11],
+"group__PkgBGLIOFctDeprecated.html":[1,0,14,9],
+"group__PkgBGLIOFctDeprecated.html#ga0ab5404e4eeb4ec0b53ef0a8f8c76b0f":[1,0,14,9,5],
+"group__PkgBGLIOFctDeprecated.html#ga382b858c3f029ac72d03e5b70663db6b":[1,0,14,9,0],
+"group__PkgBGLIOFctDeprecated.html#ga3cf109df96aa2f604d007ab7ac41d1dd":[1,0,14,9,3],
+"group__PkgBGLIOFctDeprecated.html#ga57572d046d6cf2455f74c94c9573ee09":[1,0,14,9,1],
+"group__PkgBGLIOFctDeprecated.html#gad89556470b08deb158c20526ccdaa069":[1,0,14,9,2],
+"group__PkgBGLIOFctDeprecated.html#gaf330d668dfb89f38cbf3c27c298a5e25":[1,0,14,9,4],
+"group__PkgBGLIoFuncs3MF.html":[1,0,14,8],
+"group__PkgBGLIoFuncs3MF.html#gae98865101af5e4ce88243e96a66fc4af":[1,0,14,8,0],
+"group__PkgBGLIoFuncsGOCAD.html":[1,0,14,6],
+"group__PkgBGLIoFuncsGOCAD.html#ga0c410551c039ae0d17e174f4bcf8abf2":[1,0,14,6,2],
+"group__PkgBGLIoFuncsGOCAD.html#ga5e9358f4bff9d3241c47fa2c4b2b8789":[1,0,14,6,0],
+"group__PkgBGLIoFuncsGOCAD.html#gacdeb673a394fde627d561f0e76307f34":[1,0,14,6,4],
+"group__PkgBGLIoFuncsGOCAD.html#gad6ba9ef0b9b83b454b73dae1f7ac1a0d":[1,0,14,6,1],
+"group__PkgBGLIoFuncsGOCAD.html#gaf820010477649ec0ed0fc88281095d32":[1,0,14,6,3],
+"group__PkgBGLIoFuncsOBJ.html":[1,0,14,2],
+"group__PkgBGLIoFuncsOBJ.html#ga2870507971728c2b871f42a15ba74e7a":[1,0,14,2,0],
+"group__PkgBGLIoFuncsOBJ.html#ga28e1caa147b4e44e0870f7ba02f34ec2":[1,0,14,2,1],
+"group__PkgBGLIoFuncsOBJ.html#ga6354f94dfd862ef741f5b3cccf95f35c":[1,0,14,2,2],
+"group__PkgBGLIoFuncsOBJ.html#ga71c52dff3021f71894a12563f80602a9":[1,0,14,2,3]
 };
