@@ -1,13 +1,13 @@
 var examples =
 [
-    [ "Barycentric_coordinates_2/affine_coordinates.cpp", "Barycentric_coordinates_2_2affine_coordinates_8cpp-example.html", null ],
-    [ "Barycentric_coordinates_2/deprecated_coordinates.cpp", "Barycentric_coordinates_2_2deprecated_coordinates_8cpp-example.html", null ],
-    [ "Barycentric_coordinates_2/discrete_harmonic_coordinates.cpp", "Barycentric_coordinates_2_2discrete_harmonic_coordinates_8cpp-example.html", null ],
-    [ "Barycentric_coordinates_2/harmonic_coordinates.cpp", "Barycentric_coordinates_2_2harmonic_coordinates_8cpp-example.html", null ],
-    [ "Barycentric_coordinates_2/mean_value_coordinates.cpp", "Barycentric_coordinates_2_2mean_value_coordinates_8cpp-example.html", null ],
     [ "Barycentric_coordinates_2/segment_coordinates.cpp", "Barycentric_coordinates_2_2segment_coordinates_8cpp-example.html", null ],
-    [ "Barycentric_coordinates_2/shape_deformation.cpp", "Barycentric_coordinates_2_2shape_deformation_8cpp-example.html", null ],
-    [ "Barycentric_coordinates_2/terrain_height_modeling.cpp", "Barycentric_coordinates_2_2terrain_height_modeling_8cpp-example.html", null ],
     [ "Barycentric_coordinates_2/triangle_coordinates.cpp", "Barycentric_coordinates_2_2triangle_coordinates_8cpp-example.html", null ],
-    [ "Barycentric_coordinates_2/wachspress_coordinates.cpp", "Barycentric_coordinates_2_2wachspress_coordinates_8cpp-example.html", null ]
+    [ "Barycentric_coordinates_2/wachspress_coordinates.cpp", "Barycentric_coordinates_2_2wachspress_coordinates_8cpp-example.html", null ],
+    [ "Barycentric_coordinates_2/discrete_harmonic_coordinates.cpp", "Barycentric_coordinates_2_2discrete_harmonic_coordinates_8cpp-example.html", null ],
+    [ "Barycentric_coordinates_2/mean_value_coordinates.cpp", "Barycentric_coordinates_2_2mean_value_coordinates_8cpp-example.html", null ],
+    [ "Barycentric_coordinates_2/harmonic_coordinates.cpp", "Barycentric_coordinates_2_2harmonic_coordinates_8cpp-example.html", null ],
+    [ "Barycentric_coordinates_2/terrain_height_modeling.cpp", "Barycentric_coordinates_2_2terrain_height_modeling_8cpp-example.html", null ],
+    [ "Barycentric_coordinates_2/shape_deformation.cpp", "Barycentric_coordinates_2_2shape_deformation_8cpp-example.html", null ],
+    [ "Barycentric_coordinates_2/affine_coordinates.cpp", "Barycentric_coordinates_2_2affine_coordinates_8cpp-example.html", null ],
+    [ "Barycentric_coordinates_2/deprecated_coordinates.cpp", "Barycentric_coordinates_2_2deprecated_coordinates_8cpp-example.html", null ]
 ];
\ No newline at end of file
