@@ -6,7 +6,7 @@ var index =
       [ "Tuning with Graphics Scene Options", "index.html#BV_GraphicSceneOptions", null ]
     ] ],
     [ "The Graphics Scene", "index.html#BV_GraphicsScene", null ],
-    [ "The Basic Viewer Class", "index.html#BV_BasicViewer", null ],
+    [ "The Qt Basic Viewer Class", "index.html#BV_BasicViewer", null ],
     [ "Adding Interaction", "index.html#BV_Interactions", null ],
     [ "Design and Implementation History", "index.html#BV_Design", null ]
 ];
\ No newline at end of file
