@@ -1,7 +1,7 @@
 var group__PkgBoundingVolumesRef =
 [
     [ "Concepts", "group__PkgBoundingVolumesConcepts.html", "group__PkgBoundingVolumesConcepts" ],
-    [ "Approximate_min_ellipsoid_d", "classCGAL_1_1Approximate__min__ellipsoid__d.html", [
+    [ "CGAL::Approximate_min_ellipsoid_d< Traits >", "classCGAL_1_1Approximate__min__ellipsoid__d.html", [
       [ "Axes_direction_coordinate_iterator", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a7a6a1adb0e4590e5f07de50c03994de3", null ],
       [ "Axes_lengths_iterator", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a72cb50febc6d4c7c24c68a8016bde351", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Approximate__min__ellipsoid__d.html#adf47ed5aabdb6ad61f6efac038e2fb41", null ],
@@ -24,28 +24,28 @@ var group__PkgBoundingVolumesRef =
       [ "is_full_dimensional", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a636b12855568f4471e0dadc3d6fefb3f", null ],
       [ "is_valid", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a2449d677fe6d12a445d5a090723d9349", null ],
       [ "number_of_points", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a747a40738dc64031ddf3bb09144c7984", null ],
-      [ "traits", "classCGAL_1_1Approximate__min__ellipsoid__d.html#ac5ae03954e671b379a3879563ef023db", null ],
+      [ "traits", "classCGAL_1_1Approximate__min__ellipsoid__d.html#ad799fb3e56b6e4609963c4fd21663898", null ],
       [ "write_eps", "classCGAL_1_1Approximate__min__ellipsoid__d.html#a1cd41640f8cf8b562772399a0fb00b13", null ]
     ] ],
-    [ "Approximate_min_ellipsoid_d_traits_2", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html", [
+    [ "CGAL::Approximate_min_ellipsoid_d_traits_2< K, ET >", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html", [
       [ "Cartesian_const_iterator", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#a5309b1e046162e4b559cac9585c00abc", null ],
       [ "ET", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#afb1ed3381a30852ee5fe483a710eb479", null ],
       [ "FT", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#abf223b25a3617bdae9ccfc3cbdce7326", null ],
       [ "Point", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__2.html#aa907d2b0f3e7736fcd6815f806fc26be", null ]
     ] ],
-    [ "Approximate_min_ellipsoid_d_traits_3", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html", [
+    [ "CGAL::Approximate_min_ellipsoid_d_traits_3< K, ET >", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html", [
       [ "Cartesian_const_iterator", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#af5845621fee97bc1d6d68209d5b58f7c", null ],
       [ "ET", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#a677c8508fdb25ece5021ce348431ace8", null ],
       [ "FT", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#ac877f3c0e63bd32b12a6b5e0c3473ab8", null ],
       [ "Point", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__3.html#a1dec6c6b90a414871287e9afd7041144", null ]
     ] ],
-    [ "Approximate_min_ellipsoid_d_traits_d", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html", [
+    [ "CGAL::Approximate_min_ellipsoid_d_traits_d< K, ET >", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html", [
       [ "Cartesian_const_iterator", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#a84bd9b61bfc876a6a7e2c27fdd5e3898", null ],
       [ "ET", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#a7afbc4488836e7e4525a464eef1ff5cd", null ],
       [ "FT", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#a935d2599a3e2deb12509017bdba2b69d", null ],
       [ "Point", "structCGAL_1_1Approximate__min__ellipsoid__d__traits__d.html#ab8f47bce7eb1adb55c32dabdf3b2a6fa", null ]
     ] ],
-    [ "Min_annulus_d", "classCGAL_1_1Min__annulus__d.html", [
+    [ "CGAL::Min_annulus_d< Traits >", "classCGAL_1_1Min__annulus__d.html", [
       [ "Coordinate_iterator", "classCGAL_1_1Min__annulus__d.html#a2997ba09820a621e34e804f9edccd246", null ],
       [ "ET", "classCGAL_1_1Min__annulus__d.html#a947fa6cfa188274b8656a4380fc2d8cb", null ],
       [ "FT", "classCGAL_1_1Min__annulus__d.html#a5e8f3da81b7c3fd68ffaa21e7926c506", null ],
@@ -88,11 +88,11 @@ var group__PkgBoundingVolumesRef =
       [ "squared_radii_denominator", "classCGAL_1_1Min__annulus__d.html#ab99e20561e5eec7dd888fae46a5ddb17", null ],
       [ "support_points_begin", "classCGAL_1_1Min__annulus__d.html#aa13d1ab896d71286f55af4e2c6d9dfb3", null ],
       [ "support_points_end", "classCGAL_1_1Min__annulus__d.html#aa9bcc33770d92957f3307a2d5eb47516", null ],
-      [ "traits", "classCGAL_1_1Min__annulus__d.html#af4f4a62be80c86f863c91b9e18c1a651", null ],
+      [ "traits", "classCGAL_1_1Min__annulus__d.html#a388b4ee91e90b6bb81ec7d54ccb906bf", null ],
       [ "operator<<", "classCGAL_1_1Min__annulus__d.html#a5b3cb90ca9cbc372272fd93eecc20a3f", null ],
       [ "operator>>", "classCGAL_1_1Min__annulus__d.html#aa7aae875e52de2a0c597e6d020fe05ea", null ]
     ] ],
-    [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html", [
+    [ "CGAL::Min_circle_2< Traits >", "classCGAL_1_1Min__circle__2.html", [
       [ "Circle", "classCGAL_1_1Min__circle__2.html#a48aea3450e5b91924646e784481ff44d", null ],
       [ "Point", "classCGAL_1_1Min__circle__2.html#acaff2d7da19f3c8ca5bf8845253f6039", null ],
       [ "Point_iterator", "classCGAL_1_1Min__circle__2.html#a716c27257a327f9eb570de854ccb57f4", null ],
@@ -103,7 +103,7 @@ var group__PkgBoundingVolumesRef =
       [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html#aa6e065ed602ef49dcbf064d749f7cd32", null ],
       [ "Min_circle_2", "classCGAL_1_1Min__circle__2.html#ab68687584c9a3593e2316a26acc57ca5", null ],
       [ "bounded_side", "classCGAL_1_1Min__circle__2.html#a5e222fd1ba182d24bd6c10e0d31b2c75", null ],
-      [ "circle", "classCGAL_1_1Min__circle__2.html#a0e6629c5d9af38017400dc812edb584a", null ],
+      [ "circle", "classCGAL_1_1Min__circle__2.html#a746c29e29f7288b9a3a2741c9a207c11", null ],
       [ "clear", "classCGAL_1_1Min__circle__2.html#a3dd9c86b2ca28f8bd7d9274091d726eb", null ],
       [ "has_on_boundary", "classCGAL_1_1Min__circle__2.html#a649ea54cd5c4d679eecabe3f2e7d29b2", null ],
       [ "has_on_bounded_side", "classCGAL_1_1Min__circle__2.html#ac3c6dadb9c3289c43396f8a439c6257f", null ],
@@ -117,21 +117,21 @@ var group__PkgBoundingVolumesRef =
       [ "number_of_support_points", "classCGAL_1_1Min__circle__2.html#ac87c3d760053509a41be898771111854", null ],
       [ "points_begin", "classCGAL_1_1Min__circle__2.html#ade14badb14c8b404d099f637ff53be87", null ],
       [ "points_end", "classCGAL_1_1Min__circle__2.html#aa98f7f868d6c7cacd137bb18cc4ec527", null ],
-      [ "support_point", "classCGAL_1_1Min__circle__2.html#a5a544c739e6e46c2ced10d54720f89ec", null ],
+      [ "support_point", "classCGAL_1_1Min__circle__2.html#a5e52a11bc13981434a9b0e7c5dc6a1c8", null ],
       [ "support_points_begin", "classCGAL_1_1Min__circle__2.html#acb33d435a72cfcda800b739ba172082d", null ],
       [ "support_points_end", "classCGAL_1_1Min__circle__2.html#af808f54e70621f0fe201c4b327b5de3b", null ],
-      [ "traits", "classCGAL_1_1Min__circle__2.html#aab9f3aa378f5a4ef4c87a7fde63c0b4e", null ],
+      [ "traits", "classCGAL_1_1Min__circle__2.html#a6c918bb03abf62031574a645746086ef", null ],
       [ "operator<<", "classCGAL_1_1Min__circle__2.html#a693dca04f21bc2c897f489f085a0fbff", null ],
       [ "operator>>", "classCGAL_1_1Min__circle__2.html#a8c0e384847bfe95d8f8dc7c5291547c6", null ]
     ] ],
-    [ "Min_circle_2_traits_2", "classCGAL_1_1Min__circle__2__traits__2.html", [
+    [ "CGAL::Min_circle_2_traits_2< K >", "classCGAL_1_1Min__circle__2__traits__2.html", [
       [ "Circle", "classCGAL_1_1Min__circle__2__traits__2.html#a4730c8f60ffb166d97304f9d0ca2f564", null ],
       [ "Point", "classCGAL_1_1Min__circle__2__traits__2.html#af428b0078814d818535ccd277e2e69ff", null ],
       [ "Min_circle_2_traits_2", "classCGAL_1_1Min__circle__2__traits__2.html#ad9f44306b03a697ddb9f29ed482a7778", null ],
       [ "Min_circle_2_traits_2", "classCGAL_1_1Min__circle__2__traits__2.html#ac1ea3bf4752819b72e3c40fc115ea5a2", null ],
       [ "orientation", "classCGAL_1_1Min__circle__2__traits__2.html#aed107bf202be6c387338c08cc20d0ad1", null ]
     ] ],
-    [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html", [
+    [ "CGAL::Min_ellipse_2< Traits >", "classCGAL_1_1Min__ellipse__2.html", [
       [ "Ellipse", "classCGAL_1_1Min__ellipse__2.html#acd1b1aa7a496bc993dd231548192f1fc", null ],
       [ "Point", "classCGAL_1_1Min__ellipse__2.html#a85d7523e566c0be7444fdbc057d4ec8b", null ],
       [ "Point_iterator", "classCGAL_1_1Min__ellipse__2.html#a8179f6ba721e4fae0e56a04e08e5dd11", null ],
@@ -144,7 +144,7 @@ var group__PkgBoundingVolumesRef =
       [ "Min_ellipse_2", "classCGAL_1_1Min__ellipse__2.html#a0428f8b9a5a58ad1c16196b94262ad9a", null ],
       [ "bounded_side", "classCGAL_1_1Min__ellipse__2.html#a965651e0633d4820cd206e498ae655fc", null ],
       [ "clear", "classCGAL_1_1Min__ellipse__2.html#ae9e4a669bf02a62d491fb6c8234388d0", null ],
-      [ "ellipse", "classCGAL_1_1Min__ellipse__2.html#a7fa49674a6a731a09ac3459379bf810b", null ],
+      [ "ellipse", "classCGAL_1_1Min__ellipse__2.html#a8e409d48ee6822f036911ec4893b9b17", null ],
       [ "has_on_boundary", "classCGAL_1_1Min__ellipse__2.html#a2a47110a544ae513d3d2d0e225637705", null ],
       [ "has_on_bounded_side", "classCGAL_1_1Min__ellipse__2.html#a3992583c7aa438c5b0fb1b2753ffca98", null ],
       [ "has_on_unbounded_side", "classCGAL_1_1Min__ellipse__2.html#afd9664f3ff624fef94eab667c900d0b7", null ],
@@ -158,14 +158,14 @@ var group__PkgBoundingVolumesRef =
       [ "number_of_support_points", "classCGAL_1_1Min__ellipse__2.html#a57a229ca573b9eb958b48e580b17318a", null ],
       [ "points_begin", "classCGAL_1_1Min__ellipse__2.html#a1dddfc673f54a1b6050553999cc0a400", null ],
       [ "points_end", "classCGAL_1_1Min__ellipse__2.html#abbd618de1cd53057ab4880be7ec7f99a", null ],
-      [ "support_point", "classCGAL_1_1Min__ellipse__2.html#a1a5825a107c3df865df6afb754aca4e1", null ],
+      [ "support_point", "classCGAL_1_1Min__ellipse__2.html#a039654b38c2fa49ffb66ac6f9e9465cf", null ],
       [ "support_points_begin", "classCGAL_1_1Min__ellipse__2.html#af778c1c16dae49ad9fc01681be5b4674", null ],
       [ "support_points_end", "classCGAL_1_1Min__ellipse__2.html#ab7b13e07ab190b99fa9385c06e9d7a7b", null ],
-      [ "traits", "classCGAL_1_1Min__ellipse__2.html#a77e9d2e633013cd7b882320f29f78212", null ],
+      [ "traits", "classCGAL_1_1Min__ellipse__2.html#adfb3289a1c1204f72a590bdc6010c073", null ],
       [ "operator<<", "classCGAL_1_1Min__ellipse__2.html#af7c0fb64d240921356e6a4e818592e42", null ],
       [ "operator>>", "classCGAL_1_1Min__ellipse__2.html#a13acc6b8559f5210d49e60513eaaf7b6", null ]
     ] ],
-    [ "Min_ellipse_2_traits_2", "classCGAL_1_1Min__ellipse__2__traits__2.html", [
+    [ "CGAL::Min_ellipse_2_traits_2< K >", "classCGAL_1_1Min__ellipse__2__traits__2.html", [
       [ "Ellipse", "classCGAL_1_1Min__ellipse__2__traits__2.html#afb570df476f009372ccb7f5fd34a1cd8", null ],
       [ "Point", "classCGAL_1_1Min__ellipse__2__traits__2.html#a8735671fd45fb060496e7aafa499d489", null ],
       [ "Min_ellipse_2_traits_2", "classCGAL_1_1Min__ellipse__2__traits__2.html#a4e7c9281018670b510fb47b6860681c2", null ],
@@ -173,7 +173,7 @@ var group__PkgBoundingVolumesRef =
       [ "double_coefficients", "classCGAL_1_1Min__ellipse__2__traits__2.html#a9323f32b47a2695404057f113fd94936", null ],
       [ "is_circle", "classCGAL_1_1Min__ellipse__2__traits__2.html#a4ab1badaf8c40c2d7e98dbfb6d9af125", null ]
     ] ],
-    [ "Min_quadrilateral_default_traits_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html", [
+    [ "CGAL::Min_quadrilateral_default_traits_2< K >", "structCGAL_1_1Min__quadrilateral__default__traits__2.html", [
       [ "Area_less_parallelogram_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a9cf5438dc4616b673a7434944e8a9d7a", null ],
       [ "Area_less_rectangle_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a5abad8e2016092ac67030f518c486dc7", null ],
       [ "Compare_angle_with_x_axis_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#aedd43689dcbd935cf563fe8513a0daad", null ],
@@ -204,7 +204,7 @@ var group__PkgBoundingVolumesRef =
       [ "copy_rectangle_vertices_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a9e42464b62db36b890579422a3b0cd6d", null ],
       [ "copy_strip_lines_2", "structCGAL_1_1Min__quadrilateral__default__traits__2.html#a82711522d257e5a16086bc69d966869f", null ]
     ] ],
-    [ "Min_sphere_annulus_d_traits_2", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html", [
+    [ "CGAL::Min_sphere_annulus_d_traits_2< K, ET, NT >", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html", [
       [ "Access_coordinates_begin_d", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#abde2b2b0c54710c511cbaf924eaf2fef", null ],
       [ "Access_dimension_d", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a494549a4c89f24cfec83b0912b52815a", null ],
       [ "Construct_point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a8215d935833718ce7bf9c9e93d69ced6", null ],
@@ -220,7 +220,7 @@ var group__PkgBoundingVolumesRef =
       [ "access_dimension_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#ab9c6b4a08b0731863d87ed8309daaf1d", null ],
       [ "construct_point_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__2.html#a01a04ea4438729c7e7fc4b7f3977dc98", null ]
     ] ],
-    [ "Min_sphere_annulus_d_traits_3", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html", [
+    [ "CGAL::Min_sphere_annulus_d_traits_3< K, ET, NT >", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html", [
       [ "Access_coordinates_begin_d", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a30b15dccc6a9f2561fbcf5a0c1a915c1", null ],
       [ "Access_dimension_d", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a9014bed241c83c21cf68476770ed1183", null ],
       [ "Construct_point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a27c5cf94e0092a2092a3694533e95f0c", null ],
@@ -236,7 +236,7 @@ var group__PkgBoundingVolumesRef =
       [ "access_dimension_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a5065111938a70e7d0df6a516fa1d74e4", null ],
       [ "construct_point_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__3.html#a36d3313215951b052e34b10a5729a8f5", null ]
     ] ],
-    [ "Min_sphere_annulus_d_traits_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html", [
+    [ "CGAL::Min_sphere_annulus_d_traits_d< K, ET, NT >", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html", [
       [ "Access_coordinates_begin_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a404697a19a97ad957bae7a8dd0a10a35", null ],
       [ "Access_dimension_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a693aabf86cc46f852c565206a058ef4e", null ],
       [ "Construct_point_d", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#a60baf81455f6e0f4fcbdccbcf4855486", null ],
@@ -252,7 +252,7 @@ var group__PkgBoundingVolumesRef =
       [ "access_dimension_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#ad1f43db65695ee38409aa0fc960a6f87", null ],
       [ "construct_point_d_object", "classCGAL_1_1Min__sphere__annulus__d__traits__d.html#ae1c45fcf184cff58d90b43c4a3fe8a27", null ]
     ] ],
-    [ "Min_sphere_d", "classCGAL_1_1Min__sphere__d.html", [
+    [ "CGAL::Min_sphere_d< Traits >", "classCGAL_1_1Min__sphere__d.html", [
       [ "FT", "classCGAL_1_1Min__sphere__d.html#a388649f898d870cfe912dfe35aa5ebac", null ],
       [ "Point", "classCGAL_1_1Min__sphere__d.html#a6bde4249e0f11678a51745703fe01788", null ],
       [ "Point_iterator", "classCGAL_1_1Min__sphere__d.html#ad1816fab29ac1876f60a7b01042c79eb", null ],
@@ -261,7 +261,7 @@ var group__PkgBoundingVolumesRef =
       [ "Min_sphere_d", "classCGAL_1_1Min__sphere__d.html#ace8d13f062848145130056146d671fa2", null ],
       [ "ambient_dimension", "classCGAL_1_1Min__sphere__d.html#a62910f817822d46de39071ea8e219c2d", null ],
       [ "bounded_side", "classCGAL_1_1Min__sphere__d.html#a25787da8103c796a1c119c2994d4a15e", null ],
-      [ "center", "classCGAL_1_1Min__sphere__d.html#aea94f4c41632800e6c5ab3ed9010d22b", null ],
+      [ "center", "classCGAL_1_1Min__sphere__d.html#a7f0aa75ed38c50e93619d4459b17835c", null ],
       [ "clear", "classCGAL_1_1Min__sphere__d.html#adce1310d8a8665b58977d3225fe4a262", null ],
       [ "has_on_boundary", "classCGAL_1_1Min__sphere__d.html#adec034ebd9ae7207cc70da0bff841f4b", null ],
       [ "has_on_bounded_side", "classCGAL_1_1Min__sphere__d.html#aa36d08deb1ecdc647d4b5bcb0d76460a", null ],
@@ -279,11 +279,11 @@ var group__PkgBoundingVolumesRef =
       [ "squared_radius", "classCGAL_1_1Min__sphere__d.html#aae47567cad6991e4b340192339b424d6", null ],
       [ "support_points_begin", "classCGAL_1_1Min__sphere__d.html#a8484385e353b193ec77183b2b53243af", null ],
       [ "support_points_end", "classCGAL_1_1Min__sphere__d.html#ac98a21a97668704844ec0543b848d201", null ],
-      [ "traits", "classCGAL_1_1Min__sphere__d.html#a4467737789865cd41bd897ed23052081", null ],
+      [ "traits", "classCGAL_1_1Min__sphere__d.html#a33092b10644c7dddf15322373cd09595", null ],
       [ "operator<<", "classCGAL_1_1Min__sphere__d.html#a388d8ea8a3f91b3e9eef69f362372c13", null ],
       [ "operator>>", "classCGAL_1_1Min__sphere__d.html#a6204c32883cc3c5911eb90b928d6735f", null ]
     ] ],
-    [ "Min_sphere_of_points_d_traits_2", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html", [
+    [ "CGAL::Min_sphere_of_points_d_traits_2< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html", [
       [ "Algorithm", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a22361f8533225ecdff267449edf0e034", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a5d672099ca93a47e5722980aa9da02c4", null ],
       [ "D", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#ab2464a313c5a3407eff24d1dc9410073", null ],
@@ -295,7 +295,7 @@ var group__PkgBoundingVolumesRef =
       [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a56ff745563ec6ecfd94d712d1f86dd80", null ],
       [ "radius", "classCGAL_1_1Min__sphere__of__points__d__traits__2.html#a7e11c29e4d0c0bbe74523cf03db68ae4", null ]
     ] ],
-    [ "Min_sphere_of_points_d_traits_3", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html", [
+    [ "CGAL::Min_sphere_of_points_d_traits_3< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html", [
       [ "Algorithm", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#adcd5fd5540760777a4d1a3750e1f0194", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a49a68ce21177cc21f478b2e180df617b", null ],
       [ "D", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a563c97ffb2d321f235918bc9b51c83ff", null ],
@@ -307,7 +307,7 @@ var group__PkgBoundingVolumesRef =
       [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#a02501c0c228db573467f0db4de5a0ee6", null ],
       [ "radius", "classCGAL_1_1Min__sphere__of__points__d__traits__3.html#ac2d50529ef5913a6ffba1feca9280c95", null ]
     ] ],
-    [ "Min_sphere_of_points_d_traits_d", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html", [
+    [ "CGAL::Min_sphere_of_points_d_traits_d< K, FT, Dim, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html", [
       [ "Algorithm", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#aff88714939b9aa5ebda84835886840b5", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#af5b93f3749b8a5076058cc2c26399421", null ],
       [ "D", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#ada3cfbae652c4d9696f688d65914a260", null ],
@@ -319,7 +319,7 @@ var group__PkgBoundingVolumesRef =
       [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#a0e89943cc90d97c73887630723b7c6cb", null ],
       [ "radius", "classCGAL_1_1Min__sphere__of__points__d__traits__d.html#ae61a74d5ea8c75b0d792d396c7c90985", null ]
     ] ],
-    [ "Min_sphere_of_spheres_d", "classCGAL_1_1Min__sphere__of__spheres__d.html", [
+    [ "CGAL::Min_sphere_of_spheres_d< Traits >", "classCGAL_1_1Min__sphere__of__spheres__d.html", [
       [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d.html#af253e35b654e49e4c545dd2a0a1eb609", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d.html#a228f584194657230bff244b0700ef3e8", null ],
       [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d.html#ab2aeddc77594db89ca74d2c9266e0e04", null ],
@@ -331,7 +331,7 @@ var group__PkgBoundingVolumesRef =
       [ "center_cartesian_begin", "classCGAL_1_1Min__sphere__of__spheres__d.html#a979d76c29e9a2a5ea2fbda01cc26cb44", null ],
       [ "center_cartesian_end", "classCGAL_1_1Min__sphere__of__spheres__d.html#a7cc8d666c94bc4c5486472faacb54d6f", null ],
       [ "clear", "classCGAL_1_1Min__sphere__of__spheres__d.html#afa2734bbcfd23ed9ac4bb512fc72e295", null ],
-      [ "discriminant", "classCGAL_1_1Min__sphere__of__spheres__d.html#a0a7aed9d213bd66c8ea5bd8dded5ebfd", null ],
+      [ "discriminant", "classCGAL_1_1Min__sphere__of__spheres__d.html#ac57af1d42e76a4cb1911d2ff09447186", null ],
       [ "insert", "classCGAL_1_1Min__sphere__of__spheres__d.html#adcd37fdc4ec874d38cc5694dd64bc9cd", null ],
       [ "insert", "classCGAL_1_1Min__sphere__of__spheres__d.html#ad9f8d55ba940c8aeb59933372ecf9968", null ],
       [ "is_empty", "classCGAL_1_1Min__sphere__of__spheres__d.html#ac80672339921e1c7374557d3416c44bf", null ],
@@ -340,9 +340,9 @@ var group__PkgBoundingVolumesRef =
       [ "set", "classCGAL_1_1Min__sphere__of__spheres__d.html#a97f3b20946efc0ddee063587f4974dca", null ],
       [ "support_begin", "classCGAL_1_1Min__sphere__of__spheres__d.html#affae999e8d10145165bb425b2ab3293a", null ],
       [ "support_end", "classCGAL_1_1Min__sphere__of__spheres__d.html#af032978c5f57bbee756051cb0bf81e9d", null ],
-      [ "traits", "classCGAL_1_1Min__sphere__of__spheres__d.html#a62540aa250c67c22a3d1ec66c7efbd35", null ]
+      [ "traits", "classCGAL_1_1Min__sphere__of__spheres__d.html#ae6e369807115adb3e978162f579b0a30", null ]
     ] ],
-    [ "Min_sphere_of_spheres_d_traits_2", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html", [
+    [ "CGAL::Min_sphere_of_spheres_d_traits_2< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html", [
       [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a6c92b7fe2cb8f1bba39ef95ec879fb3b", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a101061d82e32f576a1d5f4fc1a158da0", null ],
       [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a9b41f81682208168838b63650e34f19b", null ],
@@ -354,7 +354,7 @@ var group__PkgBoundingVolumesRef =
       [ "radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#ab49792a6e80e95536932502d0d016325", null ],
       [ "D", "classCGAL_1_1Min__sphere__of__spheres__d__traits__2.html#a9795b48de19b201bce14dc76da403456", null ]
     ] ],
-    [ "Min_sphere_of_spheres_d_traits_3", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html", [
+    [ "CGAL::Min_sphere_of_spheres_d_traits_3< K, FT, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html", [
       [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#abb101ab115309601792fe22b9c39d11e", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#a88ca064b1e8369a6a503452b190cfcac", null ],
       [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#ad990e05c12488bb0e6ca4e64e3cb4ebc", null ],
@@ -366,7 +366,7 @@ var group__PkgBoundingVolumesRef =
       [ "radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#af946005502938a2216d17c5b826f748c", null ],
       [ "D", "classCGAL_1_1Min__sphere__of__spheres__d__traits__3.html#a705b61c967335cb3a186559898175655", null ]
     ] ],
-    [ "Min_sphere_of_spheres_d_traits_d", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html", [
+    [ "CGAL::Min_sphere_of_spheres_d_traits_d< K, FT, Dim, UseSqrt, Algorithm >", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html", [
       [ "Algorithm", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ac665c8509f8dd1c2074c384775919f87", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#a70b934ecfa7c1ecedfb38b002f1a29d0", null ],
       [ "FT", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ae38a2383ac72f506360b97bd50362005", null ],
@@ -378,7 +378,7 @@ var group__PkgBoundingVolumesRef =
       [ "radius", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#a9b537faddaa9a59ad1dec6329c32be33", null ],
       [ "D", "classCGAL_1_1Min__sphere__of__spheres__d__traits__d.html#ac250b867de45c8fe3111cb6e3018f301", null ]
     ] ],
-    [ "Rectangular_p_center_default_traits_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html", [
+    [ "CGAL::Rectangular_p_center_default_traits_2< K >", "classCGAL_1_1Rectangular__p__center__default__traits__2.html", [
       [ "Construct_iso_rectangle_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#ac6118ebe2a67c15b121864f54370da22", null ],
       [ "Construct_point_2_above_left_implicit_point_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#ab1a0d959ee399743bf08d8cf28f5de5a", null ],
       [ "Construct_point_2_above_right_implicit_point_2", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a94daec8e0edce9ee1d7cdfb2d519a373", null ],
@@ -403,8 +403,8 @@ var group__PkgBoundingVolumesRef =
       [ "inf_distance_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#afccd690d01b4b47136c8679c31c6d083", null ],
       [ "signed_inf_distance_2_object", "classCGAL_1_1Rectangular__p__center__default__traits__2.html#a01941caac5b00ecb76d3f474379b36b4", null ]
     ] ],
-    [ "min_parallelogram_2", "group__PkgBoundingVolumesRef.html#ga15d5706ceec6fc6fcae0b1625b6da2ac", null ],
-    [ "min_rectangle_2", "group__PkgBoundingVolumesRef.html#gadcf412afbf5ae512fc88d25d286fa3fa", null ],
-    [ "min_strip_2", "group__PkgBoundingVolumesRef.html#gafc685ec39e42e18195ca101631c61cd0", null ],
-    [ "rectangular_p_center_2", "group__PkgBoundingVolumesRef.html#ga37fae6bf8313f85322987d3f230eca53", null ]
+    [ "CGAL::min_parallelogram_2", "group__PkgBoundingVolumesRef.html#ga15d5706ceec6fc6fcae0b1625b6da2ac", null ],
+    [ "CGAL::min_rectangle_2", "group__PkgBoundingVolumesRef.html#gadcf412afbf5ae512fc88d25d286fa3fa", null ],
+    [ "CGAL::min_strip_2", "group__PkgBoundingVolumesRef.html#gafc685ec39e42e18195ca101631c61cd0", null ],
+    [ "CGAL::rectangular_p_center_2", "group__PkgBoundingVolumesRef.html#ga37fae6bf8313f85322987d3f230eca53", null ]
 ];
\ No newline at end of file
