@@ -6,7 +6,7 @@ var group__PkgHandlesAndCirculatorsRef =
     [ "Compile Time Tags", "group__PkgHandlesAndCirculatorsTags.html", "group__PkgHandlesAndCirculatorsTags" ],
     [ "Assertions", "group__PkgHandlesAndCirculatorsAssert.html", "group__PkgHandlesAndCirculatorsAssert" ],
     [ "Base Classes", "group__PkgHandlesAndCirculatorsBaseClasses.html", "group__PkgHandlesAndCirculatorsBaseClasses" ],
-    [ "Circulator_traits", "structCGAL_1_1Circulator__traits.html", [
+    [ "CGAL::Circulator_traits< C >", "structCGAL_1_1Circulator__traits.html", [
       [ "category", "structCGAL_1_1Circulator__traits.html#ab2e4d7455faba1f9691ff131f9e55122", null ],
       [ "circulator_category", "structCGAL_1_1Circulator__traits.html#ae2e6fd2d23e124a2c3969d0288d986ea", null ],
       [ "iterator_category", "structCGAL_1_1Circulator__traits.html#ae7831013cf3c859246d2d1268461f5a0", null ]
