@@ -3,6 +3,6 @@ var classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3 =
     [ "Surface_3", "classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3.html#a22d4292c94e5d011607917f82a0b30f4", null ],
     [ "Surface_3", "classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3.html#afbc001636237cd6fcedb8015078b4c1b", null ],
     [ "Surface_3", "classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3.html#a8add961f14c923d582cbdb2540fa4a57", null ],
-    [ "data", "classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3.html#a7e4dbdf29bed97fb8d35057a44349124", null ],
-    [ "set_data", "classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3.html#a4e80b5783dde8d6db3f321b3adf1ce33", null ]
+    [ "data", "classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3.html#ace0ed1aad77be9e6f67314fae83155f5", null ],
+    [ "set_env_data", "classCGAL_1_1Env__surface__data__traits__3_1_1Surface__3.html#a52d70433dfa616515be31618bd00d9b7", null ]
 ];
\ No newline at end of file
