@@ -1,11 +1,12 @@
 var examples =
 [
     [ "Generalized_map/gmap_2_moebius.cpp", "Generalized_map_2gmap_2_moebius_8cpp-example.html", null ],
+    [ "Generalized_map/gmap_3_marks.cpp", "Generalized_map_2gmap_3_marks_8cpp-example.html", null ],
+    [ "Generalized_map/gmap_3_simple_example.cpp", "Generalized_map_2gmap_3_simple_example_8cpp-example.html", null ],
+    [ "Generalized_map/gmap_3_operations.cpp", "Generalized_map_2gmap_3_operations_8cpp-example.html", null ],
+    [ "Generalized_map/gmap_4_simple_example.cpp", "Generalized_map_2gmap_4_simple_example_8cpp-example.html", null ],
+    [ "Generalized_map/gmap_3_with_colored_facets.cpp", "Generalized_map_2gmap_3_with_colored_facets_8cpp-example.html", null ],
     [ "Generalized_map/gmap_3_dynamic_onmerge.cpp", "Generalized_map_2gmap_3_dynamic_onmerge_8cpp-example.html", null ],
     [ "Generalized_map/gmap_3_index.cpp", "Generalized_map_2gmap_3_index_8cpp-example.html", null ],
-    [ "Generalized_map/gmap_3_marks.cpp", "Generalized_map_2gmap_3_marks_8cpp-example.html", null ],
-    [ "Generalized_map/gmap_3_operations.cpp", "Generalized_map_2gmap_3_operations_8cpp-example.html", null ],
-    [ "Generalized_map/gmap_3_simple_example.cpp", "Generalized_map_2gmap_3_simple_example_8cpp-example.html", null ],
-    [ "Generalized_map/gmap_3_with_colored_facets.cpp", "Generalized_map_2gmap_3_with_colored_facets_8cpp-example.html", null ],
-    [ "Generalized_map/gmap_4_simple_example.cpp", "Generalized_map_2gmap_4_simple_example_8cpp-example.html", null ]
+    [ "Generalized_map/gmap_3_insert.cpp", "Generalized_map_2gmap_3_insert_8cpp-example.html", null ]
 ];
\ No newline at end of file
