@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__in__cube__3 =
 [
     [ "difference_type", "classCGAL_1_1Random__points__in__cube__3.html#a1c7eee3320119414b47d9c8ae3e3322d", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__in__cube__3.html#a81bd69dda9b73c1c276faccb501f311d", null ],
+    [ "pointer", "classCGAL_1_1Random__points__in__cube__3.html#a9f7277c0adb278481fee29c65c655d97", null ],
+    [ "reference", "classCGAL_1_1Random__points__in__cube__3.html#aa2e347df0c62d99ccb74a2a8688b8c11", null ],
     [ "value_type", "classCGAL_1_1Random__points__in__cube__3.html#ac125bee43a091f9c52bbb6376cbb2697", null ],
-    [ "Random_points_in_cube_3", "classCGAL_1_1Random__points__in__cube__3.html#a6d882f19dd4c74a2f65e90a3f607b302", null ],
-    [ "pointer", "classCGAL_1_1Random__points__in__cube__3.html#a880ec871e5393bc5c7e9b4947bb2bcf0", null ],
-    [ "reference", "classCGAL_1_1Random__points__in__cube__3.html#ac47c329fbb6b9e08614cdf19f46bb68c", null ]
+    [ "Random_points_in_cube_3", "classCGAL_1_1Random__points__in__cube__3.html#a6d882f19dd4c74a2f65e90a3f607b302", null ]
 ];
\ No newline at end of file
