@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__in__square__2 =
 [
     [ "difference_type", "classCGAL_1_1Random__points__in__square__2.html#a6833a1546f9a668d9a3e419e1ede8685", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__in__square__2.html#a8e3eada446241a44bfdfb8fa6606a276", null ],
+    [ "pointer", "classCGAL_1_1Random__points__in__square__2.html#a4e76649e27b42d521d4b07ee9584292c", null ],
+    [ "reference", "classCGAL_1_1Random__points__in__square__2.html#a303db6f0397001d2819277fdb65cb8a4", null ],
     [ "value_type", "classCGAL_1_1Random__points__in__square__2.html#afb046c56f265c54eb45fa9867a7a229b", null ],
-    [ "Random_points_in_square_2", "classCGAL_1_1Random__points__in__square__2.html#ada581acf50d28cd3e9eb8dd8cfc7ed77", null ],
-    [ "pointer", "classCGAL_1_1Random__points__in__square__2.html#aea8f71c727444b249aded777b212e5c0", null ],
-    [ "reference", "classCGAL_1_1Random__points__in__square__2.html#a96c229d452cdfcb6007e86a571f2ac0d", null ]
+    [ "Random_points_in_square_2", "classCGAL_1_1Random__points__in__square__2.html#ada581acf50d28cd3e9eb8dd8cfc7ed77", null ]
 ];
\ No newline at end of file
