@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__in__tetrahedral__mesh__3 =
 [
     [ "difference_type", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#afa4d2401730917b03925786a4c842f40", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#abda9e1ec3fbfd6167b7ebc763dda0634", null ],
+    [ "pointer", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#a206ce0a24c775262e67af878f6d13fa0", null ],
+    [ "reference", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#afdcbe24ce4c744532e828549ceb1cc4e", null ],
     [ "value_type", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#a1de214102076ba9cb2177350122509dd", null ],
-    [ "Random_points_in_tetrahedral_mesh_3", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#ae1fed8db5b0960ddcb386d4b43ee0234", null ],
-    [ "pointer", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#a8a93fc6bdf0445b731878b8e65433514", null ],
-    [ "reference", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#a3b1c5b47b3cf601689abd7cbcc7e1336", null ]
+    [ "Random_points_in_tetrahedral_mesh_3", "classCGAL_1_1Random__points__in__tetrahedral__mesh__3.html#ae1fed8db5b0960ddcb386d4b43ee0234", null ]
 ];
\ No newline at end of file
