@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3 =
 [
     [ "difference_type", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a64c006961a2921bbca3b461fbde284db", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a0998e07dc3d950f6f8b3168141d94a4e", null ],
+    [ "pointer", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a57f8943da2b603909b482906b7ba9072", null ],
+    [ "reference", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a4dcd7ee749b2f766c34b4fdbb6cec8c7", null ],
     [ "value_type", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a9653ad46ee26ccb6a9ae54ea9c228e84", null ],
-    [ "Random_points_in_tetrahedral_mesh_boundary_3", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a95583aaf3b67be46a4ac6c583ca9fcfd", null ],
-    [ "pointer", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a5a52db2359349b36cc99ed3a96e8cfbc", null ],
-    [ "reference", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#af29d96fcc2934f402f3099d1b55562e5", null ]
+    [ "Random_points_in_tetrahedral_mesh_boundary_3", "classCGAL_1_1Random__points__in__tetrahedral__mesh__boundary__3.html#a95583aaf3b67be46a4ac6c583ca9fcfd", null ]
 ];
\ No newline at end of file
