@@ -2,9 +2,9 @@ var classCGAL_1_1Random__points__in__tetrahedron__3 =
 [
     [ "difference_type", "classCGAL_1_1Random__points__in__tetrahedron__3.html#a6f9f0bad244768fe18d5d6784f37ae11", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__in__tetrahedron__3.html#a2455052cb0cfd337c6eec42d75bbb7b5", null ],
+    [ "pointer", "classCGAL_1_1Random__points__in__tetrahedron__3.html#ad141679005b08b2e2edc20913de25c78", null ],
+    [ "reference", "classCGAL_1_1Random__points__in__tetrahedron__3.html#ac6553c40c3bc7f41b69b0cf767de5fd6", null ],
     [ "value_type", "classCGAL_1_1Random__points__in__tetrahedron__3.html#a0f296b3bc118f48c3a642e080fb90e32", null ],
     [ "Random_points_in_tetrahedron_3", "classCGAL_1_1Random__points__in__tetrahedron__3.html#aef047844432b4747836beb1f1dade2f5", null ],
-    [ "Random_points_in_tetrahedron_3", "classCGAL_1_1Random__points__in__tetrahedron__3.html#ab680dbc31ca4b302b8f2db95dc724e6a", null ],
-    [ "pointer", "classCGAL_1_1Random__points__in__tetrahedron__3.html#afc722e026da5b27954da3d4b3ec65ac7", null ],
-    [ "reference", "classCGAL_1_1Random__points__in__tetrahedron__3.html#a28f18f0a135913e19028f0d0218622d9", null ]
+    [ "Random_points_in_tetrahedron_3", "classCGAL_1_1Random__points__in__tetrahedron__3.html#ab680dbc31ca4b302b8f2db95dc724e6a", null ]
 ];
\ No newline at end of file
