@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__in__triangle__mesh__2 =
 [
     [ "difference_type", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#a46ed305b84f04424ebe1513a92798df8", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#a86137e00506d96a522eef9f8f8c36dd8", null ],
+    [ "pointer", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#ad7986501c463f8bfe0f1f07757fc9bd3", null ],
+    [ "reference", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#ab431e97ee8e81aacf7b4e1051530df98", null ],
     [ "value_type", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#a1befec72df6a31897ff49dd8d044afb0", null ],
-    [ "Random_points_in_triangle_mesh_2", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#ac2a9a7c28184898b4f8931510b5315d2", null ],
-    [ "pointer", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#afe70ecd8054ec216556cee0045cbfca6", null ],
-    [ "reference", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#aa1ccdc1669fffb68e21ff16b174cf426", null ]
+    [ "Random_points_in_triangle_mesh_2", "classCGAL_1_1Random__points__in__triangle__mesh__2.html#ac2a9a7c28184898b4f8931510b5315d2", null ]
 ];
\ No newline at end of file
