@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__on__segment__3 =
 [
     [ "difference_type", "classCGAL_1_1Random__points__on__segment__3.html#aebaabbe7599d9d57288c2cbea12b60af", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__on__segment__3.html#a114c946704a86fa5b0c3901e284918b0", null ],
+    [ "pointer", "classCGAL_1_1Random__points__on__segment__3.html#aca84b5c3ef9161732d2c1fec820d733f", null ],
+    [ "reference", "classCGAL_1_1Random__points__on__segment__3.html#acba5cfd1d80785daeefb35c1e57619dc", null ],
     [ "value_type", "classCGAL_1_1Random__points__on__segment__3.html#afc766c3006f17b8241a3cc152eadd9db", null ],
-    [ "Random_points_on_segment_3", "classCGAL_1_1Random__points__on__segment__3.html#af01f3833c8dc78b4753882b15e6d137c", null ],
-    [ "pointer", "classCGAL_1_1Random__points__on__segment__3.html#ad9a02671ba5f76fe94e61113e04b79f8", null ],
-    [ "reference", "classCGAL_1_1Random__points__on__segment__3.html#abc1c18c0f3fea1e384a43938c5789e02", null ]
+    [ "Random_points_on_segment_3", "classCGAL_1_1Random__points__on__segment__3.html#af01f3833c8dc78b4753882b15e6d137c", null ]
 ];
\ No newline at end of file
