@@ -2,8 +2,8 @@ var structCGAL_1_1Random__points__in__triangles__3 =
 [
     [ "difference_type", "structCGAL_1_1Random__points__in__triangles__3.html#a288ad1f8515af53b207cfea62ac18a38", null ],
     [ "iterator_category", "structCGAL_1_1Random__points__in__triangles__3.html#a2af465eee318945c6d69fd1f3b3dac05", null ],
+    [ "pointer", "structCGAL_1_1Random__points__in__triangles__3.html#ab69c0c98e9099c51bd932f371022bd01", null ],
+    [ "reference", "structCGAL_1_1Random__points__in__triangles__3.html#adc2453cbce747503fc2cf7e3c2bbfc5b", null ],
     [ "value_type", "structCGAL_1_1Random__points__in__triangles__3.html#ad53112155d61868d0c285c6666144f63", null ],
-    [ "Random_points_in_triangles_3", "structCGAL_1_1Random__points__in__triangles__3.html#ae619fe00d9cdaf0d9376e9a418727b49", null ],
-    [ "pointer", "structCGAL_1_1Random__points__in__triangles__3.html#a006e8af99e639659a5a9206fee04a7da", null ],
-    [ "reference", "structCGAL_1_1Random__points__in__triangles__3.html#ae01a3bfe84a79c215a29abcd509ffdde", null ]
+    [ "Random_points_in_triangles_3", "structCGAL_1_1Random__points__in__triangles__3.html#ae619fe00d9cdaf0d9376e9a418727b49", null ]
 ];
\ No newline at end of file
