@@ -1,12 +1,12 @@
 var examples =
 [
     [ "Interpolation/interpolation_2.cpp", "Interpolation_2interpolation_2_8cpp-example.html", null ],
-    [ "Interpolation/linear_interpolation_2.cpp", "Interpolation_2linear_interpolation_2_8cpp-example.html", null ],
-    [ "Interpolation/linear_interpolation_of_vector_3.cpp", "Interpolation_2linear_interpolation_of_vector_3_8cpp-example.html", null ],
     [ "Interpolation/nn_coordinates_2.cpp", "Interpolation_2nn_coordinates_2_8cpp-example.html", null ],
     [ "Interpolation/nn_coordinates_with_info_2.cpp", "Interpolation_2nn_coordinates_with_info_2_8cpp-example.html", null ],
     [ "Interpolation/rn_coordinates_2.cpp", "Interpolation_2rn_coordinates_2_8cpp-example.html", null ],
+    [ "Interpolation/surface_neighbor_coordinates_3.cpp", "Interpolation_2surface_neighbor_coordinates_3_8cpp-example.html", null ],
+    [ "Interpolation/linear_interpolation_2.cpp", "Interpolation_2linear_interpolation_2_8cpp-example.html", null ],
+    [ "Interpolation/linear_interpolation_of_vector_3.cpp", "Interpolation_2linear_interpolation_of_vector_3_8cpp-example.html", null ],
     [ "Interpolation/sibson_interpolation_2.cpp", "Interpolation_2sibson_interpolation_2_8cpp-example.html", null ],
-    [ "Interpolation/sibson_interpolation_vertex_with_info_2.cpp", "Interpolation_2sibson_interpolation_vertex_with_info_2_8cpp-example.html", null ],
-    [ "Interpolation/surface_neighbor_coordinates_3.cpp", "Interpolation_2surface_neighbor_coordinates_3_8cpp-example.html", null ]
+    [ "Interpolation/sibson_interpolation_vertex_with_info_2.cpp", "Interpolation_2sibson_interpolation_vertex_with_info_2_8cpp-example.html", null ]
 ];
\ No newline at end of file
