@@ -4,10 +4,10 @@ var group__PkgInterpolation2Ref =
     [ "Interpolation Functions", "group__PkgInterpolation2Interpolation.html", "group__PkgInterpolation2Interpolation" ],
     [ "Natural Neighbor Coordinate Computation", "group__PkgInterpolation2NatNeighbor.html", "group__PkgInterpolation2NatNeighbor" ],
     [ "Surface Neighbor and Surface Neighbor Coordinate Computation", "group__PkgInterpolation2SurfaceNeighbor.html", "group__PkgInterpolation2SurfaceNeighbor" ],
-    [ "Data_access", "structCGAL_1_1Data__access.html", [
+    [ "CGAL::Data_access< Map >", "structCGAL_1_1Data__access.html", [
       [ "Data_type", "structCGAL_1_1Data__access.html#a76236b77a209de3d6ddec9fa64b786a9", null ],
       [ "Key_type", "structCGAL_1_1Data__access.html#aafdf39f2ee356305f7938f9ff3bdabee", null ],
       [ "Data_access", "structCGAL_1_1Data__access.html#a148cb522f2beb240d4e914e7f8fd72c5", null ],
-      [ "operator()", "structCGAL_1_1Data__access.html#aa259af1f489bbd39ba7edcf3b66a158e", null ]
+      [ "operator()", "structCGAL_1_1Data__access.html#a393635849a9062855f2ffdd8fa14f2de", null ]
     ] ]
 ];
\ No newline at end of file
