@@ -307,5 +307,6 @@ var group__PkgKernel23Concepts =
       [ "Weighted_point_3", "classKernel.html#a9048cf2dfda25db2f1bcd7f66b5585b1", null ],
       [ "construct_vector_2_object", "classKernel.html#a82111132db3c8afe8e4a87ce5cb87b9e", null ],
       [ "Has_filtered_predicates", "classKernel.html#aa0116f436c29a44078471dcf595a37d6", null ]
-    ] ]
+    ] ],
+    [ "ProjectionTraitsGeometricTraits_3", "classProjectionTraitsGeometricTraits__3.html", null ]
 ];
\ No newline at end of file
