@@ -1,5 +1,7 @@
 var NAVTREEINDEX4 =
 {
+"classKernel_1_1Angle__3.html#a8f9c12ba6e2210f50fb6a192df9e3af4":[1,0,0,1,1,3],
+"classKernel_1_1Angle__3.html#af32f055dda7e3af1de26a70b7d5d9fb2":[1,0,0,1,1,1],
 "classKernel_1_1AreOrderedAlongLine__2.html":[1,0,0,1,2],
 "classKernel_1_1AreOrderedAlongLine__2.html#ab5f06b9d09599dc79576d069ecd4cf2c":[1,0,0,1,2,0],
 "classKernel_1_1AreOrderedAlongLine__3.html":[1,0,0,1,3],
@@ -23,12 +25,12 @@ var NAVTREEINDEX4 =
 "classKernel_1_1Assign__3.html#a36f27d9221caa056e6c28eae475ef3e0":[1,0,0,1,9,0],
 "classKernel_1_1BoundedSide__2.html":[1,0,0,1,10],
 "classKernel_1_1BoundedSide__2.html#a086badcc69e0d154eb32cf8bf619b6e8":[1,0,0,1,10,0],
-"classKernel_1_1BoundedSide__2.html#a5465e99a2054d84b1c3f2fded26ea178":[1,0,0,1,10,2],
-"classKernel_1_1BoundedSide__2.html#ab4726672aa5ce591f4ae9f0ac6103a5a":[1,0,0,1,10,1],
+"classKernel_1_1BoundedSide__2.html#a5465e99a2054d84b1c3f2fded26ea178":[1,0,0,1,10,1],
+"classKernel_1_1BoundedSide__2.html#ab4726672aa5ce591f4ae9f0ac6103a5a":[1,0,0,1,10,2],
 "classKernel_1_1BoundedSide__3.html":[1,0,0,1,11],
-"classKernel_1_1BoundedSide__3.html#aa310226fbe23ec6520c257038a8007c2":[1,0,0,1,11,1],
-"classKernel_1_1BoundedSide__3.html#ad8d55c8294d3e4df59c4189d85ab7a89":[1,0,0,1,11,2],
-"classKernel_1_1BoundedSide__3.html#adb68f9302e4e28904c15abda4c8b45e7":[1,0,0,1,11,0],
+"classKernel_1_1BoundedSide__3.html#aa310226fbe23ec6520c257038a8007c2":[1,0,0,1,11,2],
+"classKernel_1_1BoundedSide__3.html#ad8d55c8294d3e4df59c4189d85ab7a89":[1,0,0,1,11,0],
+"classKernel_1_1BoundedSide__3.html#adb68f9302e4e28904c15abda4c8b45e7":[1,0,0,1,11,1],
 "classKernel_1_1CartesianConstIterator__2.html":[1,0,0,1,12],
 "classKernel_1_1CartesianConstIterator__3.html":[1,0,0,1,13],
 "classKernel_1_1Circle__2.html":[1,0,0,0,0],
@@ -51,6 +53,8 @@ var NAVTREEINDEX4 =
 "classKernel_1_1CompareAngleWithXAxis__2.html":[1,0,0,1,21],
 "classKernel_1_1CompareAngleWithXAxis__2.html#ac59c23215bcbba1a45e947c611ce7f35":[1,0,0,1,21,0],
 "classKernel_1_1CompareAngle__3.html":[1,0,0,1,22],
+"classKernel_1_1CompareAngle__3.html#a8d9db055c3a7eedb34b1f27d4eac6a6d":[1,0,0,1,22,2],
+"classKernel_1_1CompareAngle__3.html#a909b74740ed5d19e1e7e2e2d0ea113f9":[1,0,0,1,22,1],
 "classKernel_1_1CompareAngle__3.html#ab25a6d5d07f50b09b8ef46b4ef114422":[1,0,0,1,22,0],
 "classKernel_1_1CompareDihedralAngle__3.html":[1,0,0,1,23],
 "classKernel_1_1CompareDihedralAngle__3.html#a1309d6f4fc962b410eff4d06ea9cce02":[1,0,0,1,23,1],
@@ -68,12 +72,12 @@ var NAVTREEINDEX4 =
 "classKernel_1_1ComparePowerDistance__3.html":[1,0,0,1,27],
 "classKernel_1_1ComparePowerDistance__3.html#a4c74dd7e4581caefd03e3f3efbce4988":[1,0,0,1,27,0],
 "classKernel_1_1CompareSignedDistanceToLine__2.html":[1,0,0,1,28],
-"classKernel_1_1CompareSignedDistanceToLine__2.html#a06ae3a7d6fe36e30138952d1529e61de":[1,0,0,1,28,1],
-"classKernel_1_1CompareSignedDistanceToLine__2.html#a2700c56d7f2be4346a01c3a932b93dd3":[1,0,0,1,28,0],
+"classKernel_1_1CompareSignedDistanceToLine__2.html#a06ae3a7d6fe36e30138952d1529e61de":[1,0,0,1,28,0],
+"classKernel_1_1CompareSignedDistanceToLine__2.html#a2700c56d7f2be4346a01c3a932b93dd3":[1,0,0,1,28,1],
 "classKernel_1_1CompareSlope__2.html":[1,0,0,1,29],
-"classKernel_1_1CompareSlope__2.html#a31392050cebd89f10f1c8fb33ec290ab":[1,0,0,1,29,1],
+"classKernel_1_1CompareSlope__2.html#a31392050cebd89f10f1c8fb33ec290ab":[1,0,0,1,29,2],
 "classKernel_1_1CompareSlope__2.html#ad7dc0c96020253fae931f3235c018bd0":[1,0,0,1,29,0],
-"classKernel_1_1CompareSlope__2.html#af2855a74b3500a2b16ecd76f516a034d":[1,0,0,1,29,2],
+"classKernel_1_1CompareSlope__2.html#af2855a74b3500a2b16ecd76f516a034d":[1,0,0,1,29,1],
 "classKernel_1_1CompareSlope__3.html":[1,0,0,1,30],
 "classKernel_1_1CompareSlope__3.html#a1c974113436dfe09aabcbc03ae1f65e0":[1,0,0,1,30,0],
 "classKernel_1_1CompareSquaredDistance__2.html":[1,0,0,1,31],
@@ -86,15 +90,15 @@ var NAVTREEINDEX4 =
 "classKernel_1_1CompareSquaredRadius__3.html#a9eab8876a09b1c64d00fcbfc4cb267d7":[1,0,0,1,33,2],
 "classKernel_1_1CompareSquaredRadius__3.html#aa91cbf2115e8791f3b03407558f894ef":[1,0,0,1,33,0],
 "classKernel_1_1CompareWeightedSquaredRadius__3.html":[1,0,0,1,34],
-"classKernel_1_1CompareWeightedSquaredRadius__3.html#a0aaba811f933c5881a7be7ccacb22a3f":[1,0,0,1,34,3],
-"classKernel_1_1CompareWeightedSquaredRadius__3.html#a361736e136fdbd4f607b2d8210044674":[1,0,0,1,34,1],
-"classKernel_1_1CompareWeightedSquaredRadius__3.html#aaaf829606929899bdaac2c18692f6358":[1,0,0,1,34,0],
-"classKernel_1_1CompareWeightedSquaredRadius__3.html#ab09a7575da7a5ce27c9a12852eb84aff":[1,0,0,1,34,2],
+"classKernel_1_1CompareWeightedSquaredRadius__3.html#a0aaba811f933c5881a7be7ccacb22a3f":[1,0,0,1,34,0],
+"classKernel_1_1CompareWeightedSquaredRadius__3.html#a361736e136fdbd4f607b2d8210044674":[1,0,0,1,34,2],
+"classKernel_1_1CompareWeightedSquaredRadius__3.html#aaaf829606929899bdaac2c18692f6358":[1,0,0,1,34,3],
+"classKernel_1_1CompareWeightedSquaredRadius__3.html#ab09a7575da7a5ce27c9a12852eb84aff":[1,0,0,1,34,1],
 "classKernel_1_1CompareXAtY__2.html":[1,0,0,1,35],
-"classKernel_1_1CompareXAtY__2.html#a447c19283a0027dbeaac344ca48bdada":[1,0,0,1,35,1],
-"classKernel_1_1CompareXAtY__2.html#a6c86f55ac44f50d0ec13e7ad800c0339":[1,0,0,1,35,2],
-"classKernel_1_1CompareXAtY__2.html#a79f920422213b9addce46f41e8963b3c":[1,0,0,1,35,3],
-"classKernel_1_1CompareXAtY__2.html#adc4a95f961de5558931371bb1fc422b4":[1,0,0,1,35,0],
+"classKernel_1_1CompareXAtY__2.html#a447c19283a0027dbeaac344ca48bdada":[1,0,0,1,35,3],
+"classKernel_1_1CompareXAtY__2.html#a6c86f55ac44f50d0ec13e7ad800c0339":[1,0,0,1,35,0],
+"classKernel_1_1CompareXAtY__2.html#a79f920422213b9addce46f41e8963b3c":[1,0,0,1,35,1],
+"classKernel_1_1CompareXAtY__2.html#adc4a95f961de5558931371bb1fc422b4":[1,0,0,1,35,2],
 "classKernel_1_1CompareXYZ__3.html":[1,0,0,1,36],
 "classKernel_1_1CompareXYZ__3.html#a0043bb3ba9b29cf9948e051f5698f39c":[1,0,0,1,36,0],
 "classKernel_1_1CompareXY__2.html":[1,0,0,1,37],
@@ -102,26 +106,26 @@ var NAVTREEINDEX4 =
 "classKernel_1_1CompareXY__3.html":[1,0,0,1,38],
 "classKernel_1_1CompareXY__3.html#a19b0a6c060f90110611385255b4471a9":[1,0,0,1,38,0],
 "classKernel_1_1CompareX__2.html":[1,0,0,1,39],
-"classKernel_1_1CompareX__2.html#a07127b3d58bd9453033b4a4abb004bbb":[1,0,0,1,39,0],
-"classKernel_1_1CompareX__2.html#a4d8b68d2337e6d8c3c812d64f7e4474c":[1,0,0,1,39,3],
-"classKernel_1_1CompareX__2.html#a54794a38c701fe6931afd42919df0334":[1,0,0,1,39,2],
-"classKernel_1_1CompareX__2.html#a99377411446d95f821a48c29e4da8207":[1,0,0,1,39,1],
+"classKernel_1_1CompareX__2.html#a07127b3d58bd9453033b4a4abb004bbb":[1,0,0,1,39,3],
+"classKernel_1_1CompareX__2.html#a4d8b68d2337e6d8c3c812d64f7e4474c":[1,0,0,1,39,1],
+"classKernel_1_1CompareX__2.html#a54794a38c701fe6931afd42919df0334":[1,0,0,1,39,0],
+"classKernel_1_1CompareX__2.html#a99377411446d95f821a48c29e4da8207":[1,0,0,1,39,2],
 "classKernel_1_1CompareX__3.html":[1,0,0,1,40],
 "classKernel_1_1CompareX__3.html#a2e0f86874f36982ca14dcec4489c8395":[1,0,0,1,40,0],
 "classKernel_1_1CompareYAtX__2.html":[1,0,0,1,41],
-"classKernel_1_1CompareYAtX__2.html#a18c0ef789b19738972dd0bac6d039bbb":[1,0,0,1,41,0],
-"classKernel_1_1CompareYAtX__2.html#a27b7944ceab26bf24186e5bb1a808d47":[1,0,0,1,41,3],
-"classKernel_1_1CompareYAtX__2.html#a63ab598617c0997eaf50e615c6218f33":[1,0,0,1,41,1],
-"classKernel_1_1CompareYAtX__2.html#a9ead49e798d4a802e30a6374db304439":[1,0,0,1,41,2],
+"classKernel_1_1CompareYAtX__2.html#a18c0ef789b19738972dd0bac6d039bbb":[1,0,0,1,41,2],
+"classKernel_1_1CompareYAtX__2.html#a27b7944ceab26bf24186e5bb1a808d47":[1,0,0,1,41,1],
+"classKernel_1_1CompareYAtX__2.html#a63ab598617c0997eaf50e615c6218f33":[1,0,0,1,41,3],
+"classKernel_1_1CompareYAtX__2.html#a9ead49e798d4a802e30a6374db304439":[1,0,0,1,41,0],
 "classKernel_1_1CompareYAtX__2.html#aec05d3911f4f01cd8c52765b7f4d597d":[1,0,0,1,41,5],
 "classKernel_1_1CompareYAtX__2.html#aee5b8d6c0f38a7326eb3ee7a5ad0f996":[1,0,0,1,41,4],
 "classKernel_1_1CompareYX__2.html":[1,0,0,1,42],
 "classKernel_1_1CompareYX__2.html#a51a00839fdb5fa76bede856f8ba46e4b":[1,0,0,1,42,0],
 "classKernel_1_1CompareY__2.html":[1,0,0,1,43],
-"classKernel_1_1CompareY__2.html#a674c4fc049e3c2122ccc3c365c55c268":[1,0,0,1,43,0],
-"classKernel_1_1CompareY__2.html#a762d1bf35a3d3df34dc4c5814acbed82":[1,0,0,1,43,3],
-"classKernel_1_1CompareY__2.html#a9d501abc49e20cc3cabee87c48bd2952":[1,0,0,1,43,2],
-"classKernel_1_1CompareY__2.html#afc4684a4a0cea42e4604e34394232397":[1,0,0,1,43,1],
+"classKernel_1_1CompareY__2.html#a674c4fc049e3c2122ccc3c365c55c268":[1,0,0,1,43,3],
+"classKernel_1_1CompareY__2.html#a762d1bf35a3d3df34dc4c5814acbed82":[1,0,0,1,43,1],
+"classKernel_1_1CompareY__2.html#a9d501abc49e20cc3cabee87c48bd2952":[1,0,0,1,43,0],
+"classKernel_1_1CompareY__2.html#afc4684a4a0cea42e4604e34394232397":[1,0,0,1,43,2],
 "classKernel_1_1CompareY__3.html":[1,0,0,1,44],
 "classKernel_1_1CompareY__3.html#ab7f74a7c6afbeec8f756dba5134e8222":[1,0,0,1,44,0],
 "classKernel_1_1CompareZ__3.html":[1,0,0,1,45],
@@ -131,8 +135,8 @@ var NAVTREEINDEX4 =
 "classKernel_1_1ComputeA__3.html":[1,0,0,1,47],
 "classKernel_1_1ComputeA__3.html#a6cf15c0877eb947af1c99c8a1a58d9c9":[1,0,0,1,47,0],
 "classKernel_1_1ComputeApproximateAngle__3.html":[1,0,0,1,49],
-"classKernel_1_1ComputeApproximateAngle__3.html#a105dfa2cec87896ff870ca8e7f8ecd54":[1,0,0,1,49,0],
-"classKernel_1_1ComputeApproximateAngle__3.html#a493135c37d1480cfcb80e5ebb46f61f9":[1,0,0,1,49,1],
+"classKernel_1_1ComputeApproximateAngle__3.html#a105dfa2cec87896ff870ca8e7f8ecd54":[1,0,0,1,49,1],
+"classKernel_1_1ComputeApproximateAngle__3.html#a493135c37d1480cfcb80e5ebb46f61f9":[1,0,0,1,49,0],
 "classKernel_1_1ComputeApproximateArea__3.html":[1,0,0,1,48],
 "classKernel_1_1ComputeApproximateArea__3.html#a587bcaaac0d89c7ad6f6ba806a24b1c1":[1,0,0,1,48,0],
 "classKernel_1_1ComputeApproximateDihedralAngle__3.html":[1,0,0,1,50],
@@ -142,12 +146,12 @@ var NAVTREEINDEX4 =
 "classKernel_1_1ComputeAreaDividedByPi__3.html":[1,0,0,1,52],
 "classKernel_1_1ComputeAreaDividedByPi__3.html#ade0ff58bb2135c61713b22f4ef29a38a":[1,0,0,1,52,0],
 "classKernel_1_1ComputeArea__2.html":[1,0,0,1,53],
-"classKernel_1_1ComputeArea__2.html#aa975e6931b54650389c60279a0b776e0":[1,0,0,1,53,0],
-"classKernel_1_1ComputeArea__2.html#ac9805310672bae715b5af725de2e7f22":[1,0,0,1,53,1],
+"classKernel_1_1ComputeArea__2.html#aa975e6931b54650389c60279a0b776e0":[1,0,0,1,53,1],
+"classKernel_1_1ComputeArea__2.html#ac9805310672bae715b5af725de2e7f22":[1,0,0,1,53,0],
 "classKernel_1_1ComputeArea__2.html#ad6e5e07e2538ec6f6ef11bf3f0f34f47":[1,0,0,1,53,2],
 "classKernel_1_1ComputeArea__3.html":[1,0,0,1,54],
-"classKernel_1_1ComputeArea__3.html#a22596084ab39cf5c7c67024d1fb9aec9":[1,0,0,1,54,1],
-"classKernel_1_1ComputeArea__3.html#ab69f07bfd58f02c5a6ae84b52d6d9b8f":[1,0,0,1,54,0],
+"classKernel_1_1ComputeArea__3.html#a22596084ab39cf5c7c67024d1fb9aec9":[1,0,0,1,54,0],
+"classKernel_1_1ComputeArea__3.html#ab69f07bfd58f02c5a6ae84b52d6d9b8f":[1,0,0,1,54,1],
 "classKernel_1_1ComputeB__2.html":[1,0,0,1,55],
 "classKernel_1_1ComputeB__2.html#aa2aee035eb9f0d31a8d2cb6284147592":[1,0,0,1,55,0],
 "classKernel_1_1ComputeB__3.html":[1,0,0,1,56],
@@ -208,8 +212,8 @@ var NAVTREEINDEX4 =
 "classKernel_1_1ComputeScalarProduct__3.html":[1,0,0,1,80],
 "classKernel_1_1ComputeScalarProduct__3.html#a817539049318ed24cb61928ce01012e7":[1,0,0,1,80,0],
 "classKernel_1_1ComputeSquaredArea__3.html":[1,0,0,1,81],
-"classKernel_1_1ComputeSquaredArea__3.html#ae16ed1e2e12662ba85f00e92cc4a6029":[1,0,0,1,81,0],
-"classKernel_1_1ComputeSquaredArea__3.html#aec0b63518de63cb51fdb3bdb49279227":[1,0,0,1,81,1],
+"classKernel_1_1ComputeSquaredArea__3.html#ae16ed1e2e12662ba85f00e92cc4a6029":[1,0,0,1,81,1],
+"classKernel_1_1ComputeSquaredArea__3.html#aec0b63518de63cb51fdb3bdb49279227":[1,0,0,1,81,0],
 "classKernel_1_1ComputeSquaredDistance__2.html":[1,0,0,1,82],
 "classKernel_1_1ComputeSquaredDistance__2.html#ae451eda5afcef71efcb128c9b978dcf5":[1,0,0,1,82,0],
 "classKernel_1_1ComputeSquaredDistance__3.html":[1,0,0,1,83],
@@ -217,37 +221,33 @@ var NAVTREEINDEX4 =
 "classKernel_1_1ComputeSquaredLengthDividedByPiSquare__3.html":[1,0,0,1,84],
 "classKernel_1_1ComputeSquaredLengthDividedByPiSquare__3.html#a09674ab2d2fecca66ca09751e17d0df2":[1,0,0,1,84,0],
 "classKernel_1_1ComputeSquaredLength__2.html":[1,0,0,1,85],
-"classKernel_1_1ComputeSquaredLength__2.html#a2ea5af9fc98d16f993c93be6a655dddb":[1,0,0,1,85,1],
-"classKernel_1_1ComputeSquaredLength__2.html#ad8f0b591f9181f2f4d03db7de049b28a":[1,0,0,1,85,0],
+"classKernel_1_1ComputeSquaredLength__2.html#a2ea5af9fc98d16f993c93be6a655dddb":[1,0,0,1,85,0],
+"classKernel_1_1ComputeSquaredLength__2.html#ad8f0b591f9181f2f4d03db7de049b28a":[1,0,0,1,85,1],
 "classKernel_1_1ComputeSquaredLength__3.html":[1,0,0,1,86],
-"classKernel_1_1ComputeSquaredLength__3.html#a98b5f34095316f4062096af83edb5e5b":[1,0,0,1,86,0],
-"classKernel_1_1ComputeSquaredLength__3.html#aceab22457752ff8df3fd7d09b13b7c31":[1,0,0,1,86,1],
+"classKernel_1_1ComputeSquaredLength__3.html#a98b5f34095316f4062096af83edb5e5b":[1,0,0,1,86,1],
+"classKernel_1_1ComputeSquaredLength__3.html#aceab22457752ff8df3fd7d09b13b7c31":[1,0,0,1,86,0],
 "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html":[1,0,0,1,89],
-"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#a31f5c389188861678c9d89281c7d4c59":[1,0,0,1,89,0],
+"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#a31f5c389188861678c9d89281c7d4c59":[1,0,0,1,89,2],
 "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#a94466bb8c2dfe149e0c22514bb9824ea":[1,0,0,1,89,1],
-"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#ad3ddce1b9ddebebd000380137a6c02ad":[1,0,0,1,89,2],
+"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#ad3ddce1b9ddebebd000380137a6c02ad":[1,0,0,1,89,0],
 "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html":[1,0,0,1,90],
-"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a53cf045adf5a892d16fa20348f71a14a":[1,0,0,1,90,2],
-"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a5f693db27e0c576b4c4e3e204c956f62":[1,0,0,1,90,3],
-"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a949acfc065c474afdf964be5cfcc9a6f":[1,0,0,1,90,0],
-"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a9ad9adc320f4a4d24337bcb081f0eec2":[1,0,0,1,90,1],
+"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a53cf045adf5a892d16fa20348f71a14a":[1,0,0,1,90,1],
+"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a5f693db27e0c576b4c4e3e204c956f62":[1,0,0,1,90,0],
+"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a949acfc065c474afdf964be5cfcc9a6f":[1,0,0,1,90,3],
+"classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a9ad9adc320f4a4d24337bcb081f0eec2":[1,0,0,1,90,2],
 "classKernel_1_1ComputeSquaredRadius__2.html":[1,0,0,1,87],
-"classKernel_1_1ComputeSquaredRadius__2.html#a30731ea8f3b8438e6a0b772a3aa30bfa":[1,0,0,1,87,1],
+"classKernel_1_1ComputeSquaredRadius__2.html#a30731ea8f3b8438e6a0b772a3aa30bfa":[1,0,0,1,87,3],
 "classKernel_1_1ComputeSquaredRadius__2.html#a4285a35d2bc59fc497faf77405202faa":[1,0,0,1,87,0],
 "classKernel_1_1ComputeSquaredRadius__2.html#a76215f7d5a6da13200dca4b3daa3fee1":[1,0,0,1,87,2],
-"classKernel_1_1ComputeSquaredRadius__2.html#af65b0eea28e6c45a64501db4565c361c":[1,0,0,1,87,3],
+"classKernel_1_1ComputeSquaredRadius__2.html#af65b0eea28e6c45a64501db4565c361c":[1,0,0,1,87,1],
 "classKernel_1_1ComputeSquaredRadius__3.html":[1,0,0,1,88],
-"classKernel_1_1ComputeSquaredRadius__3.html#a248284447edc1be233839a8f70379f51":[1,0,0,1,88,4],
-"classKernel_1_1ComputeSquaredRadius__3.html#a284c3c3b0d66abe1585a6b6093c42e7c":[1,0,0,1,88,2],
+"classKernel_1_1ComputeSquaredRadius__3.html#a248284447edc1be233839a8f70379f51":[1,0,0,1,88,2],
+"classKernel_1_1ComputeSquaredRadius__3.html#a284c3c3b0d66abe1585a6b6093c42e7c":[1,0,0,1,88,4],
 "classKernel_1_1ComputeSquaredRadius__3.html#abdc899e5baaa377b8fb7c66af26597bc":[1,0,0,1,88,3],
-"classKernel_1_1ComputeSquaredRadius__3.html#ac605cadaafe388c7ee0399bdd05c5cfd":[1,0,0,1,88,0],
-"classKernel_1_1ComputeSquaredRadius__3.html#ad4edaefd24ec9dad1eb2cc23bb0e8df3":[1,0,0,1,88,1],
-"classKernel_1_1ComputeSquaredRadius__3.html#add3dc17f5adfb4737e68887a4201d404":[1,0,0,1,88,5],
+"classKernel_1_1ComputeSquaredRadius__3.html#ac605cadaafe388c7ee0399bdd05c5cfd":[1,0,0,1,88,5],
+"classKernel_1_1ComputeSquaredRadius__3.html#ad4edaefd24ec9dad1eb2cc23bb0e8df3":[1,0,0,1,88,0],
+"classKernel_1_1ComputeSquaredRadius__3.html#add3dc17f5adfb4737e68887a4201d404":[1,0,0,1,88,1],
 "classKernel_1_1ComputeVolume__3.html":[1,0,0,1,91],
-"classKernel_1_1ComputeVolume__3.html#a138e1f41d22655f052e249ca415e3418":[1,0,0,1,91,2],
-"classKernel_1_1ComputeVolume__3.html#a617d129f99def4c454ae94b475cf6e81":[1,0,0,1,91,1],
-"classKernel_1_1ComputeVolume__3.html#a74e33e215c888bf11f5fbe40241ac831":[1,0,0,1,91,0],
-"classKernel_1_1ComputeWeight__2.html":[1,0,0,1,92],
-"classKernel_1_1ComputeWeight__2.html#a98da75c6327155024c533907e7af0961":[1,0,0,1,92,0],
-"classKernel_1_1ComputeWeight__3.html":[1,0,0,1,93]
+"classKernel_1_1ComputeVolume__3.html#a138e1f41d22655f052e249ca415e3418":[1,0,0,1,91,1],
+"classKernel_1_1ComputeVolume__3.html#a617d129f99def4c454ae94b475cf6e81":[1,0,0,1,91,2]
 };
