@@ -1,5 +1,23 @@
 var group__PkgKernelDKernelObjs =
 [
+    [ "CGAL::Bbox_d< DimensionTag >", "classCGAL_1_1Bbox__d.html", [
+      [ "Cartesian_const_iterator", "classCGAL_1_1Bbox__d.html#a8b6d7e973c8c8c010ba237e1b48b86ba", null ],
+      [ "Bbox_d", "classCGAL_1_1Bbox__d.html#ae6377719b06ff84996456f2fc9590869", null ],
+      [ "Bbox_d", "classCGAL_1_1Bbox__d.html#a12cd4756b7c94bd3c5577d876535db92", null ],
+      [ "Bbox_d", "classCGAL_1_1Bbox__d.html#ae55d2d5c93309ae357c0b1845f0cb216", null ],
+      [ "Bbox_d", "classCGAL_1_1Bbox__d.html#af3844025289128bd3378cbc43b61cdf2", null ],
+      [ "cartesian_begin", "classCGAL_1_1Bbox__d.html#a1c72dca3c5ba35d3220d40471c9a89f2", null ],
+      [ "cartesian_end", "classCGAL_1_1Bbox__d.html#ad20a4a32225bd9cca82c7634035e7af5", null ],
+      [ "dilate", "classCGAL_1_1Bbox__d.html#a9da24182b11d4361397c298d7f94579c", null ],
+      [ "dimension", "classCGAL_1_1Bbox__d.html#aeaa1076c8522571f54788962e49fb04f", null ],
+      [ "max", "classCGAL_1_1Bbox__d.html#aca68e4165b705f0feb28fb1c6e1bcd73", null ],
+      [ "min", "classCGAL_1_1Bbox__d.html#a073c0df0b7072701a7b10d5c2bec0202", null ],
+      [ "operator!=", "classCGAL_1_1Bbox__d.html#a3796e7bfa9c96104a031158546236804", null ],
+      [ "operator+", "classCGAL_1_1Bbox__d.html#a697da143ba5a30969e5f022e0a76ce28", null ],
+      [ "operator+=", "classCGAL_1_1Bbox__d.html#af719dcd76c5f4e371565ac7cbdd8e344", null ],
+      [ "operator==", "classCGAL_1_1Bbox__d.html#a23d94ca64f7fceff52c5e862f62fa935", null ],
+      [ "scale", "classCGAL_1_1Bbox__d.html#af92f7d0955a4a0eab2014afd80ec28ab", null ]
+    ] ],
     [ "CGAL::Aff_transformation_d< Kernel >", "classCGAL_1_1Aff__transformation__d.html", [
       [ "LA", "classCGAL_1_1Aff__transformation__d.html#a4292bc487be965e90d5464ad93b09fc5", null ],
       [ "Matrix", "classCGAL_1_1Aff__transformation__d.html#abd21f60ed6258ea830372804b973fddb", null ],
