@@ -1,30 +1,59 @@
 var NAVTREEINDEX1 =
 {
-"classCGAL_1_1Vector__d.html#a41278e116e5722f162fe71c0f45f0310":[1,0,2,9,23],
-"classCGAL_1_1Vector__d.html#a4925f42397ae33014323459fe240afbd":[1,0,2,9,29],
-"classCGAL_1_1Vector__d.html#a6c28e5ac83cc71b63f4827a6163d1039":[1,0,2,9,32],
-"classCGAL_1_1Vector__d.html#a6c6af5a05242e434fe1f18625b2e5abc":[1,0,2,9,18],
-"classCGAL_1_1Vector__d.html#a6ceb8b177d76be0d1c1772f65e8e354f":[1,0,2,9,4],
-"classCGAL_1_1Vector__d.html#a75fe7006bd5e272b722a5002f45ff862":[1,0,2,9,30],
-"classCGAL_1_1Vector__d.html#a7930cda0c92e9e421c66ac9b214b3ade":[1,0,2,9,3],
-"classCGAL_1_1Vector__d.html#a7d9f7685f507841e4f8f2690f92888e8":[1,0,2,9,7],
-"classCGAL_1_1Vector__d.html#a8288c139baf99c2ebc34aef5cfa83479":[1,0,2,9,8],
-"classCGAL_1_1Vector__d.html#a841643d06a91c206839168242d0dd03a":[1,0,2,9,34],
-"classCGAL_1_1Vector__d.html#a9261acb0cde2d37cdfc6269c90688029":[1,0,2,9,31],
-"classCGAL_1_1Vector__d.html#a944a1c3eda179f213d6848f9bac93c51":[1,0,2,9,14],
-"classCGAL_1_1Vector__d.html#aa1e303bff4b1939e3670cb0e11a8edce":[1,0,2,9,27],
-"classCGAL_1_1Vector__d.html#aa2eceb6f3cbbca60237ae6deb2018a16":[1,0,2,9,28],
-"classCGAL_1_1Vector__d.html#aa84f119ef69d31fe0845bd7c112060ca":[1,0,2,9,13],
-"classCGAL_1_1Vector__d.html#ab6de895342098614abe3f598ab0ff91e":[1,0,2,9,5],
-"classCGAL_1_1Vector__d.html#ab93791339deff5d2f5faad3b3dfec6b5":[1,0,2,9,20],
-"classCGAL_1_1Vector__d.html#ac042ae890d327f53cbc16567c4e3ebcd":[1,0,2,9,9],
-"classCGAL_1_1Vector__d.html#ac270ccd0dd4ed479360a8ef18142e66a":[1,0,2,9,35],
-"classCGAL_1_1Vector__d.html#ac4dd3794dfd1621a8bc3b2e9c7daa6e2":[1,0,2,9,15],
-"classCGAL_1_1Vector__d.html#acf0128cadf001ecf33603b94c10f2313":[1,0,2,9,0],
-"classCGAL_1_1Vector__d.html#ade38e140c6a25524259500d68c6617ba":[1,0,2,9,33],
-"classCGAL_1_1Vector__d.html#ae596c0142cb2d3f4fdbea49fe6a736ce":[1,0,2,9,19],
-"classCGAL_1_1Vector__d.html#af12a14784542f396b38f06421b4fb042":[1,0,2,9,36],
-"classCGAL_1_1Vector__d.html#af3c5d874b637f27ce2e6f12648528bda":[1,0,2,9,2],
+"classCGAL_1_1Sphere__d.html#a6e20d81170e58ab7bcb0ce2b3cabca99":[1,0,2,9,8],
+"classCGAL_1_1Sphere__d.html#a84413276df4788abcb5f8d8f92592750":[1,0,2,9,19],
+"classCGAL_1_1Sphere__d.html#a85a6c8d59672a38e92e4b3d45b8fcd10":[1,0,2,9,15],
+"classCGAL_1_1Sphere__d.html#aa6a4abb8b5024687f46ed07688ce814d":[1,0,2,9,7],
+"classCGAL_1_1Sphere__d.html#aa7effce8dc037fe9bd077105b9d22b00":[1,0,2,9,20],
+"classCGAL_1_1Sphere__d.html#aae79081d86323b638f21cc4dc34566b5":[1,0,2,9,9],
+"classCGAL_1_1Sphere__d.html#aaf3c458d451f0d3e5054d1f87e488b76":[1,0,2,9,4],
+"classCGAL_1_1Sphere__d.html#ac7b7a2ee32be0b2a97af951643979941":[1,0,2,9,10],
+"classCGAL_1_1Sphere__d.html#aca7e2a872a0e152913e38f96cb3ab393":[1,0,2,9,2],
+"classCGAL_1_1Sphere__d.html#ad0403469fc1ca6a2c7b358a4649161ac":[1,0,2,9,5],
+"classCGAL_1_1Sphere__d.html#ad3dc610c7902c12a1820f8fca2515c5d":[1,0,2,9,22],
+"classCGAL_1_1Sphere__d.html#ad622d2d04e8ac1f620c36e3b25ee5046":[1,0,2,9,6],
+"classCGAL_1_1Sphere__d.html#ad6402b3560a4d7c89e8531ff66aca1a4":[1,0,2,9,21],
+"classCGAL_1_1Sphere__d.html#adb0876359790861163d4eb2a01d28f8c":[1,0,2,9,17],
+"classCGAL_1_1Sphere__d.html#aebcbe3c205a998792f4a3ad804f8380a":[1,0,2,9,12],
+"classCGAL_1_1Sphere__d.html#af68af2fdc7f94b05edef2bd9add3fa11":[1,0,2,9,11],
+"classCGAL_1_1Vector__d.html":[1,0,2,10],
+"classCGAL_1_1Vector__d.html#a0e9e2e23850e74e17d5416fec98baf2a":[1,0,2,10,11],
+"classCGAL_1_1Vector__d.html#a15d0f3596124c72357fee80819599d1e":[1,0,2,10,24],
+"classCGAL_1_1Vector__d.html#a18a1f239d8e7917149f257ee2d59c8ef":[1,0,2,10,6],
+"classCGAL_1_1Vector__d.html#a2428612148969ddd4bfb4af570805e0d":[1,0,2,10,12],
+"classCGAL_1_1Vector__d.html#a303f14d91232cdd25ea22786cbacd830":[1,0,2,10,17],
+"classCGAL_1_1Vector__d.html#a30a7fa8723c1b6fcbf68f664f265c099":[1,0,2,10,16],
+"classCGAL_1_1Vector__d.html#a3304d743c8357fedc3954dc69850f8d6":[1,0,2,10,25],
+"classCGAL_1_1Vector__d.html#a3636fa8a4b6d0cdcc08ca761f774d4d5":[1,0,2,10,21],
+"classCGAL_1_1Vector__d.html#a365ff3327e86a90d86c9d5e98a3a20ae":[1,0,2,10,26],
+"classCGAL_1_1Vector__d.html#a384b9c914c629169cab397859b889811":[1,0,2,10,10],
+"classCGAL_1_1Vector__d.html#a3a4e780b2cf234f94d443b0c04df3752":[1,0,2,10,1],
+"classCGAL_1_1Vector__d.html#a3e45bec815ca82356699ac8316f09e2f":[1,0,2,10,22],
+"classCGAL_1_1Vector__d.html#a41278e116e5722f162fe71c0f45f0310":[1,0,2,10,23],
+"classCGAL_1_1Vector__d.html#a4925f42397ae33014323459fe240afbd":[1,0,2,10,29],
+"classCGAL_1_1Vector__d.html#a6c28e5ac83cc71b63f4827a6163d1039":[1,0,2,10,32],
+"classCGAL_1_1Vector__d.html#a6c6af5a05242e434fe1f18625b2e5abc":[1,0,2,10,18],
+"classCGAL_1_1Vector__d.html#a6ceb8b177d76be0d1c1772f65e8e354f":[1,0,2,10,4],
+"classCGAL_1_1Vector__d.html#a75fe7006bd5e272b722a5002f45ff862":[1,0,2,10,30],
+"classCGAL_1_1Vector__d.html#a7930cda0c92e9e421c66ac9b214b3ade":[1,0,2,10,3],
+"classCGAL_1_1Vector__d.html#a7d9f7685f507841e4f8f2690f92888e8":[1,0,2,10,7],
+"classCGAL_1_1Vector__d.html#a8288c139baf99c2ebc34aef5cfa83479":[1,0,2,10,8],
+"classCGAL_1_1Vector__d.html#a841643d06a91c206839168242d0dd03a":[1,0,2,10,34],
+"classCGAL_1_1Vector__d.html#a9261acb0cde2d37cdfc6269c90688029":[1,0,2,10,31],
+"classCGAL_1_1Vector__d.html#a944a1c3eda179f213d6848f9bac93c51":[1,0,2,10,14],
+"classCGAL_1_1Vector__d.html#aa1e303bff4b1939e3670cb0e11a8edce":[1,0,2,10,27],
+"classCGAL_1_1Vector__d.html#aa2eceb6f3cbbca60237ae6deb2018a16":[1,0,2,10,28],
+"classCGAL_1_1Vector__d.html#aa84f119ef69d31fe0845bd7c112060ca":[1,0,2,10,13],
+"classCGAL_1_1Vector__d.html#ab6de895342098614abe3f598ab0ff91e":[1,0,2,10,5],
+"classCGAL_1_1Vector__d.html#ab93791339deff5d2f5faad3b3dfec6b5":[1,0,2,10,20],
+"classCGAL_1_1Vector__d.html#ac042ae890d327f53cbc16567c4e3ebcd":[1,0,2,10,9],
+"classCGAL_1_1Vector__d.html#ac270ccd0dd4ed479360a8ef18142e66a":[1,0,2,10,35],
+"classCGAL_1_1Vector__d.html#ac4dd3794dfd1621a8bc3b2e9c7daa6e2":[1,0,2,10,15],
+"classCGAL_1_1Vector__d.html#acf0128cadf001ecf33603b94c10f2313":[1,0,2,10,0],
+"classCGAL_1_1Vector__d.html#ade38e140c6a25524259500d68c6617ba":[1,0,2,10,33],
+"classCGAL_1_1Vector__d.html#ae596c0142cb2d3f4fdbea49fe6a736ce":[1,0,2,10,19],
+"classCGAL_1_1Vector__d.html#af12a14784542f396b38f06421b4fb042":[1,0,2,10,36],
+"classCGAL_1_1Vector__d.html#af3c5d874b637f27ce2e6f12648528bda":[1,0,2,10,2],
 "classKernelWithLifting__d.html":[1,0,1,35],
 "classKernelWithLifting__d.html#a5e3e5ca6fb480bdf7984e43465657d13":[1,0,1,35,1],
 "classKernelWithLifting__d.html#aad4bcf66ceb95c8d470fd0e9f172e6b1":[1,0,1,35,2],
@@ -220,34 +249,5 @@ var NAVTREEINDEX1 =
 "classMatrix.html#a9824b9554cf8e5336584a2cc8512369e":[1,0,5,1,6],
 "classMatrix.html#aa729a3721fe888ddc2a7b782d0556039":[1,0,5,1,14],
 "classMatrix.html#aaa6cf4181364809544e9c0317868320a":[1,0,5,1,30],
-"classMatrix.html#ab0e4740a8276f8ed4260c40f7cb921c3":[1,0,5,1,40],
-"classMatrix.html#ab1eb34fc4e69afde03fe9d36e961846a":[1,0,5,1,39],
-"classMatrix.html#ab7b0b88e8d9db6917314deebf3b6058f":[1,0,5,1,13],
-"classMatrix.html#abfa64c600f3001dac24409b53fee609c":[1,0,5,1,34],
-"classMatrix.html#adc0e82f527cab2ae7463140cf8a072a0":[1,0,5,1,10],
-"classMatrix.html#add12f46f4fe2e5f4d28619102dce5d03":[1,0,5,1,43],
-"classMatrix.html#ae9024e5963cb6b4aa4b2295bbc0c88d2":[1,0,5,1,7],
-"classMatrix.html#aea017627b8806f04e254371f633b39d1":[1,0,5,1,36],
-"classMatrix.html#aeeb01663c821db08857fc7ae58a67511":[1,0,5,1,35],
-"classMatrix.html#af7c3d6c831c98700660c73bf594b4a47":[1,0,5,1,20],
-"classVector.html":[1,0,5,2],
-"classVector.html#a0816042666dda53a188b9485e7452213":[1,0,5,2,13],
-"classVector.html#a13438f9d939845eb7d3ec40b51092b85":[1,0,5,2,22],
-"classVector.html#a1b4a908b6431447c1aba0710cae3b92b":[1,0,5,2,18],
-"classVector.html#a1e0bdb9b899215359ab5f33d1f7a2981":[1,0,5,2,10],
-"classVector.html#a20e75dc447ca6ba3e7da6b3d49321a59":[1,0,5,2,8],
-"classVector.html#a2272ba7391dae9d0392e8703ef94c049":[1,0,5,2,16],
-"classVector.html#a310e50878d1672dc89ab0fba9617d843":[1,0,5,2,6],
-"classVector.html#a436d65a4512d10caee283e3ec3646f91":[1,0,5,2,2],
-"classVector.html#a44c79b7e3b7284211c10cbb827eacdb5":[1,0,5,2,14],
-"classVector.html#a46504cdd44572a8c09ad8009e9aedd14":[1,0,5,2,11],
-"classVector.html#a4cf3e7a7499c632160dd9e51e8d425b7":[1,0,5,2,4],
-"classVector.html#a563a636171881629c216b78e6f15d079":[1,0,5,2,1],
-"classVector.html#a6f80c73b5f18dcf3f8e36065bdc8b9e5":[1,0,5,2,3],
-"classVector.html#a8f86aa28f32530a0caa6a6aa6c80015b":[1,0,5,2,0],
-"classVector.html#a9a0db80b001d99ce89e83585135c25a3":[1,0,5,2,20],
-"classVector.html#a9d992e1c8ffe3499475e33bca1c5d471":[1,0,5,2,12],
-"classVector.html#aaa5f64a3756e6294c6070b3f7c9c3b33":[1,0,5,2,19],
-"classVector.html#aad53c18c42d77948f920956a3739e2b6":[1,0,5,2,5],
-"classVector.html#aae096dc427068deacc3344768d564495":[1,0,5,2,23]
+"classMatrix.html#ab0e4740a8276f8ed4260c40f7cb921c3":[1,0,5,1,40]
 };
