@@ -1,9 +1,10 @@
 var examples =
 [
-    [ "Linear_cell_complex/draw_linear_cell_complex.cpp", "Linear_cell_complex_2draw_linear_cell_complex_8cpp-example.html", null ],
+    [ "Linear_cell_complex/linear_cell_complex_3_with_colored_vertices.cpp", "Linear_cell_complex_2linear_cell_complex_3_with_colored_vertices_8cpp-example.html", null ],
     [ "Linear_cell_complex/linear_cell_complex_3.cpp", "Linear_cell_complex_2linear_cell_complex_3_8cpp-example.html", null ],
+    [ "Linear_cell_complex/linear_cell_complex_4.cpp", "Linear_cell_complex_2linear_cell_complex_4_8cpp-example.html", null ],
     [ "Linear_cell_complex/linear_cell_complex_3_attributes_management.cpp", "Linear_cell_complex_2linear_cell_complex_3_attributes_management_8cpp-example.html", null ],
     [ "Linear_cell_complex/linear_cell_complex_3_incremental_builder.cpp", "Linear_cell_complex_2linear_cell_complex_3_incremental_builder_8cpp-example.html", null ],
-    [ "Linear_cell_complex/linear_cell_complex_3_with_colored_vertices.cpp", "Linear_cell_complex_2linear_cell_complex_3_with_colored_vertices_8cpp-example.html", null ],
-    [ "Linear_cell_complex/linear_cell_complex_4.cpp", "Linear_cell_complex_2linear_cell_complex_4_8cpp-example.html", null ]
+    [ "Linear_cell_complex/draw_linear_cell_complex.cpp", "Linear_cell_complex_2draw_linear_cell_complex_8cpp-example.html", null ],
+    [ "Linear_cell_complex/linear_cell_complex_3_insert.cpp", "Linear_cell_complex_2linear_cell_complex_3_insert_8cpp-example.html", null ]
 ];
\ No newline at end of file
