@@ -128,7 +128,7 @@ var searchData=
   ['sphere_5fsegment_125',['Sphere_segment',['../../Nef_S2/classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html',1,'CGAL::Nef_polyhedron_S2']]],
   ['spherical_5fkernel_5f3_126',['Spherical_kernel_3',['../../Circular_kernel_3/structCGAL_1_1Spherical__kernel__3.html',1,'CGAL']]],
   ['sphericalkernel_127',['SphericalKernel',['../../Circular_kernel_3/classSphericalKernel.html',1,'']]],
-  ['split_5f2_128',['Split_2',['../../Boolean_set_operations_2/classArrDirectionalTraits_1_1Split__2.html',1,'ArrDirectionalTraits::Split_2'],['../../Arrangement_on_surface_2/classArrTraits_1_1Split__2.html',1,'ArrTraits::Split_2'],['../../Circular_kernel_2/classCircularKernel_1_1Split__2.html',1,'CircularKernel::Split_2']]],
+  ['split_5f2_128',['Split_2',['../../Arrangement_on_surface_2/classAosTraits_1_1Split__2.html',1,'AosTraits::Split_2'],['../../Boolean_set_operations_2/classArrDirectionalTraits_1_1Split__2.html',1,'ArrDirectionalTraits::Split_2'],['../../Circular_kernel_2/classCircularKernel_1_1Split__2.html',1,'CircularKernel::Split_2']]],
   ['split_5f3_129',['Split_3',['../../Circular_kernel_3/classSphericalKernel_1_1Split__3.html',1,'SphericalKernel']]],
   ['split_5fpredicate_5fnode_5fmin_5fextent_130',['Split_predicate_node_min_extent',['../../Orthtree/classCGAL_1_1Orthtree__traits__face__graph_1_1Split__predicate__node__min__extent.html',1,'CGAL::Orthtree_traits_face_graph']]],
   ['splitter_131',['Splitter',['../../Spatial_searching/classSplitter.html',1,'']]],
