@@ -5,7 +5,5 @@ var searchData=
   ['kernel_20function_20object_20concepts_2',['Kernel Function Object Concepts',['../../Kernel_23/group__PkgKernel23ConceptsFunctionObjects.html',1,'']]],
   ['kernel_20geometric_20object_20concepts_3',['Kernel Geometric Object Concepts',['../../Kernel_23/group__PkgKernel23ConceptsGeomObject.html',1,'']]],
   ['kernel_20objects_4',['Kernel Objects',['../../Kernel_d/group__PkgKernelDKernelObjs.html',1,'']]],
-  ['kernels_5',['Kernels',['../../Kernel_d/group__PkgKernelDKernels.html',1,'']]],
-  ['kinetic_20space_20partition_20reference_6',['Kinetic Space Partition Reference',['../../Kinetic_space_partition/group__PkgKineticSpacePartitionRef.html',1,'']]],
-  ['kinetic_20surface_20reconstruction_20reference_7',['Kinetic Surface Reconstruction Reference',['../../Kinetic_surface_reconstruction/group__PkgKineticSurfaceReconstructionRef.html',1,'']]]
+  ['kernels_5',['Kernels',['../../Kernel_d/group__PkgKernelDKernels.html',1,'']]]
 ];
