@@ -1,7 +1,7 @@
 var searchData=
 [
   ['macros_0',['Macros',['../../Arrangement_on_surface_2/group__PkgArrangementOnSurface2Macros.html',1,'']]],
-  ['main_20classes_1',['Main Classes',['../../Hyperbolic_triangulation_2/group__PkgHyperbolicTriangulation2MainClasses.html',1,'(Global Namespace)'],['../../Periodic_2_triangulation_2/group__PkgPeriodic2Triangulation2MainClasses.html',1,'(Global Namespace)'],['../../Periodic_3_triangulation_3/group__PkgPeriodic3Triangulation3MainClasses.html',1,'(Global Namespace)'],['../../Periodic_4_hyperbolic_triangulation_2/group__PkgPeriodic4HyperbolicTriangulation2MainClasses.html',1,'(Global Namespace)']]],
+  ['main_20classes_1',['Main Classes',['../../Triangulation_on_hyperbolic_surface_2/group__PkgHyperbolicSurfaceTriangulation2MainClasses.html',1,'(Global Namespace)'],['../../Hyperbolic_triangulation_2/group__PkgHyperbolicTriangulation2MainClasses.html',1,'(Global Namespace)'],['../../Periodic_2_triangulation_2/group__PkgPeriodic2Triangulation2MainClasses.html',1,'(Global Namespace)'],['../../Periodic_3_triangulation_3/group__PkgPeriodic3Triangulation3MainClasses.html',1,'(Global Namespace)'],['../../Periodic_4_hyperbolic_triangulation_2/group__PkgPeriodic4HyperbolicTriangulation2MainClasses.html',1,'(Global Namespace)']]],
   ['main_20concepts_2',['Main Concepts',['../../Mesh_3/group__PkgMesh3Concepts.html',1,'']]],
   ['main_20functions_3',['Main Functions',['../../Classification/group__PkgClassificationMain.html',1,'(Global Namespace)'],['../../Surface_mesh_parameterization/group__PkgSurfaceMeshParameterizationMainFunction.html',1,'(Global Namespace)']]],
   ['mean_20value_20weight_4',['Mean Value Weight',['../../Weights/group__PkgWeightsRefMeanValueWeights.html',1,'']]],
@@ -12,12 +12,11 @@ var searchData=
   ['mesh_20domain_20fields_9',['Mesh Domain Fields',['../../Mesh_3/group__PkgMesh3DomainFields.html',1,'']]],
   ['mesh_20generation_10',['Mesh Generation',['../../Surface_mesher/group__PkgSurfaceMesher3FunctionsMakeMesh.html',1,'']]],
   ['mesh_20generation_20functions_11',['Mesh Generation Functions',['../../Mesh_2/group__PkgMesh2Functions.html',1,'(Global Namespace)'],['../../Mesh_3/group__PkgMesh3Functions.html',1,'(Global Namespace)'],['../../Periodic_3_mesh_3/group__PkgPeriodic3Mesh3Functions.html',1,'(Global Namespace)']]],
-  ['meshing_12',['Meshing',['../../Polygon_mesh_processing/group__PMP__meshing__grp.html',1,'']]],
-  ['miscellaneous_13',['Miscellaneous',['../../Triangulation_2/group__PkgTriangulation2Miscellaneous.html',1,'']]],
-  ['miscellaneous_20classes_14',['Miscellaneous Classes',['../../GraphicsView/group__PkgGraphicsViewMiscClasses.html',1,'']]],
-  ['mixed_20integer_20programming_15',['Mixed Integer Programming',['../../Solver_interface/group__PkgSolverInterfaceMIP.html',1,'']]],
-  ['mixed_20voronoi_20region_20weight_16',['Mixed Voronoi Region Weight',['../../Weights/group__PkgWeightsRefMixedVoronoiRegionWeights.html',1,'']]],
-  ['models_17',['Models',['../../Algebraic_kernel_d/group__PkgAlgebraicKernelDModels.html',1,'']]],
-  ['modular_20arithmetic_20reference_18',['Modular Arithmetic Reference',['../../Modular_arithmetic/group__PkgModularArithmeticRef.html',1,'']]],
-  ['monotone_20and_20sorted_20matrix_20search_20reference_19',['Monotone and Sorted Matrix Search Reference',['../../Matrix_search/group__PkgMatrixSearchRef.html',1,'']]]
+  ['mesh_20initialization_20functors_12',['Mesh Initialization Functors',['../../Mesh_3/group__PkgMesh3Initializers.html',1,'']]],
+  ['meshing_13',['Meshing',['../../Polygon_mesh_processing/group__PMP__meshing__grp.html',1,'']]],
+  ['miscellaneous_14',['Miscellaneous',['../../Triangulation_2/group__PkgTriangulation2Miscellaneous.html',1,'']]],
+  ['miscellaneous_20classes_15',['Miscellaneous Classes',['../../GraphicsView/group__PkgGraphicsViewMiscClasses.html',1,'']]],
+  ['mixed_20integer_20programming_16',['Mixed Integer Programming',['../../Solver_interface/group__PkgSolverInterfaceMIP.html',1,'']]],
+  ['mixed_20voronoi_20region_20weight_17',['Mixed Voronoi Region Weight',['../../Weights/group__PkgWeightsRefMixedVoronoiRegionWeights.html',1,'']]],
+  ['models_18',['Models',['../../Algebraic_kernel_d/group__PkgAlgebraicKernelDModels.html',1,'']]]
 ];
