@@ -4,6 +4,5 @@ var searchData=
   ['natural_20neighbor_20coordinate_20computation_1',['Natural Neighbor Coordinate Computation',['../../Interpolation/group__PkgInterpolation2NatNeighbor.html',1,'']]],
   ['nearest_20neighbor_20search_2',['Nearest Neighbor Search',['../../Point_set_2/group__PkgPointSet2NeighborSearch.html',1,'']]],
   ['nonlinear_20programming_3',['Nonlinear Programming',['../../Solver_interface/group__PkgSolverInterfaceNLP.html',1,'']]],
-  ['normal_20computation_4',['Normal Computation',['../../Polygon_mesh_processing/group__PMP__normal__grp.html',1,'']]],
-  ['number_20types_20reference_5',['Number Types Reference',['../../Number_types/group__PkgNumberTypesRef.html',1,'']]]
+  ['normal_20computation_4',['Normal Computation',['../../Polygon_mesh_processing/group__PMP__normal__grp.html',1,'']]]
 ];
