@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['cgal_206_2e0_2e3_20_2d_20manual_0',['CGAL 6.0.3 - Manual',['../index.html',1,'']]],
+  ['cgal_206_2e1_20_2d_20manual_0',['CGAL 6.1 - Manual',['../index.html',1,'']]],
   ['checks_3a_20pre_2d_20and_20postconditions_2c_20assertions_2c_20and_20warnings_1',['Checks: Pre- and Postconditions, Assertions, and Warnings',['../devman_checks.html',1,'dev_manual']]],
   ['classified_20reference_20pages_2',['Classified Reference Pages',['../../Algebraic_foundations/AlgebraicFoundationsClassified.html',1,'']]],
   ['coding_20conventions_3',['Coding Conventions',['../devman_code_format.html',1,'dev_manual']]],
