@@ -2,5 +2,6 @@ var searchData=
 [
   ['debugging_20tips_0',['Debugging Tips',['../devman_debugging.html',1,'dev_manual']]],
   ['deprecation_20notice_1',['Deprecation Notice',['../deprecated.html',1,'dev_manual']]],
-  ['developer_20manual_2',['Developer Manual',['../dev_manual.html',1,'index']]]
+  ['developer_20manual_2',['Developer Manual',['../dev_manual.html',1,'index']]],
+  ['doxygen_20for_20cgal_3',['Doxygen for CGAL',['../md_Doxygen_for_CGAL.html',1,'']]]
 ];
