@@ -9,7 +9,7 @@ var indexSectionsWithContent =
   6: "abcdefghiklmnopqrstuvwxyz",
   7: "abcdefghilmopqrstuvw",
   8: "gop",
-  9: "23abcdefghiklmnopqrstuvw",
+  9: "23abcdefghiklmnoprstuvw",
   10: "abcdeghilmnoprstu"
 };
 
