@@ -1,6 +1,9 @@
 var annotated =
 [
-    [ "CGAL", "namespaceCGAL.html", "namespaceCGAL" ],
+    [ "CGAL", null, [
+      [ "Dynamic_matrix", "classCGAL_1_1Dynamic__matrix.html", "classCGAL_1_1Dynamic__matrix" ],
+      [ "Sorted_matrix_search_traits_adaptor", "classCGAL_1_1Sorted__matrix__search__traits__adaptor.html", "classCGAL_1_1Sorted__matrix__search__traits__adaptor" ]
+    ] ],
     [ "BasicMatrix", "classBasicMatrix.html", "classBasicMatrix" ],
     [ "MonotoneMatrixSearchTraits", "classMonotoneMatrixSearchTraits.html", "classMonotoneMatrixSearchTraits" ],
     [ "SortedMatrixSearchTraits", "classSortedMatrixSearchTraits.html", "classSortedMatrixSearchTraits" ]
