@@ -3,7 +3,7 @@ var examples =
     [ "Mesh_2/conforming.cpp", "Mesh_2_2conforming_8cpp-example.html", null ],
     [ "Mesh_2/mesh_class.cpp", "Mesh_2_2mesh_class_8cpp-example.html", null ],
     [ "Mesh_2/mesh_global.cpp", "Mesh_2_2mesh_global_8cpp-example.html", null ],
+    [ "Mesh_2/mesh_with_seeds.cpp", "Mesh_2_2mesh_with_seeds_8cpp-example.html", null ],
     [ "Mesh_2/mesh_marked_domain.cpp", "Mesh_2_2mesh_marked_domain_8cpp-example.html", null ],
-    [ "Mesh_2/mesh_optimization.cpp", "Mesh_2_2mesh_optimization_8cpp-example.html", null ],
-    [ "Mesh_2/mesh_with_seeds.cpp", "Mesh_2_2mesh_with_seeds_8cpp-example.html", null ]
+    [ "Mesh_2/mesh_optimization.cpp", "Mesh_2_2mesh_optimization_8cpp-example.html", null ]
 ];
\ No newline at end of file
