@@ -2,16 +2,15 @@ var examples =
 [
     [ "Mesh_3/implicit_functions.cpp", "Mesh_3_2implicit_functions_8cpp-example.html", null ],
     [ "Mesh_3/mesh_3D_image.cpp", "Mesh_3_2mesh_3D_image_8cpp-example.html", null ],
-    [ "Mesh_3/mesh_3D_gray_image_with_custom_initialization.cpp", "Mesh_3_2mesh_3D_gray_image_with_custom_initialization_8cpp-example.html", null ],
     [ "Mesh_3/mesh_3D_image_with_features.cpp", "Mesh_3_2mesh_3D_image_with_features_8cpp-example.html", null ],
     [ "Mesh_3/mesh_3D_image_with_custom_initialization.cpp", "Mesh_3_2mesh_3D_image_with_custom_initialization_8cpp-example.html", null ],
+    [ "Mesh_3/mesh_3D_image_with_initial_points.cpp", "Mesh_3_2mesh_3D_image_with_initial_points_8cpp-example.html", null ],
+    [ "Mesh_3/mesh_3D_image_with_image_initialization.cpp", "Mesh_3_2mesh_3D_image_with_image_initialization_8cpp-example.html", null ],
     [ "Mesh_3/mesh_3D_image_with_detection_of_features.cpp", "Mesh_3_2mesh_3D_image_with_detection_of_features_8cpp-example.html", null ],
     [ "Mesh_3/mesh_3D_image_with_input_features.cpp", "Mesh_3_2mesh_3D_image_with_input_features_8cpp-example.html", null ],
     [ "Mesh_3/mesh_3D_weighted_image.cpp", "Mesh_3_2mesh_3D_weighted_image_8cpp-example.html", null ],
     [ "Mesh_3/mesh_3D_weighted_image_with_detection_of_features.cpp", "Mesh_3_2mesh_3D_weighted_image_with_detection_of_features_8cpp-example.html", null ],
     [ "Mesh_3/random_labeled_image.h", "Mesh_3_2random_labeled_image_8h-example.html", null ],
-    [ "CGAL/Mesh_3/initialize_triangulation_from_gray_image.h", "CGAL_2Mesh_3_2initialize_triangulation_from_gray_image_8h-example.html", null ],
-    [ "CGAL/Mesh_3/initialize_triangulation_from_labeled_image.h", "CGAL_2Mesh_3_2initialize_triangulation_from_labeled_image_8h-example.html", null ],
     [ "Mesh_3/mesh_3D_image_variable_size.cpp", "Mesh_3_2mesh_3D_image_variable_size_8cpp-example.html", null ],
     [ "Mesh_3/mesh_hybrid_mesh_domain.cpp", "Mesh_3_2mesh_hybrid_mesh_domain_8cpp-example.html", null ],
     [ "Mesh_3/mesh_implicit_domains.cpp", "Mesh_3_2mesh_implicit_domains_8cpp-example.html", null ],
