@@ -1,40 +1,39 @@
 var NAVTREEINDEX0 =
 {
-"CGAL_2Mesh_3_2initialize_triangulation_from_gray_image_8h-example.html":[5,10],
-"CGAL_2Mesh_3_2initialize_triangulation_from_labeled_image_8h-example.html":[5,11],
 "Mesh_3_2implicit_functions_8cpp-example.html":[5,0],
-"Mesh_3_2mesh_3D_gray_image_8cpp-example.html":[5,33],
-"Mesh_3_2mesh_3D_gray_image_with_custom_initialization_8cpp-example.html":[5,2],
-"Mesh_3_2mesh_3D_gray_vtk_image_8cpp-example.html":[5,34],
+"Mesh_3_2mesh_3D_gray_image_8cpp-example.html":[5,32],
+"Mesh_3_2mesh_3D_gray_vtk_image_8cpp-example.html":[5,33],
 "Mesh_3_2mesh_3D_image_8cpp-example.html":[5,1],
-"Mesh_3_2mesh_3D_image_variable_size_8cpp-example.html":[5,12],
-"Mesh_3_2mesh_3D_image_with_custom_initialization_8cpp-example.html":[5,4],
-"Mesh_3_2mesh_3D_image_with_detection_of_features_8cpp-example.html":[5,5],
-"Mesh_3_2mesh_3D_image_with_features_8cpp-example.html":[5,3],
-"Mesh_3_2mesh_3D_image_with_input_features_8cpp-example.html":[5,6],
-"Mesh_3_2mesh_3D_weighted_image_8cpp-example.html":[5,7],
-"Mesh_3_2mesh_3D_weighted_image_with_detection_of_features_8cpp-example.html":[5,8],
-"Mesh_3_2mesh_hybrid_mesh_domain_8cpp-example.html":[5,13],
-"Mesh_3_2mesh_implicit_domains_2_8cpp-example.html":[5,15],
-"Mesh_3_2mesh_implicit_domains_8cpp-example.html":[5,14],
-"Mesh_3_2mesh_implicit_ellipsoid_8cpp-example.html":[5,16],
-"Mesh_3_2mesh_implicit_sphere_8cpp-example.html":[5,17],
-"Mesh_3_2mesh_implicit_sphere_variable_size_8cpp-example.html":[5,18],
-"Mesh_3_2mesh_optimization_example_8cpp-example.html":[5,19],
-"Mesh_3_2mesh_optimization_lloyd_example_8cpp-example.html":[5,20],
-"Mesh_3_2mesh_polyhedral_complex_8cpp-example.html":[5,23],
-"Mesh_3_2mesh_polyhedral_complex_sm_8cpp-example.html":[5,24],
-"Mesh_3_2mesh_polyhedral_domain_8cpp-example.html":[5,21],
-"Mesh_3_2mesh_polyhedral_domain_sm_8cpp-example.html":[5,22],
-"Mesh_3_2mesh_polyhedral_domain_with_edge_distance_8cpp-example.html":[5,27],
-"Mesh_3_2mesh_polyhedral_domain_with_features_8cpp-example.html":[5,26],
-"Mesh_3_2mesh_polyhedral_domain_with_features_sizing_8cpp-example.html":[5,29],
-"Mesh_3_2mesh_polyhedral_domain_with_features_sm_8cpp-example.html":[5,28],
-"Mesh_3_2mesh_polyhedral_domain_with_lipschitz_sizing_8cpp-example.html":[5,31],
-"Mesh_3_2mesh_polyhedral_domain_with_surface_inside_8cpp-example.html":[5,30],
-"Mesh_3_2mesh_two_implicit_spheres_with_balls_8cpp-example.html":[5,32],
-"Mesh_3_2random_labeled_image_8h-example.html":[5,9],
-"Mesh_3_2remesh_polyhedral_surface_8cpp-example.html":[5,25],
+"Mesh_3_2mesh_3D_image_variable_size_8cpp-example.html":[5,11],
+"Mesh_3_2mesh_3D_image_with_custom_initialization_8cpp-example.html":[5,3],
+"Mesh_3_2mesh_3D_image_with_detection_of_features_8cpp-example.html":[5,6],
+"Mesh_3_2mesh_3D_image_with_features_8cpp-example.html":[5,2],
+"Mesh_3_2mesh_3D_image_with_image_initialization_8cpp-example.html":[5,5],
+"Mesh_3_2mesh_3D_image_with_initial_points_8cpp-example.html":[5,4],
+"Mesh_3_2mesh_3D_image_with_input_features_8cpp-example.html":[5,7],
+"Mesh_3_2mesh_3D_weighted_image_8cpp-example.html":[5,8],
+"Mesh_3_2mesh_3D_weighted_image_with_detection_of_features_8cpp-example.html":[5,9],
+"Mesh_3_2mesh_hybrid_mesh_domain_8cpp-example.html":[5,12],
+"Mesh_3_2mesh_implicit_domains_2_8cpp-example.html":[5,14],
+"Mesh_3_2mesh_implicit_domains_8cpp-example.html":[5,13],
+"Mesh_3_2mesh_implicit_ellipsoid_8cpp-example.html":[5,15],
+"Mesh_3_2mesh_implicit_sphere_8cpp-example.html":[5,16],
+"Mesh_3_2mesh_implicit_sphere_variable_size_8cpp-example.html":[5,17],
+"Mesh_3_2mesh_optimization_example_8cpp-example.html":[5,18],
+"Mesh_3_2mesh_optimization_lloyd_example_8cpp-example.html":[5,19],
+"Mesh_3_2mesh_polyhedral_complex_8cpp-example.html":[5,22],
+"Mesh_3_2mesh_polyhedral_complex_sm_8cpp-example.html":[5,23],
+"Mesh_3_2mesh_polyhedral_domain_8cpp-example.html":[5,20],
+"Mesh_3_2mesh_polyhedral_domain_sm_8cpp-example.html":[5,21],
+"Mesh_3_2mesh_polyhedral_domain_with_edge_distance_8cpp-example.html":[5,26],
+"Mesh_3_2mesh_polyhedral_domain_with_features_8cpp-example.html":[5,25],
+"Mesh_3_2mesh_polyhedral_domain_with_features_sizing_8cpp-example.html":[5,28],
+"Mesh_3_2mesh_polyhedral_domain_with_features_sm_8cpp-example.html":[5,27],
+"Mesh_3_2mesh_polyhedral_domain_with_lipschitz_sizing_8cpp-example.html":[5,30],
+"Mesh_3_2mesh_polyhedral_domain_with_surface_inside_8cpp-example.html":[5,29],
+"Mesh_3_2mesh_two_implicit_spheres_with_balls_8cpp-example.html":[5,31],
+"Mesh_3_2random_labeled_image_8h-example.html":[5,10],
+"Mesh_3_2remesh_polyhedral_surface_8cpp-example.html":[5,24],
 "annotated.html":[4],
 "citelist.html":[3],
 "classBisectionGeometricTraits__3.html":[1,0,1,0],
@@ -64,13 +63,13 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Implicit__multi__domain__to__labeling__function__wrapper.html#a2774fcc5804ceda753f3de7feec1096e":[1,0,3,5,1],
 "classCGAL_1_1Implicit__multi__domain__to__labeling__function__wrapper.html#a964b449d65e6c37dfa41a59251b48802":[1,0,3,5,2],
 "classCGAL_1_1Implicit__multi__domain__to__labeling__function__wrapper.html#aa29af1b60ab31299e8bda6a9d0c124b0":[1,0,3,5,0],
-"classCGAL_1_1Implicit__to__labeling__function__wrapper.html":[4,0,4],
-"classCGAL_1_1Implicit__to__labeling__function__wrapper.html#a418a7b18da1345541bf475ccecaca145":[4,0,4,1],
-"classCGAL_1_1Implicit__to__labeling__function__wrapper.html#a63ee748a20191eee00eef2a538d9c3f3":[4,0,4,0],
-"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html":[4,0,5],
-"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html#a1ace0b5ddedba17a8345dcb9f9d59539":[4,0,5,0],
-"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html#a806e43619ccf77aa0654e65200859f93":[4,0,5,2],
-"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html#aa38066de069f5172bed823de276c9ad0":[4,0,5,1],
+"classCGAL_1_1Implicit__to__labeling__function__wrapper.html":[4,0,6],
+"classCGAL_1_1Implicit__to__labeling__function__wrapper.html#a418a7b18da1345541bf475ccecaca145":[4,0,6,1],
+"classCGAL_1_1Implicit__to__labeling__function__wrapper.html#a63ee748a20191eee00eef2a538d9c3f3":[4,0,6,0],
+"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html":[4,0,7],
+"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html#a1ace0b5ddedba17a8345dcb9f9d59539":[4,0,7,0],
+"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html#a806e43619ccf77aa0654e65200859f93":[4,0,7,2],
+"classCGAL_1_1Implicit__vector__to__labeling__function__wrapper.html#aa38066de069f5172bed823de276c9ad0":[4,0,7,1],
 "classCGAL_1_1Labeled__mesh__domain__3.html":[1,0,3,7],
 "classCGAL_1_1Labeled__mesh__domain__3.html#a6180cb25285e4474e6e9ea8d8e25a4c6":[1,0,3,7,3],
 "classCGAL_1_1Labeled__mesh__domain__3.html#a7824b7e09d8d4cf12020a38bee8932f5":[1,0,3,7,8],
@@ -139,49 +138,53 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#a0148fe3a78de546d4543bde4e7be6d2c":[1,0,3,2,7],
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#a0daa5c9bfd8b0ca35696413f7e0c17a5":[1,0,3,2,9],
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#a13a07fd13ffc58ded914420169143c7d":[1,0,3,2,6],
-"classCGAL_1_1Polyhedral__mesh__domain__3.html#a3c93c8c580afc479d10c9173817cc58e":[1,0,3,2,4],
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#a7fdbb698f6d73298da063c4243044082":[1,0,3,2,10],
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#a848293ebbe85ccd62785b07f1bddda42":[1,0,3,2,12],
+"classCGAL_1_1Polyhedral__mesh__domain__3.html#a8f61dfeca9b7ca4ec6f7718b0ffb9a79":[1,0,3,2,4],
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#ae50047e5a4b1106069bd448223b5abf3":[1,0,3,2,8],
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#afdd05a187eb76df413a7b6906642e268":[1,0,3,2,5],
 "classCGAL_1_1Polyhedral__mesh__domain__3.html#aff272c49669eb916dcff55523f84a08e":[1,0,3,2,11],
 "classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html":[1,0,3,3],
 "classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#a03bb630b104206e106c8db3361114ba2":[1,0,3,3,2],
-"classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#a41552115cde4e7c05a17df02955c8ba5":[1,0,3,3,0],
+"classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#a0ce75a90e88563944ac12db6c4d0a6b7":[1,0,3,3,0],
 "classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#a6028cafa6549170749f026f9354d2096":[1,0,3,3,1],
 "classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#a8264d9a44747be3ed04d292538e6cc6b":[1,0,3,3,6],
 "classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#a9a101b70f24d8d06ada4b4c90e190edc":[1,0,3,3,4],
 "classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#ae450b23fbd85646051b31fad7eeb5b55":[1,0,3,3,5],
 "classCGAL_1_1Polyhedral__mesh__domain__with__features__3.html#aea9cb8c3128172a8fac9ca70f4873ff4":[1,0,3,3,3],
-"classIntersectionGeometricTraits__3.html":[1,0,1,1],
-"classIntersectionGeometricTraits__3.html#a0504f5625b1aa2e475fe31686b38afc8":[1,0,1,1,2],
-"classIntersectionGeometricTraits__3.html#a30502ace5406c493b1d2b1f147ef4850":[1,0,1,1,4],
-"classIntersectionGeometricTraits__3.html#a4eaf6c2bb851a932b50ae237a1be1416":[1,0,1,1,5],
-"classIntersectionGeometricTraits__3.html#a572393696b038882cf2653179c5eef95":[1,0,1,1,6],
-"classIntersectionGeometricTraits__3.html#a5b50b9166990edb9a59a06bd7f168250":[1,0,1,1,0],
-"classIntersectionGeometricTraits__3.html#aa197980bca0213b46280a6fed030485f":[1,0,1,1,3],
-"classIntersectionGeometricTraits__3.html#ae0e03751a406a5c035f342d1db5bf27a":[1,0,1,1,1],
-"classMeshCellBase__3.html":[1,0,1,2],
-"classMeshCellBase__3.html#a1e5a289fcd823ae9c5f76cbae0153917":[1,0,1,2,12],
-"classMeshCellBase__3.html#a240af8b65b0a350eb0b96e3fd6819764":[1,0,1,2,11],
-"classMeshCellBase__3.html#a252c8665018b4af31d8ce3e89fecdf35":[1,0,1,2,9],
-"classMeshCellBase__3.html#a2c8e8ff436eaecd8ce44dc5550b74d18":[1,0,1,2,2],
-"classMeshCellBase__3.html#a3e07014c602b84433793c23d95057c95":[1,0,1,2,17],
-"classMeshCellBase__3.html#a5d535cf3b5a4f52dcaac926e29613596":[1,0,1,2,5],
-"classMeshCellBase__3.html#a65a9d9229f31dbc76250f7def07e2ed4":[1,0,1,2,14],
-"classMeshCellBase__3.html#a691f35189273073f95d7a2c5fb492317":[1,0,1,2,19],
-"classMeshCellBase__3.html#a7085ef7e2f47d14dbd4d20af52965462":[1,0,1,2,1],
-"classMeshCellBase__3.html#a82d5cf14ca5ae289eb2bd8ad48fb8d90":[1,0,1,2,7],
-"classMeshCellBase__3.html#a8b30589496761cc637d3b88e08912b6d":[1,0,1,2,13],
-"classMeshCellBase__3.html#a8d4190fb1260c909e9d69a61e51c09c0":[1,0,1,2,18],
-"classMeshCellBase__3.html#a9c32a0c6270176273cdabd84e79e4daf":[1,0,1,2,4],
-"classMeshCellBase__3.html#aa8881f0d3b648bd95e7587a9e3fdf747":[1,0,1,2,0],
-"classMeshCellBase__3.html#aba4cf8df1f35b5536b3c7b87ba9142e7":[1,0,1,2,15],
-"classMeshCellBase__3.html#abff8d9bf46d76ffd606aed04f848b38b":[1,0,1,2,8],
-"classMeshCellBase__3.html#ac39a69ed4506ab8e8f3c787b38d19dd7":[1,0,1,2,3],
-"classMeshCellBase__3.html#ae79a609f04699112fb97706d2fb008b7":[1,0,1,2,6],
-"classMeshCellBase__3.html#af3016b81eed56dc896a5fbe0ad754212":[1,0,1,2,16],
-"classMeshCellBase__3.html#af49971996bab148cb98f1e2fc633c48f":[1,0,1,2,10],
+"classInitialPointsGenerator__3.html":[1,0,1,1],
+"classInitialPointsGenerator__3.html#a1c795803bf7f5ababd5ace85480bb934":[1,0,1,1,2],
+"classInitialPointsGenerator__3.html#a60a183ca1c26e301a868478457496ef7":[1,0,1,1,0],
+"classInitialPointsGenerator__3.html#adcc41d2f0f7f1542301dec684a3590cd":[1,0,1,1,1],
+"classIntersectionGeometricTraits__3.html":[1,0,1,2],
+"classIntersectionGeometricTraits__3.html#a0504f5625b1aa2e475fe31686b38afc8":[1,0,1,2,2],
+"classIntersectionGeometricTraits__3.html#a30502ace5406c493b1d2b1f147ef4850":[1,0,1,2,4],
+"classIntersectionGeometricTraits__3.html#a4eaf6c2bb851a932b50ae237a1be1416":[1,0,1,2,5],
+"classIntersectionGeometricTraits__3.html#a572393696b038882cf2653179c5eef95":[1,0,1,2,6],
+"classIntersectionGeometricTraits__3.html#a5b50b9166990edb9a59a06bd7f168250":[1,0,1,2,0],
+"classIntersectionGeometricTraits__3.html#aa197980bca0213b46280a6fed030485f":[1,0,1,2,3],
+"classIntersectionGeometricTraits__3.html#ae0e03751a406a5c035f342d1db5bf27a":[1,0,1,2,1],
+"classMeshCellBase__3.html":[1,0,1,3],
+"classMeshCellBase__3.html#a1e5a289fcd823ae9c5f76cbae0153917":[1,0,1,3,12],
+"classMeshCellBase__3.html#a240af8b65b0a350eb0b96e3fd6819764":[1,0,1,3,11],
+"classMeshCellBase__3.html#a252c8665018b4af31d8ce3e89fecdf35":[1,0,1,3,9],
+"classMeshCellBase__3.html#a2c8e8ff436eaecd8ce44dc5550b74d18":[1,0,1,3,2],
+"classMeshCellBase__3.html#a3e07014c602b84433793c23d95057c95":[1,0,1,3,17],
+"classMeshCellBase__3.html#a5d535cf3b5a4f52dcaac926e29613596":[1,0,1,3,5],
+"classMeshCellBase__3.html#a65a9d9229f31dbc76250f7def07e2ed4":[1,0,1,3,14],
+"classMeshCellBase__3.html#a691f35189273073f95d7a2c5fb492317":[1,0,1,3,19],
+"classMeshCellBase__3.html#a7085ef7e2f47d14dbd4d20af52965462":[1,0,1,3,1],
+"classMeshCellBase__3.html#a82d5cf14ca5ae289eb2bd8ad48fb8d90":[1,0,1,3,7],
+"classMeshCellBase__3.html#a8b30589496761cc637d3b88e08912b6d":[1,0,1,3,13],
+"classMeshCellBase__3.html#a8d4190fb1260c909e9d69a61e51c09c0":[1,0,1,3,18],
+"classMeshCellBase__3.html#a9c32a0c6270176273cdabd84e79e4daf":[1,0,1,3,4],
+"classMeshCellBase__3.html#aa8881f0d3b648bd95e7587a9e3fdf747":[1,0,1,3,0],
+"classMeshCellBase__3.html#aba4cf8df1f35b5536b3c7b87ba9142e7":[1,0,1,3,15],
+"classMeshCellBase__3.html#abff8d9bf46d76ffd606aed04f848b38b":[1,0,1,3,8],
+"classMeshCellBase__3.html#ac39a69ed4506ab8e8f3c787b38d19dd7":[1,0,1,3,3],
+"classMeshCellBase__3.html#ae79a609f04699112fb97706d2fb008b7":[1,0,1,3,6],
+"classMeshCellBase__3.html#af3016b81eed56dc896a5fbe0ad754212":[1,0,1,3,16],
+"classMeshCellBase__3.html#af49971996bab148cb98f1e2fc633c48f":[1,0,1,3,10],
 "classMeshCellCriteria__3.html":[1,0,0,0],
 "classMeshCellCriteria__3.html#a5c4da00f015aad5e7c1c30a040969569":[1,0,0,0,0],
 "classMeshCellCriteria__3.html#a9834b36e2ca7474b746a16e221081d5f":[1,0,0,0,3],
@@ -195,11 +198,11 @@ var NAVTREEINDEX0 =
 "classMeshCriteria__3.html#a1b268ffc1370ba4648ebc9eee854b2c4":[1,0,0,1,3],
 "classMeshCriteria__3.html#a8816863dce0c74bb3da040adf81ed55c":[1,0,0,1,1],
 "classMeshCriteria__3.html#a9d0b2c6a522a2e444b3b183322166665":[1,0,0,1,2],
-"classMeshDomainField__3.html":[1,0,1,3],
-"classMeshDomainField__3.html#a0b438d9d8866c0cc9ac3337da37008b2":[1,0,1,3,0],
-"classMeshDomainField__3.html#a48234956569cf29d341ac048d5640961":[1,0,1,3,3],
-"classMeshDomainField__3.html#a7425b4d0d6cc0e0e71dfa4163f037281":[1,0,1,3,2],
-"classMeshDomainField__3.html#a91b9b68a2a4296ef8f75017dcc72e1db":[1,0,1,3,1],
+"classMeshDomainField__3.html":[1,0,1,4],
+"classMeshDomainField__3.html#a0b438d9d8866c0cc9ac3337da37008b2":[1,0,1,4,0],
+"classMeshDomainField__3.html#a48234956569cf29d341ac048d5640961":[1,0,1,4,3],
+"classMeshDomainField__3.html#a7425b4d0d6cc0e0e71dfa4163f037281":[1,0,1,4,2],
+"classMeshDomainField__3.html#a91b9b68a2a4296ef8f75017dcc72e1db":[1,0,1,4,1],
 "classMeshDomainWithFeatures__3.html":[1,0,0,4],
 "classMeshDomainWithFeatures__3.html#a03644f9a161e0554008b8e9e8ed12b17":[1,0,0,4,14],
 "classMeshDomainWithFeatures__3.html#a0401c7a0942686c51e14e43837f945e6":[1,0,0,4,2],
@@ -246,8 +249,5 @@ var NAVTREEINDEX0 =
 "classMeshEdgeCriteria__3.html#a795ddd08538ed89078398c76f9c3919a":[1,0,0,5,2],
 "classMeshEdgeCriteria__3.html#aaee8bb7cf5fe1f15a2feabbac44d517b":[1,0,0,5,0],
 "classMeshEdgeCriteria__3.html#abcafa1ddf6efff30f16ecc20e8053d2e":[1,0,0,5,4],
-"classMeshEdgeCriteria__3.html#abda226ec819332ac1a69a97f3759f1af":[1,0,0,5,3],
-"classMeshEdgeCriteria__3.html#ad6d0c00829f27332881a1164284d7408":[1,0,0,5,1],
-"classMeshFacetCriteria__3.html":[1,0,0,6],
-"classMeshFacetCriteria__3.html#a2f4c1a086e867ecaf8fbb2c4019be484":[1,0,0,6,5]
+"classMeshEdgeCriteria__3.html#abda226ec819332ac1a69a97f3759f1af":[1,0,0,5,3]
 };
