@@ -1,5 +1,8 @@
 var NAVTREEINDEX1 =
 {
+"index.html":[0],
+"index.html#Nef_3ConstructionandComparison":[0,4,0],
+"index.html#Nef_3Definition":[0,1],
 "index.html#Nef_3DrawNefPolyhedron":[0,4,6],
 "index.html#Nef_3Example":[0,4],
 "index.html#Nef_3ExploringaSphereMap":[0,6,0],
@@ -16,6 +19,5 @@ var NAVTREEINDEX1 =
 "index.html#sectoinRegularized":[0,3],
 "index.html#subsectionNef_3ShellExploration":[0,6,1],
 "modules.html":[1],
-"namespaceCGAL.html":[3,0],
 "pages.html":[]
 };
