@@ -1,14 +1,14 @@
 var group__nt__rrational =
 [
-    [ "Rational_traits", "classCGAL_1_1Rational__traits.html", [
+    [ "CGAL::Rational_traits< NT >", "classCGAL_1_1Rational__traits.html", [
       [ "RT", "classCGAL_1_1Rational__traits.html#ade08a9f051b95ed2de96da69a90377c3", null ],
       [ "denominator", "classCGAL_1_1Rational__traits.html#a61f43e34a39b92bb04237721272987fd", null ],
-      [ "make_rational", "classCGAL_1_1Rational__traits.html#ac9948947523f60516288944a37a85556", null ],
-      [ "make_rational", "classCGAL_1_1Rational__traits.html#ac3f0ef292e9ea9c44afd762c0f0072f0", null ],
-      [ "make_rational", "classCGAL_1_1Rational__traits.html#a182c967765055c50b473ebd9ecaf4c13", null ],
       [ "make_rational", "classCGAL_1_1Rational__traits.html#ae778b46cc2e91f3765e83b4a6002e661", null ],
+      [ "make_rational", "classCGAL_1_1Rational__traits.html#ac9948947523f60516288944a37a85556", null ],
+      [ "make_rational", "classCGAL_1_1Rational__traits.html#a182c967765055c50b473ebd9ecaf4c13", null ],
+      [ "make_rational", "classCGAL_1_1Rational__traits.html#ac3f0ef292e9ea9c44afd762c0f0072f0", null ],
       [ "numerator", "classCGAL_1_1Rational__traits.html#a4fc33a9ace726befaf39f07fc2d19375", null ]
     ] ],
-    [ "simplest_rational_in_interval", "group__nt__rrational.html#ga17858fbeefd20878349736beb169df97", null ],
-    [ "to_rational", "group__nt__rrational.html#gaac65e38f22218d07ff294d8bf72790a1", null ]
+    [ "CGAL::simplest_rational_in_interval", "group__nt__rrational.html#ga17858fbeefd20878349736beb169df97", null ],
+    [ "CGAL::to_rational", "group__nt__rrational.html#gaac65e38f22218d07ff294d8bf72790a1", null ]
 ];
\ No newline at end of file
