@@ -1,14 +1,14 @@
 var group__PkgPartition2FunctionObjectClasses =
 [
-    [ "Is_convex_2", "classCGAL_1_1Is__convex__2.html", [
+    [ "CGAL::Is_convex_2< Traits >", "classCGAL_1_1Is__convex__2.html", [
       [ "Is_convex_2", "classCGAL_1_1Is__convex__2.html#a5c45108a394c170405919f23ef507497", null ],
       [ "operator()", "classCGAL_1_1Is__convex__2.html#aec5182e5091623055436b93a82845add", null ]
     ] ],
-    [ "Is_vacuously_valid", "classCGAL_1_1Is__vacuously__valid.html", [
+    [ "CGAL::Is_vacuously_valid< Traits >", "classCGAL_1_1Is__vacuously__valid.html", [
       [ "Is_vacuously_valid", "classCGAL_1_1Is__vacuously__valid.html#aa201da510989ce2e59ab0b8d278d0078", null ],
       [ "operator()", "classCGAL_1_1Is__vacuously__valid.html#a62ae10de72d696b55528a07f3746043b", null ]
     ] ],
-    [ "Is_y_monotone_2", "classCGAL_1_1Is__y__monotone__2.html", [
+    [ "CGAL::Is_y_monotone_2< Traits >", "classCGAL_1_1Is__y__monotone__2.html", [
       [ "Is_y_monotone_2", "classCGAL_1_1Is__y__monotone__2.html#a64852cc2facafafaecc4ca7ec2555454", null ],
       [ "operator()", "classCGAL_1_1Is__y__monotone__2.html#a4fc5116c95128ebbbdfe2f192bd77f79", null ]
     ] ]
