@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0.3 - 2D Periodic Triangulations", "index.html", [
+  [ "CGAL 6.1 - 2D Periodic Triangulations", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Bibliography", "citelist.html", null ],
@@ -36,7 +36,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Periodic_2_triangulation_2_2draw_periodic_2_triangulation_2_8cpp-example.html",
-"index.html#P2T2ExampleAddingHandles"
+"index.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
