@@ -42,26 +42,26 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__offset__2.html":[1,0,1,1],
 "classCGAL_1_1Periodic__2__triangulation__2.html":[1,0,1,2],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a04472945eac034df894ea298eb1e12e8":[1,0,1,2,64],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a060a17079d2af889889f748e35cfea5d":[1,0,1,2,96],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a06a61efed5c17690630561be9743b215":[1,0,1,2,94],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a060a17079d2af889889f748e35cfea5d":[1,0,1,2,98],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a06a61efed5c17690630561be9743b215":[1,0,1,2,96],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a0b11751aa806fdcc7b7167b8de51a6d0":[1,0,1,2,85],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a0b6adbd05f0f6344634adbc4c663bb2f":[1,0,1,2,113],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a0b6adbd05f0f6344634adbc4c663bb2f":[1,0,1,2,115],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a0b9c475473dbf401ba43918e13740bd3":[1,0,1,2,87],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a0b9f8cc07bc4336261a0f81936b6001c":[1,0,1,2,92],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a0b9f8cc07bc4336261a0f81936b6001c":[1,0,1,2,94],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a0d077ac57d26732a7915820f11ff531b":[1,0,1,2,28],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a0ef4b1266eed434f0ca1563e3adcc67c":[1,0,1,2,7],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a14640d6859242c8c0364515e5983a6cc":[1,0,1,2,106],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a1527c8afb9bef24e525d2162df184cad":[1,0,1,2,101],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a14640d6859242c8c0364515e5983a6cc":[1,0,1,2,108],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a1527c8afb9bef24e525d2162df184cad":[1,0,1,2,103],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a18c0afb6de36bcdf6c8ad285350facc5":[1,0,1,2,50],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a1c2ecb4b6ee87c72b518a02842602777":[1,0,1,2,44],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a1c549f1756d07d1feedc9a28f20378e6":[1,0,1,2,34],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a1d72b6e5ced525c86656cccba579085c":[1,0,1,2,112],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a1e9c60f7c9844a33edff96b95aeb6c85":[1,0,1,2,108],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a1f61d18e992af64f78a6edaee7b39ea4":[1,0,1,2,98],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a1d72b6e5ced525c86656cccba579085c":[1,0,1,2,114],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a1e9c60f7c9844a33edff96b95aeb6c85":[1,0,1,2,110],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a1f61d18e992af64f78a6edaee7b39ea4":[1,0,1,2,100],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a217b56b0d5a8c222573f520a69a696ee":[1,0,1,2,16],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a26f95ec77dfd20b2fca3a7538ba822e9":[1,0,1,2,12],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a2a093ffaeed515ad25970e014aabe172":[1,0,1,2,25],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a2b3ca0261dbf3ccce4aec15d13a6aaad":[1,0,1,2,104],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a2b3ca0261dbf3ccce4aec15d13a6aaad":[1,0,1,2,106],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a2ded6dd34ca5659d51242381eea358c9":[1,0,1,2,56],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a2e7e515df84fe16b8cf0b7e20a885cdc":[1,0,1,2,69],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a316c2075592f8ff1a892775ee30d7cf6":[1,0,1,2,81],
@@ -71,16 +71,17 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#a34f68d30e131f23a437ab43313e491b0":[1,0,1,2,73],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a35e8ca131d61b9c035c7ac29b9614c9c":[1,0,1,2,37],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a35ec6b23ee9af3f9cbb86bbc45dfbf35":[1,0,1,2,26],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a38bbc77e2c97930a336e1ba808680fa7":[1,0,1,2,109],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a38bbc77e2c97930a336e1ba808680fa7":[1,0,1,2,111],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a3d04fdf964787213090155b4a60181ef":[1,0,1,2,48],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a3ea97c9abb37a11adeee218918a09696":[1,0,1,2,107],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a3ea97c9abb37a11adeee218918a09696":[1,0,1,2,109],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a402f6d65e818d30c7245d16f25ed16ad":[1,0,1,2,67],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a405e809cac8f7754216da3a339114d91":[1,0,1,2,14],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a40eca570d53947192c31dcd90ee3f997":[1,0,1,2,100],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a40eca570d53947192c31dcd90ee3f997":[1,0,1,2,102],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a41af9d8c62fac4cecfdcf649823aaf0a":[1,0,1,2,79],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a420493d5ba78daa8cdeef1be51a70d18":[1,0,1,2,8],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a4275f3fc28498322590a090777aaa27b":[1,0,1,2,63],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a47cdc7fdd3ff0e52738edaa769ce79dc":[1,0,1,2,57],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a49eafd653c048f98f8d671690555f668":[1,0,1,2,93],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a4d430d7a064cb69747d12bf457bb4e34":[1,0,1,2,33],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a4d430d7a064cb69747d12bf457bb4e34a6665019f627d7eac50717c70129ed098":[1,0,1,2,33,1],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a4d430d7a064cb69747d12bf457bb4e34a79bfbe67dbcd1336d3eee428704186a5":[1,0,1,2,33,0],
@@ -93,7 +94,7 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#a5c72444beaaa8b21ea4952b18b7b9033":[1,0,1,2,31],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a5dd5f37123fd6036efac066caadbea75":[1,0,1,2,10],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a623385e8969628e1f35052c3056138cf":[1,0,1,2,17],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a63646ae43f76fc1e0cd6915cc1e7488a":[1,0,1,2,99],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a63646ae43f76fc1e0cd6915cc1e7488a":[1,0,1,2,101],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a6396dce2195a599e28e23636c9d6aa38":[1,0,1,2,89],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a66e3f7c70f8f269f1e0f1ced801a1228":[1,0,1,2,38],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a69ece036ad0bda74bad5c4700821a047":[1,0,1,2,61],
@@ -109,15 +110,15 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#a7262186403a9101fef5d7d0d753ad77da93741e5589eebbc9a6be6afc99b682c5":[1,0,1,2,32,0],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a7262186403a9101fef5d7d0d753ad77daf2f86d31e148354a2bc3b8441a60a669":[1,0,1,2,32,3],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a785ea610b603b3b46432a4f9f81ab487":[1,0,1,2,52],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a7d0970c780da0bc2ef511650749538db":[1,0,1,2,97],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a7d0970c780da0bc2ef511650749538db":[1,0,1,2,99],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a7d71fa08fe049290396b1adfdcf5cd52":[1,0,1,2,2],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a8263cfb2d6fdb66cf6602ff2ff827fe2":[1,0,1,2,0],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a8937e8d64de92ee8fc5e157570bcaa6d":[1,0,1,2,53],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a8f092daa5b7120627b670446d237985c":[1,0,1,2,43],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a928fe65cfc4621053029b98e988a9d06":[1,0,1,2,6],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a94c3134a0b73077ecde32187d9c3de07":[1,0,1,2,40],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a960701c40fd4b5e719649b06b806d2e8":[1,0,1,2,103],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a9918a5210e8f2450c65e098e729d290b":[1,0,1,2,111],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a960701c40fd4b5e719649b06b806d2e8":[1,0,1,2,105],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a9918a5210e8f2450c65e098e729d290b":[1,0,1,2,113],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a9b244b7bb832e87fcd2f35836bf713ef":[1,0,1,2,72],
 "classCGAL_1_1Periodic__2__triangulation__2.html#aa2a69564ca6962d6ef29846db33158e3":[1,0,1,2,91],
 "classCGAL_1_1Periodic__2__triangulation__2.html#aa5ce096101abb3ebfd7b60b490ab1bf5":[1,0,1,2,60],
@@ -127,19 +128,20 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#ab037f5564a6b3f98a60db6de52e56fdc":[1,0,1,2,20],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ab10f412ca47129b067c67c5eb5d2780e":[1,0,1,2,78],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ab45c9e3f8b5fda944f17a97a953f93ef":[1,0,1,2,45],
-"classCGAL_1_1Periodic__2__triangulation__2.html#ab72b975f18a9b39dc15bc154430fe9bb":[1,0,1,2,95],
+"classCGAL_1_1Periodic__2__triangulation__2.html#ab72b975f18a9b39dc15bc154430fe9bb":[1,0,1,2,97],
+"classCGAL_1_1Periodic__2__triangulation__2.html#ab9633e9134f1f99c13be9ee97239be53":[1,0,1,2,92],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abbbb71864b0c6785564a67ab5e713317":[1,0,1,2,19],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abc024d3aeeea49fde0f114ae892f0e0e":[1,0,1,2,62],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abfa83d109e9a2608d1116495a1d048fd":[1,0,1,2,82],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abfd5e78c312b58c4dc0b8eeb5f83decb":[1,0,1,2,30],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac26888c1f1c38f0a9807802057ae2c29":[1,0,1,2,86],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac7e52719d9a4d39bbcba45fa20a8f907":[1,0,1,2,29],
-"classCGAL_1_1Periodic__2__triangulation__2.html#ac7ed2f011842355b5755741b02722724":[1,0,1,2,110],
+"classCGAL_1_1Periodic__2__triangulation__2.html#ac7ed2f011842355b5755741b02722724":[1,0,1,2,112],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac852932d4386c6ad317154d0ce347fd9":[1,0,1,2,68],
-"classCGAL_1_1Periodic__2__triangulation__2.html#ac8b35e267db25beab4be97c747fe4329":[1,0,1,2,102],
+"classCGAL_1_1Periodic__2__triangulation__2.html#ac8b35e267db25beab4be97c747fe4329":[1,0,1,2,104],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac9fd79dbd0298e5e0987594a265383f1":[1,0,1,2,66],
 "classCGAL_1_1Periodic__2__triangulation__2.html#acb1c89e24081ca23f37b5ce2d426b462":[1,0,1,2,41],
-"classCGAL_1_1Periodic__2__triangulation__2.html#acebdb6d3b1e4daa6d92ba130e62d0657":[1,0,1,2,105],
+"classCGAL_1_1Periodic__2__triangulation__2.html#acebdb6d3b1e4daa6d92ba130e62d0657":[1,0,1,2,107],
 "classCGAL_1_1Periodic__2__triangulation__2.html#acf2a664ccbc0145f564b3bee1715fa33":[1,0,1,2,84],
 "classCGAL_1_1Periodic__2__triangulation__2.html#acf8e2bcf27f50a38d57ba232471f9674":[1,0,1,2,35],
 "classCGAL_1_1Periodic__2__triangulation__2.html#acf9971f3bb7efc8969adcece9ecfcb61":[1,0,1,2,59],
@@ -151,7 +153,7 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#ae0ab4958fda18b92080c54b064c47717":[1,0,1,2,18],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ae0c5f6a41ec6e7e946525a3ae183459c":[1,0,1,2,65],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ae45894d98f16d5fdf827c098b3a30125":[1,0,1,2,15],
-"classCGAL_1_1Periodic__2__triangulation__2.html#ae4d4fad75ed425faf754b8fa3a9fddf3":[1,0,1,2,93],
+"classCGAL_1_1Periodic__2__triangulation__2.html#ae4d4fad75ed425faf754b8fa3a9fddf3":[1,0,1,2,95],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ae8299fa6d4f126816590cdd198963ce7":[1,0,1,2,39],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ae917d8057fbca176816fe65e51ec6326":[1,0,1,2,70],
 "classCGAL_1_1Periodic__2__triangulation__2.html#aec0e8cda67134a40d53d2d77d67b5450":[1,0,1,2,13],
@@ -247,7 +249,5 @@ var NAVTREEINDEX0 =
 "group__PkgPeriodic2Triangulation2MainClasses.html":[1,0,1],
 "group__PkgPeriodic2Triangulation2Ref.html":[1,0],
 "group__PkgPeriodic2Triangulation2TraitsClasses.html":[1,0,2],
-"group__PkgPeriodic2Triangulation2VertexFaceClasses.html":[1,0,3],
-"index.html":[0],
-"index.html":[]
+"group__PkgPeriodic2Triangulation2VertexFaceClasses.html":[1,0,3]
 };
