@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0.3 - 3D Periodic Triangulations", "index.html", [
+  [ "CGAL 6.1 - 3D Periodic Triangulations", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Bibliography", "citelist.html", null ],
@@ -36,7 +36,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Periodic_3_triangulation_3_2colored_vertices_8cpp-example.html",
-"classPeriodic__3DelaunayTriangulationTraits__3.html#ac9be24d712f99b7312f53350ecda3206"
+"classPeriodic__3DelaunayTriangulationTraits__3.html#aa389978c75b6d48b0292fb051318a59e"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
