@@ -1,10 +1,10 @@
 var examples =
 [
-    [ "Point_set_3/draw_point_set_3.cpp", "Point_set_3_2draw_point_set_3_8cpp-example.html", null ],
     [ "Point_set_3/point_set.cpp", "Point_set_3_2point_set_8cpp-example.html", null ],
-    [ "Point_set_3/point_set_advanced.cpp", "Point_set_3_2point_set_advanced_8cpp-example.html", null ],
-    [ "Point_set_3/point_set_algo.cpp", "Point_set_3_2point_set_algo_8cpp-example.html", null ],
     [ "Point_set_3/point_set_property.cpp", "Point_set_3_2point_set_property_8cpp-example.html", null ],
+    [ "Point_set_3/point_set_algo.cpp", "Point_set_3_2point_set_algo_8cpp-example.html", null ],
+    [ "Point_set_3/point_set_read_xyz.cpp", "Point_set_3_2point_set_read_xyz_8cpp-example.html", null ],
     [ "Point_set_3/point_set_read_ply.cpp", "Point_set_3_2point_set_read_ply_8cpp-example.html", null ],
-    [ "Point_set_3/point_set_read_xyz.cpp", "Point_set_3_2point_set_read_xyz_8cpp-example.html", null ]
+    [ "Point_set_3/point_set_advanced.cpp", "Point_set_3_2point_set_advanced_8cpp-example.html", null ],
+    [ "Point_set_3/draw_point_set_3.cpp", "Point_set_3_2draw_point_set_3_8cpp-example.html", null ]
 ];
\ No newline at end of file
