@@ -12,6 +12,8 @@ var NAVTREEINDEX0 =
 "Point_set_processing_3_2jet_smoothing_example_8cpp-example.html":[4,15],
 "Point_set_processing_3_2normals_example_8cpp-example.html":[4,16],
 "Point_set_processing_3_2orient_scanlines_example_8cpp-example.html":[4,17],
+"Point_set_processing_3_2poisson_eliminate_example_8cpp-example.html":[4,24],
+"Point_set_processing_3_2poisson_eliminate_from_mesh_example_8cpp-example.html":[4,25],
 "Point_set_processing_3_2read_las_example_8cpp-example.html":[4,2],
 "Point_set_processing_3_2read_ply_points_with_colors_example_8cpp-example.html":[4,1],
 "Point_set_processing_3_2read_write_xyz_point_set_example_8cpp-example.html":[4,0],
@@ -51,27 +53,28 @@ var NAVTREEINDEX0 =
 "group__PkgPointSetProcessing3Algorithms.html#ga2531a1366bea67edef99e87d6b8819ec":[1,0,0,3],
 "group__PkgPointSetProcessing3Algorithms.html#ga258a9b3a40d10533f8f01d64b4e91eca":[1,0,0,7],
 "group__PkgPointSetProcessing3Algorithms.html#ga28fe6443638647be0874b283085eb2cd":[1,0,0,10],
-"group__PkgPointSetProcessing3Algorithms.html#ga2d2e21a8a49472a5ed1254f42978608e":[1,0,0,20],
+"group__PkgPointSetProcessing3Algorithms.html#ga2d2e21a8a49472a5ed1254f42978608e":[1,0,0,21],
+"group__PkgPointSetProcessing3Algorithms.html#ga2d73d46ca766656a219bf5e6045b837a":[1,0,0,19],
 "group__PkgPointSetProcessing3Algorithms.html#ga3420351b6d3fad079d13f894f42e9d03":[1,0,0,14],
-"group__PkgPointSetProcessing3Algorithms.html#ga4be2d94f1791d24b8ba0107bc33ad6dc":[1,0,0,19],
-"group__PkgPointSetProcessing3Algorithms.html#ga50c708584a8219847ce04f636dcad4b3":[1,0,0,22],
+"group__PkgPointSetProcessing3Algorithms.html#ga4be2d94f1791d24b8ba0107bc33ad6dc":[1,0,0,20],
+"group__PkgPointSetProcessing3Algorithms.html#ga50c708584a8219847ce04f636dcad4b3":[1,0,0,23],
 "group__PkgPointSetProcessing3Algorithms.html#ga6e2493a424482f07d766f12fedefedd0":[1,0,0,11],
 "group__PkgPointSetProcessing3Algorithms.html#ga721aeb7af4b2d31e08e75bc5d53303cf":[1,0,0,18],
 "group__PkgPointSetProcessing3Algorithms.html#ga771cd5e756daee1deab68c8bf65d8058":[1,0,0,6],
 "group__PkgPointSetProcessing3Algorithms.html#ga7757ef9b3900e42fde26f5a0ac56e20f":[1,0,0,13],
-"group__PkgPointSetProcessing3Algorithms.html#ga79ee6fb524ec53b9b85eb32e7ae56ca8":[1,0,0,28],
+"group__PkgPointSetProcessing3Algorithms.html#ga79ee6fb524ec53b9b85eb32e7ae56ca8":[1,0,0,29],
 "group__PkgPointSetProcessing3Algorithms.html#ga8712cbc64f1cfd4dd2f61049a24b90f4":[1,0,0,8],
 "group__PkgPointSetProcessing3Algorithms.html#ga8b330397a3fb68176c851fd7d214b513":[1,0,0,4],
 "group__PkgPointSetProcessing3Algorithms.html#ga8c6af1df54e336bd0b9a2de6b909bccf":[1,0,0,9],
 "group__PkgPointSetProcessing3Algorithms.html#ga96a3738be3b2b9bd1587af78ae10e67a":[1,0,0,16],
-"group__PkgPointSetProcessing3Algorithms.html#gaa849870cbc74cee3f2f536c70aadf976":[1,0,0,21],
-"group__PkgPointSetProcessing3Algorithms.html#gaab0fd78ef3e46c4256e9a1145a9d118e":[1,0,0,25],
-"group__PkgPointSetProcessing3Algorithms.html#gac57ce53e3249a66e4c19e85f439ff01e":[1,0,0,27],
+"group__PkgPointSetProcessing3Algorithms.html#gaa849870cbc74cee3f2f536c70aadf976":[1,0,0,22],
+"group__PkgPointSetProcessing3Algorithms.html#gaab0fd78ef3e46c4256e9a1145a9d118e":[1,0,0,26],
+"group__PkgPointSetProcessing3Algorithms.html#gac57ce53e3249a66e4c19e85f439ff01e":[1,0,0,28],
 "group__PkgPointSetProcessing3Algorithms.html#gaea71f355f996784df500a2a58809b9c5":[1,0,0,5],
-"group__PkgPointSetProcessing3Algorithms.html#gaebbc04909dfd575a94f932c8d3bacdce":[1,0,0,24],
-"group__PkgPointSetProcessing3Algorithms.html#gaf1e415a68652535215c60bc52ebacca3":[1,0,0,26],
+"group__PkgPointSetProcessing3Algorithms.html#gaebbc04909dfd575a94f932c8d3bacdce":[1,0,0,25],
+"group__PkgPointSetProcessing3Algorithms.html#gaf1e415a68652535215c60bc52ebacca3":[1,0,0,27],
 "group__PkgPointSetProcessing3Algorithms.html#gaf45220685eff6649d29f600eb66fb6c1":[1,0,0,12],
-"group__PkgPointSetProcessing3Algorithms.html#gafc3627234666e1fb458e9387e9d5f3c6":[1,0,0,23],
+"group__PkgPointSetProcessing3Algorithms.html#gafc3627234666e1fb458e9387e9d5f3c6":[1,0,0,24],
 "group__PkgPointSetProcessing3IO.html":[1,0,1],
 "group__PkgPointSetProcessing3IO.html#ga5822feba4449f0492363611620b877c0":[1,0,1,1],
 "group__PkgPointSetProcessing3IO.html#ga8fac388459c5cf96bf11ce3b4e0459c1":[1,0,1,0],
@@ -126,6 +129,8 @@ var NAVTREEINDEX0 =
 "index.html#Point_set_processing_3Example_outlier_removal":[0,7,0],
 "index.html#Point_set_processing_3Example_ply_read":[0,2,1,1],
 "index.html#Point_set_processing_3Example_ply_write":[0,2,1,0],
+"index.html#Point_set_processing_3Example_poisson_elimination":[0,8,3,0],
+"index.html#Point_set_processing_3Example_poisson_elimination_on_mesh":[0,8,3,1],
 "index.html#Point_set_processing_3Example_scale_estimation_global":[0,4,0],
 "index.html#Point_set_processing_3Example_scale_estimation_local":[0,4,1],
 "index.html#Point_set_processing_3Example_scanline_normals":[0,11,1,0],
@@ -160,6 +165,7 @@ var NAVTREEINDEX0 =
 "index.html#Point_set_processing_3Outdated":[0,1,2],
 "index.html#Point_set_processing_3OutlierRemoval":[0,7],
 "index.html#Point_set_processing_3Points_io":[0,2,0],
+"index.html#Point_set_processing_3PoissonElimination":[0,8,3],
 "index.html#Point_set_processing_3Properties_io":[0,2,1],
 "index.html#Point_set_processing_3PropertyMaps":[0,1,1],
 "index.html#Point_set_processing_3Registration":[0,5],
