@@ -2,9 +2,11 @@ var annotated =
 [
     [ "CGAL", null, [
       [ "General_polygon_with_holes_2", "classCGAL_1_1General__polygon__with__holes__2.html", "classCGAL_1_1General__polygon__with__holes__2" ],
+      [ "Multipolygon_with_holes_2", "classCGAL_1_1Multipolygon__with__holes__2.html", "classCGAL_1_1Multipolygon__with__holes__2" ],
       [ "Polygon_2", "classCGAL_1_1Polygon__2.html", "classCGAL_1_1Polygon__2" ],
       [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html", "classCGAL_1_1Polygon__with__holes__2" ]
     ] ],
     [ "GeneralPolygonWithHoles_2", "classGeneralPolygonWithHoles__2.html", "classGeneralPolygonWithHoles__2" ],
+    [ "MultipolygonWithHoles_2", "classMultipolygonWithHoles__2.html", "classMultipolygonWithHoles__2" ],
     [ "PolygonTraits_2", "classPolygonTraits__2.html", "classPolygonTraits__2" ]
 ];
\ No newline at end of file
