@@ -1,6 +1,6 @@
 var modules =
 [
-    [ "2D Polygon Reference", "group__PkgPolygon2Ref.html", "group__PkgPolygon2Ref" ],
+    [ "Reference Manual", "group__PkgPolygon2Ref.html", "group__PkgPolygon2Ref" ],
     [ "Draw a 2D Polygon with Holes", "group__PkgDrawPolygonWithHoles2.html", "group__PkgDrawPolygonWithHoles2" ],
     [ "Draw a 2D Multipolygon with Holes", "group__PkgDrawMultipolygonWithHoles2.html", "group__PkgDrawMultipolygonWithHoles2" ]
 ];
\ No newline at end of file
