@@ -5,8 +5,5 @@ var classPMPSelfIntersectionTraits =
     [ "Do_intersect_3", "classPMPSelfIntersectionTraits.html#a0cd254de374b3b52dfa55268c99de276", null ],
     [ "Point_3", "classPMPSelfIntersectionTraits.html#adbd168594bb0dda280073cd886bcae5e", null ],
     [ "Segment_3", "classPMPSelfIntersectionTraits.html#a66f3a6d91df8b9708695119b8d588003", null ],
-    [ "Triangle_3", "classPMPSelfIntersectionTraits.html#aec3c2d71b0d0197f7b991cf45954a6c5", null ],
-    [ "construct_segment_3_object", "classPMPSelfIntersectionTraits.html#a5acba64c025984743f94c34c22992951", null ],
-    [ "construct_triangle_3_object", "classPMPSelfIntersectionTraits.html#a8ee88a23743b2bcdbc3b423aabea1b5a", null ],
-    [ "do_intersect_3_object", "classPMPSelfIntersectionTraits.html#aa93dab0a75993ba826708b1b4d25c429", null ]
+    [ "Triangle_3", "classPMPSelfIntersectionTraits.html#aec3c2d71b0d0197f7b991cf45954a6c5", null ]
 ];
\ No newline at end of file
