@@ -50,6 +50,8 @@ var examples =
     [ "Polygon_mesh_processing/cc_compatible_orientations.cpp", "Polygon_mesh_processing_2cc_compatible_orientations_8cpp-example.html", null ],
     [ "Polygon_mesh_processing/remesh_planar_patches.cpp", "Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html", null ],
     [ "Polygon_mesh_processing/remesh_almost_planar_patches.cpp", "Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html", null ],
+    [ "Polygon_mesh_processing/acvd_remeshing_example.cpp", "Polygon_mesh_processing_2acvd_remeshing_example_8cpp-example.html", null ],
     [ "Polygon_mesh_processing/sample_example.cpp", "Polygon_mesh_processing_2sample_example_8cpp-example.html", null ],
-    [ "Polygon_mesh_processing/soup_autorefinement.cpp", "Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html", null ]
+    [ "Polygon_mesh_processing/soup_autorefinement.cpp", "Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html", null ],
+    [ "Polygon_mesh_processing/snap_polygon_soup.cpp", "Polygon_mesh_processing_2snap_polygon_soup_8cpp-example.html", null ]
 ];
\ No newline at end of file
