@@ -1,6 +1,7 @@
 var group__PkgPolygonMeshProcessingConcepts =
 [
     [ "PMPAutorefinementVisitor", "classPMPAutorefinementVisitor.html", [
+      [ "delete_triangle", "classPMPAutorefinementVisitor.html#abb941778c6bbe1fdcd2c7fe5d89650ac", null ],
       [ "new_subtriangle", "classPMPAutorefinementVisitor.html#ab2d0abdf3d2e9dc47640ca37f9737055", null ],
       [ "number_of_output_triangles", "classPMPAutorefinementVisitor.html#a2b7130b0c94651e21b6a3c4f2d3ec765", null ],
       [ "verbatim_triangle_copy", "classPMPAutorefinementVisitor.html#a454023769deabacd45540d8a5dcb27ab", null ]
@@ -47,6 +48,7 @@ var group__PkgPolygonMeshProcessingConcepts =
       [ "start_handling_edge_face_intersections", "classPMPCorefinementVisitor.html#a0d160a1573cd93115b300ec86c9221d8", null ],
       [ "start_handling_intersection_of_coplanar_faces", "classPMPCorefinementVisitor.html#ad742db01b774aed6b3edca64e5795ee3", null ],
       [ "start_triangulating_faces", "classPMPCorefinementVisitor.html#adf3a799f88e90df66b9f44468c996bd6", null ],
+      [ "subface_of_coplanar_faces_intersection", "classPMPCorefinementVisitor.html#a1276fd28e4443a9cbfa14c5d64258323", null ],
       [ "triangulating_faces_step", "classPMPCorefinementVisitor.html#a9499eac0ae81a5a469e28c3fdc41e2b0", null ]
     ] ],
     [ "PMPDistanceTraits", "classPMPDistanceTraits.html", [
