@@ -1,6 +1,7 @@
 var NAVTREEINDEX0 =
 {
 "Poisson_surface_reconstruction_3_2poisson_reconstruction_example_8cpp-example.html":[5,29],
+"Polygon_mesh_processing_2acvd_remeshing_example_8cpp-example.html":[5,50],
 "Polygon_mesh_processing_2cc_compatible_orientations_8cpp-example.html":[5,47],
 "Polygon_mesh_processing_2compute_normals_example_8cpp-example.html":[5,9],
 "Polygon_mesh_processing_2compute_normals_example_Polyhedron_8cpp-example.html":[5,27],
@@ -42,10 +43,11 @@ var NAVTREEINDEX0 =
 "Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html":[5,49],
 "Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html":[5,48],
 "Polygon_mesh_processing_2repair_polygon_soup_example_8cpp-example.html":[5,39],
-"Polygon_mesh_processing_2sample_example_8cpp-example.html":[5,50],
+"Polygon_mesh_processing_2sample_example_8cpp-example.html":[5,51],
 "Polygon_mesh_processing_2self_intersections_example_8cpp-example.html":[5,4],
 "Polygon_mesh_processing_2shape_smoothing_example_8cpp-example.html":[5,41],
-"Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html":[5,51],
+"Polygon_mesh_processing_2snap_polygon_soup_8cpp-example.html":[5,53],
+"Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html":[5,52],
 "Polygon_mesh_processing_2stitch_borders_example_8cpp-example.html":[5,8],
 "Polygon_mesh_processing_2tangential_relaxation_example_8cpp-example.html":[5,42],
 "Polygon_mesh_processing_2triangulate_faces_example_8cpp-example.html":[5,11],
@@ -84,20 +86,23 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#afe5b50df0dd0f0ca85fafec145f7823d":[1,0,21,3],
 "classCGAL_1_1Side__of__triangle__mesh.html":[1,0,15,0],
 "classCGAL_1_1Side__of__triangle__mesh.html#a05c896871012c2e0e86fac65db6b5912":[1,0,15,0,3],
-"classCGAL_1_1Side__of__triangle__mesh.html#a0a2b740ebc8f4f7d395cef082aa2a01c":[1,0,15,0,4],
+"classCGAL_1_1Side__of__triangle__mesh.html#a0a2b740ebc8f4f7d395cef082aa2a01c":[1,0,15,0,5],
 "classCGAL_1_1Side__of__triangle__mesh.html#a15c506c6ef97c1f6f9679b61c453eb29":[1,0,15,0,1],
 "classCGAL_1_1Side__of__triangle__mesh.html#a2263b10214e5b5974eda87c4dd58aee7":[1,0,15,0,0],
 "classCGAL_1_1Side__of__triangle__mesh.html#acaf80bc717521b07da96a865352c6b3c":[1,0,15,0,2],
-"classCGAL_1_1Side__of__triangle__mesh.html#ae618cf6fa412ea74219bb7ca3760d311":[1,0,15,0,5],
-"classCGAL_1_1Side__of__triangle__mesh.html#af18f0a7795027cc92a372fa0d9a2710e":[1,0,15,0,6],
+"classCGAL_1_1Side__of__triangle__mesh.html#ae618cf6fa412ea74219bb7ca3760d311":[1,0,15,0,6],
+"classCGAL_1_1Side__of__triangle__mesh.html#af17094431ba27a55d33d1e35ea29aef8":[1,0,15,0,4],
+"classCGAL_1_1Side__of__triangle__mesh.html#af18f0a7795027cc92a372fa0d9a2710e":[1,0,15,0,7],
 "classPMPAutorefinementVisitor.html":[1,0,0,0],
-"classPMPAutorefinementVisitor.html#a2b7130b0c94651e21b6a3c4f2d3ec765":[1,0,0,0,1],
-"classPMPAutorefinementVisitor.html#a454023769deabacd45540d8a5dcb27ab":[1,0,0,0,2],
-"classPMPAutorefinementVisitor.html#ab2d0abdf3d2e9dc47640ca37f9737055":[1,0,0,0,0],
+"classPMPAutorefinementVisitor.html#a2b7130b0c94651e21b6a3c4f2d3ec765":[1,0,0,0,2],
+"classPMPAutorefinementVisitor.html#a454023769deabacd45540d8a5dcb27ab":[1,0,0,0,3],
+"classPMPAutorefinementVisitor.html#ab2d0abdf3d2e9dc47640ca37f9737055":[1,0,0,0,1],
+"classPMPAutorefinementVisitor.html#abb941778c6bbe1fdcd2c7fe5d89650ac":[1,0,0,0,0],
 "classPMPCorefinementVisitor.html":[1,0,0,1],
 "classPMPCorefinementVisitor.html#a02669432c89cfeaa2c69446afda07f1e":[1,0,0,1,32],
 "classPMPCorefinementVisitor.html#a0d160a1573cd93115b300ec86c9221d8":[1,0,0,1,38],
 "classPMPCorefinementVisitor.html#a0da4738da462d803465d09987d315f21":[1,0,0,1,26],
+"classPMPCorefinementVisitor.html#a1276fd28e4443a9cbfa14c5d64258323":[1,0,0,1,41],
 "classPMPCorefinementVisitor.html#a1bc3aa40f990e83bb6b5cd7f6ddffc42":[1,0,0,1,18],
 "classPMPCorefinementVisitor.html#a1ecf573a53a439e94ff33d0619efb390":[1,0,0,1,2],
 "classPMPCorefinementVisitor.html#a2a2d75da057dcdaf3232c579329ad85b":[1,0,0,1,30],
@@ -111,7 +116,7 @@ var NAVTREEINDEX0 =
 "classPMPCorefinementVisitor.html#a7e109ecde7ed610a1af1c53d4d8cffe9":[1,0,0,1,22],
 "classPMPCorefinementVisitor.html#a8a16fd716c8be00a13ead5c7b6656f23":[1,0,0,1,14],
 "classPMPCorefinementVisitor.html#a8bc4cb77915694e7a3dc6428305323d8":[1,0,0,1,36],
-"classPMPCorefinementVisitor.html#a9499eac0ae81a5a469e28c3fdc41e2b0":[1,0,0,1,41],
+"classPMPCorefinementVisitor.html#a9499eac0ae81a5a469e28c3fdc41e2b0":[1,0,0,1,42],
 "classPMPCorefinementVisitor.html#a98422d4a6689cbaaef3c107a1be439c6":[1,0,0,1,34],
 "classPMPCorefinementVisitor.html#a9adc3c945d5965ca82e58af5e01a0652":[1,0,0,1,7],
 "classPMPCorefinementVisitor.html#a9f5a635e082e2a12dcc98baeffe7efac":[1,0,0,1,1],
@@ -197,6 +202,7 @@ var NAVTREEINDEX0 =
 "group__PMP__IO__grp.html#gac5b3295bd1b6375628a46d1fbaf7e881":[1,0,16,0],
 "group__PMP__combinatorial__repair__grp.html":[1,0,9],
 "group__PMP__combinatorial__repair__grp.html#ga121f588ac324938d9a6b6931a08661e1":[1,0,9,1],
+"group__PMP__combinatorial__repair__grp.html#ga152989d1d1edabb9f68296d9395eb2dd":[1,0,9,13],
 "group__PMP__combinatorial__repair__grp.html#ga1f215926ed8794db827e2993d2960870":[1,0,9,3],
 "group__PMP__combinatorial__repair__grp.html#ga25901cbedcc6123d7760ac5b9dc8d14e":[1,0,9,0],
 "group__PMP__combinatorial__repair__grp.html#ga2af4c26afc4872bafd0caabe6af23f9a":[1,0,9,6],
@@ -211,24 +217,24 @@ var NAVTREEINDEX0 =
 "group__PMP__combinatorial__repair__grp.html#ga8b9d12d817b5cc76f5a42d74eac75bf3":[1,0,9,2],
 "group__PMP__combinatorial__repair__grp.html#ga93d14c26c259b5844dbd5a7753278e5f":[1,0,9,4],
 "group__PMP__combinatorial__repair__grp.html#ga95ff13c1578f509fa8ed58b1884d0e46":[1,0,9,5],
-"group__PMP__combinatorial__repair__grp.html#gaa0ca177eb85fafc4be1f88c5b27c25bd":[1,0,9,13],
 "group__PMP__combinatorial__repair__grp.html#gaef5c13fc9dd4cae14c860351c479a45f":[1,0,9,10],
 "group__PMP__corefinement__grp.html":[1,0,12],
 "group__PMP__corefinement__grp.html#ga02fa6ed9116a759ecfb87063392f5455":[1,0,12,11],
-"group__PMP__corefinement__grp.html#ga0c49ffd458b13ee9489cad2321656f71":[1,0,12,14],
+"group__PMP__corefinement__grp.html#ga0c49ffd458b13ee9489cad2321656f71":[1,0,12,16],
+"group__PMP__corefinement__grp.html#ga2c73d3460872e601f84a03f58dd069ae":[1,0,12,6],
 "group__PMP__corefinement__grp.html#ga3be2ae4b7de3a1d9288f7febfc27eb9a":[1,0,12,3],
 "group__PMP__corefinement__grp.html#ga3e3a0a82b6c04bdc3a6c070e8da4aed5":[1,0,12,4],
 "group__PMP__corefinement__grp.html#ga3ff96d36cad8f37efcdada916c46fbbe":[1,0,12,12],
 "group__PMP__corefinement__grp.html#ga54baccf4fbd1b1ada67465ec1d4bddc1":[1,0,12,9],
 "group__PMP__corefinement__grp.html#ga5dc9e7acf8433235adc7b91ac93a7d42":[1,0,12,8],
-"group__PMP__corefinement__grp.html#ga642520055888a41a3e1a76965a1f9fbb":[1,0,12,16],
-"group__PMP__corefinement__grp.html#ga6e6c4a724ce19e7a207de56f3a7408ab":[1,0,12,17],
-"group__PMP__corefinement__grp.html#ga88ea5360f9fe65458f9086b453447662":[1,0,12,7],
+"group__PMP__corefinement__grp.html#ga642520055888a41a3e1a76965a1f9fbb":[1,0,12,17],
+"group__PMP__corefinement__grp.html#ga6738052411a4d548a5b375f11b913924":[1,0,12,15],
+"group__PMP__corefinement__grp.html#ga6e6c4a724ce19e7a207de56f3a7408ab":[1,0,12,18],
 "group__PMP__corefinement__grp.html#ga95f618914f8d54d840065204b029492f":[1,0,12,13],
 "group__PMP__corefinement__grp.html#gaafa5e46c35c3fef461a47d73b4566961":[1,0,12,10],
-"group__PMP__corefinement__grp.html#gad3aded948e73bd683903b9449601acb0":[1,0,12,15],
-"group__PMP__corefinement__grp.html#gad934517ebf9a6427e52d457ed24faf79":[1,0,12,6],
-"group__PMP__corefinement__grp.html#gaec85370aa0b2acc0919e5f8406cfb74c":[1,0,12,5],
+"group__PMP__corefinement__grp.html#gacb9d68fa4dea8fd03ec53b56a16d6fc6":[1,0,12,14],
+"group__PMP__corefinement__grp.html#gad934517ebf9a6427e52d457ed24faf79":[1,0,12,7],
+"group__PMP__corefinement__grp.html#gaf7747d676c459d9e5da9b13be7d12bb5":[1,0,12,5],
 "group__PMP__corrected__curvatures__grp.html":[1,0,4],
 "group__PMP__corrected__curvatures__grp.html#ga22665c9ce92aaedab07df1b05f20bdb2":[1,0,4,1],
 "group__PMP__corrected__curvatures__grp.html#ga78329aab7b2fcd86880fd79dd36bd55b":[1,0,4,2],
@@ -243,11 +249,5 @@ var NAVTREEINDEX0 =
 "group__PMP__distance__grp.html#ga6307a4504382c46dc3b0e578ca1f7a3b":[1,0,11,7],
 "group__PMP__distance__grp.html#ga74376aa81d44d745426acfad5a0ac8de":[1,0,11,0],
 "group__PMP__distance__grp.html#gac251a5e983df7ee6aa61623cdb9ec454":[1,0,11,3],
-"group__PMP__distance__grp.html#gacd7487071c9d409e91c37a731999a239":[1,0,11,5],
-"group__PMP__distance__grp.html#gaed9454c6ed046cd4fb7928cf2b5f7c2c":[1,0,11,6],
-"group__PMP__distance__grp.html#gaff7bb1f6909363380f3947f1fabf06a0":[1,0,11,4],
-"group__PMP__geometric__repair__grp.html":[1,0,10],
-"group__PMP__geometric__repair__grp.html#ga2abeabce0ee6906cd274570fcc38c146":[1,0,10,1],
-"group__PMP__geometric__repair__grp.html#ga48008d2b66de8a68a7068f29db15dad6":[1,0,10,0],
-"group__PMP__geometric__repair__grp.html#ga571b1605486d5cec0f4474aae3fa1905":[1,0,10,2]
+"group__PMP__distance__grp.html#gacd7487071c9d409e91c37a731999a239":[1,0,11,5]
 };
