@@ -1,5 +1,5 @@
 var group__PkgPolygonRepairRef =
 [
     [ "Functions", "group__PkgPolygonRepairFunctions.html", "group__PkgPolygonRepairFunctions" ],
-    [ "CGAL::Polygon_repair::Even_odd_rule", "structCGAL_1_1Polygon__repair_1_1Even__odd__rule.html", null ]
+    [ "Repair Rules", "group__PkgPolygonRepairRules.html", "group__PkgPolygonRepairRules" ]
 ];
\ No newline at end of file
