@@ -108,12 +108,8 @@ var group__PkgPolyhedronRef =
       [ "vertex_handles", "classCGAL_1_1Polyhedron__3.html#a2e0843aaeeadc428e8cd25802109bdf5", null ],
       [ "vertices_begin", "classCGAL_1_1Polyhedron__3.html#a94eec0aaf19925a005e5296d6c965c55", null ],
       [ "vertices_end", "classCGAL_1_1Polyhedron__3.html#aa402ee6ce24e0259a45c8579784a0f9a", null ],
-      [ "operator<<", "group__PkgPolyhedronIOFunc.html#ga0672e8be92f0b71fe624525f80f850d0", null ],
-      [ "operator>>", "group__PkgPolyhedronIOFunc.html#ga9842e8b5cda1e38ad04aa7f80622bce3", null ],
-      [ "read_OFF", "group__PkgPolyhedronIOFunc.html#gaccd9d4d15af1376dbc166eb501f28980", null ],
-      [ "read_off", "classCGAL_1_1Polyhedron__3.html#aeb28b4c481248fce96a79bf513f0d715", null ],
-      [ "write_OFF", "group__PkgPolyhedronIOFunc.html#ga408af896e2203af605059494e620cb64", null ],
-      [ "write_off", "classCGAL_1_1Polyhedron__3.html#ab9cb7a5361ace492fe0a7fbf758a5711", null ]
+      [ "operator<<", "group__PkgPolyhedronIOFunc.html#gae76f7723a658ce16b88063ee8a17805f", null ],
+      [ "operator>>", "group__PkgPolyhedronIOFunc.html#gaf1ce25670b5796744cd6af0acce1562b", null ]
     ] ],
     [ "CGAL::Polyhedron_3< Traits >::Halfedge", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html", [
       [ "Facet", "classCGAL_1_1Polyhedron__3_1_1Halfedge.html#a228e72adb988f1fb05f1dab4f91a98e9", null ],
