@@ -95,7 +95,6 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Polyhedron__3.html#ab3269baf4b4c6ce61b86545b8fa360d2":[1,0,3,96],
 "classCGAL_1_1Polyhedron__3.html#ab34dd6ee47881cc822f578a9ba534f83":[1,0,3,57],
 "classCGAL_1_1Polyhedron__3.html#ab741e3641ed4363ab156022525f82171":[1,0,3,60],
-"classCGAL_1_1Polyhedron__3.html#ab9cb7a5361ace492fe0a7fbf758a5711":[1,0,3,109],
 "classCGAL_1_1Polyhedron__3.html#abac442c83261a025d773fcf2a64cd953":[1,0,3,2],
 "classCGAL_1_1Polyhedron__3.html#abb5fbc55c8a0e94ec9720fc951632ab0":[1,0,3,69],
 "classCGAL_1_1Polyhedron__3.html#abb6712371c2355442e42b6846bbc0375":[1,0,3,86],
@@ -114,7 +113,6 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Polyhedron__3.html#adb9c5380cb7d80196eff14e36c6a4ba1":[1,0,3,23],
 "classCGAL_1_1Polyhedron__3.html#add0588183a0e107bd7e2dc78909ca127":[1,0,3,0],
 "classCGAL_1_1Polyhedron__3.html#ae05ca3c53d3ec0ce9e84c4b173b48e3e":[1,0,3,58],
-"classCGAL_1_1Polyhedron__3.html#aeb28b4c481248fce96a79bf513f0d715":[1,0,3,107],
 "classCGAL_1_1Polyhedron__3.html#af156bdee96bbf065953569fe026795d9":[1,0,3,92],
 "classCGAL_1_1Polyhedron__3.html#af268be0ffff77469b60afbc4b4893ed5":[1,0,3,17],
 "classCGAL_1_1Polyhedron__3.html#af6abde1634fdd64d79e78f07145186f2":[1,0,3,87],
@@ -249,5 +247,7 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Polyhedron__min__items__3.html#a8789e64309da299b6375fb7c400fbf8b":[1,0,9,1],
 "classCGAL_1_1Polyhedron__traits__3.html":[1,0,10],
 "classCGAL_1_1Polyhedron__traits__3.html#a099808dc96790e01331ac5323683b60a":[1,0,10,2],
-"classCGAL_1_1Polyhedron__traits__3.html#a375be0eb3055107426e6f91982055aec":[1,0,10,1]
+"classCGAL_1_1Polyhedron__traits__3.html#a375be0eb3055107426e6f91982055aec":[1,0,10,1],
+"classCGAL_1_1Polyhedron__traits__3.html#a3c32c38bd9fc0b5a1880ed68512802f0":[1,0,10,0],
+"classCGAL_1_1Polyhedron__traits__3.html#a55732819280265ce1af883d4d90d9aa0":[1,0,10,3]
 };
