@@ -1,8 +1,8 @@
 var examples =
 [
-    [ "Polyline_simplification_2/points_and_vertices.cpp", "Polyline_simplification_2_2points_and_vertices_8cpp-example.html", null ],
+    [ "Polyline_simplification_2/simplify_polygon.cpp", "Polyline_simplification_2_2simplify_polygon_8cpp-example.html", null ],
     [ "Polyline_simplification_2/simplify.cpp", "Polyline_simplification_2_2simplify_8cpp-example.html", null ],
     [ "Polyline_simplification_2/simplify_overlapping_polylines.cpp", "Polyline_simplification_2_2simplify_overlapping_polylines_8cpp-example.html", null ],
-    [ "Polyline_simplification_2/simplify_polygon.cpp", "Polyline_simplification_2_2simplify_polygon_8cpp-example.html", null ],
-    [ "Polyline_simplification_2/simplify_terrain.cpp", "Polyline_simplification_2_2simplify_terrain_8cpp-example.html", null ]
+    [ "Polyline_simplification_2/simplify_terrain.cpp", "Polyline_simplification_2_2simplify_terrain_8cpp-example.html", null ],
+    [ "Polyline_simplification_2/points_and_vertices.cpp", "Polyline_simplification_2_2points_and_vertices_8cpp-example.html", null ]
 ];
\ No newline at end of file
