@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "CGAL 6.0.1 - Principal Component Analysis", "index.html", [
+  [ "CGAL 6.1 - Principal Component Analysis", "index.html", [
     [ "User Manual", "index.html", "index" ],
     [ "Reference Manual", "modules.html", "modules" ],
     [ "Examples", "examples.html", "examples" ]
