@@ -2,11 +2,11 @@ var structCGAL_1_1Second__of__pair__property__map =
 [
     [ "category", "structCGAL_1_1Second__of__pair__property__map.html#a987ca9eac9759bb64a66c85628c8f95d", null ],
     [ "key_type", "structCGAL_1_1Second__of__pair__property__map.html#abe463cef6cb37fff9167af7a1a38ee39", null ],
+    [ "reference", "structCGAL_1_1Second__of__pair__property__map.html#a2f004ceee94194be976ee927204f7a14", null ],
     [ "Self", "structCGAL_1_1Second__of__pair__property__map.html#a8c11bcfa6c39459150849f33ff404b14", null ],
     [ "value_type", "structCGAL_1_1Second__of__pair__property__map.html#ab6a26153f1084847957c383a36bafd54", null ],
-    [ "operator[]", "structCGAL_1_1Second__of__pair__property__map.html#a467333cc8b7533bc9a18d7641b0d50e7", null ],
+    [ "operator[]", "structCGAL_1_1Second__of__pair__property__map.html#a242fa92c240be10627691994529e8186", null ],
     [ "get", "structCGAL_1_1Second__of__pair__property__map.html#abf5db4cbe7e32348943af412794463a6", null ],
     [ "make_second_of_pair_property_map", "structCGAL_1_1Second__of__pair__property__map.html#ab212c2f9da0d77d8872fb025ae880aea", null ],
-    [ "put", "structCGAL_1_1Second__of__pair__property__map.html#a2886f327e2e778e8c4ee93c9c2cd142f", null ],
-    [ "reference", "structCGAL_1_1Second__of__pair__property__map.html#a4ebb353e8b0b5d67eec5a0af5ff1d7ec", null ]
+    [ "put", "structCGAL_1_1Second__of__pair__property__map.html#a2886f327e2e778e8c4ee93c9c2cd142f", null ]
 ];
\ No newline at end of file
