@@ -1,9 +1,10 @@
 var annotated =
 [
     [ "CGAL", null, [
+      [ "Compact_simplicial_mesh_cell_base_3", "classCGAL_1_1Compact__simplicial__mesh__cell__base__3.html", null ],
       [ "Mesh_complex_3_in_triangulation_3", "classCGAL_1_1Mesh__complex__3__in__triangulation__3.html", "classCGAL_1_1Mesh__complex__3__in__triangulation__3" ],
-      [ "Simplicial_mesh_cell_base_3", "classCGAL_1_1Simplicial__mesh__cell__base__3.html", null ],
-      [ "Simplicial_mesh_vertex_base_3", "structCGAL_1_1Simplicial__mesh__vertex__base__3.html", null ]
+      [ "Simplicial_mesh_cell_base_3", "classCGAL_1_1Simplicial__mesh__cell__base__3.html", "classCGAL_1_1Simplicial__mesh__cell__base__3" ],
+      [ "Simplicial_mesh_vertex_base_3", "classCGAL_1_1Simplicial__mesh__vertex__base__3.html", "classCGAL_1_1Simplicial__mesh__vertex__base__3" ]
     ] ],
     [ "MeshComplex_3InTriangulation_3", "classMeshComplex__3InTriangulation__3.html", "classMeshComplex__3InTriangulation__3" ],
     [ "MeshComplexWithFeatures_3InTriangulation_3", "classMeshComplexWithFeatures__3InTriangulation__3.html", "classMeshComplexWithFeatures__3InTriangulation__3" ],
