@@ -86,14 +86,13 @@ var group__PkgSMDS3Concepts =
       [ "surface_patch_index", "classSimplicialMeshCellBase__3.html#a54305607d45ce541d0199214ea4ae212", null ]
     ] ],
     [ "SimplicialMeshVertexBase_3", "classSimplicialMeshVertexBase__3.html", [
-      [ "FT", "classSimplicialMeshVertexBase__3.html#a169045c287e11a607e920437a88a3e21", null ],
       [ "Index", "classSimplicialMeshVertexBase__3.html#a2f0094baf6461c4ced271937f0361039", null ],
-      [ "cached_number_of_components", "classSimplicialMeshVertexBase__3.html#ad7e9cffef09199ae5151f50f3d70598e", null ],
-      [ "cached_number_of_incident_facets", "classSimplicialMeshVertexBase__3.html#a6bbf69fb3c4aa0785d0d494291b67e8a", null ],
+      [ "cached_number_of_components", "classSimplicialMeshVertexBase__3.html#aabba67fef2bce09d3dd5629546437a7a", null ],
+      [ "cached_number_of_incident_facets", "classSimplicialMeshVertexBase__3.html#a08bff41e51c23f7f47d89e38dc8ccc97", null ],
       [ "in_dimension", "classSimplicialMeshVertexBase__3.html#a0b90fd53f9ec42a779e9d0f36c493e0b", null ],
       [ "index", "classSimplicialMeshVertexBase__3.html#a01a2f763ed9248e182549a215da58753", null ],
-      [ "invalidate_c2t3_cache", "classSimplicialMeshVertexBase__3.html#ac54eb06b051f3459d850b2043a8d86b6", null ],
       [ "is_c2t3_cache_valid", "classSimplicialMeshVertexBase__3.html#a53b9dc4397b87195c474d6403a94fce9", null ],
+      [ "set_c2t3_cache", "classSimplicialMeshVertexBase__3.html#a8666dff4aa1ab1e9925b1c9b5cf8b7b7", null ],
       [ "set_dimension", "classSimplicialMeshVertexBase__3.html#a2a9e9692b738801db71c8c6ae1c3b73f", null ],
       [ "set_index", "classSimplicialMeshVertexBase__3.html#a17e97b42d37d4aba588b05042f0d6d68", null ]
     ] ]
