@@ -1,5 +1,10 @@
 var group__PkgSTLExtensionConcepts =
 [
+    [ "BaseWithTimeStamp", "classBaseWithTimeStamp.html", [
+      [ "Has_timestamp", "classBaseWithTimeStamp.html#a12b59a77862d15d2d75d7fabc9248020", null ],
+      [ "set_time_stamp", "classBaseWithTimeStamp.html#ab586bcb065f9061e3df1a5288cd1a008", null ],
+      [ "time_stamp", "classBaseWithTimeStamp.html#a1ee935c51f621677cb3c9342e20b0ff5", null ]
+    ] ],
     [ "Descriptor", "classDescriptor.html", null ],
     [ "Hashable", "classHashable.html", null ],
     [ "Index", "classIndex.html", null ],
