@@ -9,6 +9,10 @@ var NAVTREEINDEX0 =
 "STL_Extension_2unordered_map_8cpp-example.html":[6,5],
 "annotated.html":[5],
 "citelist.html":[4],
+"classBaseWithTimeStamp.html":[1,0,6,0],
+"classBaseWithTimeStamp.html#a12b59a77862d15d2d75d7fabc9248020":[1,0,6,0,0],
+"classBaseWithTimeStamp.html#a1ee935c51f621677cb3c9342e20b0ff5":[1,0,6,0,2],
+"classBaseWithTimeStamp.html#ab586bcb065f9061e3df1a5288cd1a008":[1,0,6,0,1],
 "classCGAL_1_1CC__safe__handle.html":[1,0,1,0],
 "classCGAL_1_1CC__safe__handle.html":[1,0,9],
 "classCGAL_1_1CC__safe__handle.html#a38f4c42d324f886a60528bfeb3f477da":[1,0,9,1],
@@ -245,9 +249,5 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1In__place__list.html#a5281a5a43c026175267e41e41aa38b72":[1,0,4,1,5],
 "classCGAL_1_1In__place__list.html#a552494a73a48e7954880509c0ef790a1":[1,0,4,1,21],
 "classCGAL_1_1In__place__list.html#a552ec80fb1d71d3ba5fcace3b3af9246":[1,0,4,1,53],
-"classCGAL_1_1In__place__list.html#a572f57e661ff03f448caccd65c6e7765":[1,0,4,1,20],
-"classCGAL_1_1In__place__list.html#a609ef678dba9971568c663bb4c48718c":[1,0,4,1,40],
-"classCGAL_1_1In__place__list.html#a615b9b1c09e2032c5e3dfb2623d26102":[1,0,4,1,44],
-"classCGAL_1_1In__place__list.html#a64beaf549c57f160ae9228b1f3373364":[1,0,4,1,39],
-"classCGAL_1_1In__place__list.html#a66f350821f5151e961801b8a35a26b8b":[1,0,4,1,32]
+"classCGAL_1_1In__place__list.html#a572f57e661ff03f448caccd65c6e7765":[1,0,4,1,20]
 };
