@@ -1,5 +1,9 @@
 var NAVTREEINDEX1 =
 {
+"classCGAL_1_1In__place__list.html#a609ef678dba9971568c663bb4c48718c":[1,0,4,1,40],
+"classCGAL_1_1In__place__list.html#a615b9b1c09e2032c5e3dfb2623d26102":[1,0,4,1,44],
+"classCGAL_1_1In__place__list.html#a64beaf549c57f160ae9228b1f3373364":[1,0,4,1,39],
+"classCGAL_1_1In__place__list.html#a66f350821f5151e961801b8a35a26b8b":[1,0,4,1,32],
 "classCGAL_1_1In__place__list.html#a6d92a22111835f0db5e4388fc3e9b9a6":[1,0,4,1,8],
 "classCGAL_1_1In__place__list.html#a7094ecad5bb64f636d719e4939df644e":[1,0,4,1,16],
 "classCGAL_1_1In__place__list.html#a745ad871c28e1f9609db5c383375ad59":[1,0,4,1,42],
@@ -180,6 +184,10 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Threetuple.html#a44ef1706795e555b4c3f5a453905f5c5":[1,0,7,14,1],
 "classCGAL_1_1Threetuple.html#abc75b80e0fe5e8f101152840c1ef4769":[1,0,7,14,0],
 "classCGAL_1_1Threetuple.html#add188d94b0e0b4525120fbd969060938":[1,0,7,14,4],
+"classCGAL_1_1Triangulation__simplex__base__with__time__stamp.html":[5,0,75],
+"classCGAL_1_1Triangulation__simplex__base__with__time__stamp.html#a000be01d0a032f3295805ff43e0c01a4":[5,0,75,2],
+"classCGAL_1_1Triangulation__simplex__base__with__time__stamp.html#a1703471a4699a5a87d6cb375bf7a9f4e":[5,0,75,3],
+"classCGAL_1_1Triangulation__simplex__base__with__time__stamp.html#af7013f12d4d8fa42a5cc38ab1b817c9a":[5,0,75,1],
 "classCGAL_1_1Triple.html":[1,0,7,18],
 "classCGAL_1_1Triple.html#a01b547c42a086c84c89f2bf1f0caaa71":[1,0,7,18,9],
 "classCGAL_1_1Triple.html#a035755acd9bb4fd703f532e346c24f1c":[1,0,7,18,2],
@@ -223,7 +231,6 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Uncertain.html#a5a42efa42bc7852647b5a77010c50330":[1,0,7,16,36],
 "classCGAL_1_1Uncertain.html#a5f345b146fd0abfceab15ad5688393d5":[1,0,7,16,15],
 "classCGAL_1_1Uncertain.html#a6d5f114dc7150c86a6a50e0f6eddd149":[1,0,7,16,9],
-"classCGAL_1_1Uncertain.html#a706f7518f1e5daf862b83b47bbad848c":[1,0,7,16,5],
 "classCGAL_1_1Uncertain.html#a73311919bfff3aad3a724a5815575565":[1,0,7,16,51],
 "classCGAL_1_1Uncertain.html#a73a3dec812e479d16688e37029040682":[1,0,7,16,55],
 "classCGAL_1_1Uncertain.html#a7a54d767adac09e9a7ca97f5f82a5e43":[1,0,7,16,12],
@@ -240,14 +247,7 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Uncertain.html#aac0743cbafe7f12e07aae977485d6eb5":[1,0,7,16,58],
 "classCGAL_1_1Uncertain.html#aadfe4670d91863370b5850358e74138b":[1,0,7,16,7],
 "classCGAL_1_1Uncertain.html#ab7db5e96b7571807ebac90f21bc5e87e":[1,0,7,16,30],
+"classCGAL_1_1Uncertain.html#aba9a3c935e55e156a975e6a0891d62c7":[1,0,7,16,5],
 "classCGAL_1_1Uncertain.html#abba43914e1f60da2f1c2baf2e8224f5e":[1,0,7,16,18],
-"classCGAL_1_1Uncertain.html#ac02688a943e0b8fa77ca69922d5c3cc8":[1,0,7,16,10],
-"classCGAL_1_1Uncertain.html#ac3a618bb4f7104eb9797170528463be9":[1,0,7,16,14],
-"classCGAL_1_1Uncertain.html#ac7e26624301533fab59aa968e113e787":[1,0,7,16,57],
-"classCGAL_1_1Uncertain.html#ad0895d249db0e47191671237593867f8":[1,0,7,16,44],
-"classCGAL_1_1Uncertain.html#ad2b9cdb445a23536b6a921875c4954ce":[1,0,7,16,33],
-"classCGAL_1_1Uncertain.html#ad314715ba07eab93e2c29adead953f11":[1,0,7,16,50],
-"classCGAL_1_1Uncertain.html#ad366333cc1f81b34aa6e67596d6422bc":[1,0,7,16,62],
-"classCGAL_1_1Uncertain.html#ad3e53e5a088abe6beafa9e8ecb430b03":[1,0,7,16,16],
-"classCGAL_1_1Uncertain.html#ad4123384957febc86c9cd2866dcd08a7":[1,0,7,16,21]
+"classCGAL_1_1Uncertain.html#ac02688a943e0b8fa77ca69922d5c3cc8":[1,0,7,16,10]
 };
