@@ -1,5 +1,13 @@
 var NAVTREEINDEX2 =
 {
+"classCGAL_1_1Uncertain.html#ac3a618bb4f7104eb9797170528463be9":[1,0,7,16,14],
+"classCGAL_1_1Uncertain.html#ac7e26624301533fab59aa968e113e787":[1,0,7,16,57],
+"classCGAL_1_1Uncertain.html#ad0895d249db0e47191671237593867f8":[1,0,7,16,44],
+"classCGAL_1_1Uncertain.html#ad2b9cdb445a23536b6a921875c4954ce":[1,0,7,16,33],
+"classCGAL_1_1Uncertain.html#ad314715ba07eab93e2c29adead953f11":[1,0,7,16,50],
+"classCGAL_1_1Uncertain.html#ad366333cc1f81b34aa6e67596d6422bc":[1,0,7,16,62],
+"classCGAL_1_1Uncertain.html#ad3e53e5a088abe6beafa9e8ecb430b03":[1,0,7,16,16],
+"classCGAL_1_1Uncertain.html#ad4123384957febc86c9cd2866dcd08a7":[1,0,7,16,21],
 "classCGAL_1_1Uncertain.html#ad6216622e449e7a0b988704540a1fd42":[1,0,7,16,8],
 "classCGAL_1_1Uncertain.html#ad6b02383921d42f9f9cb7ea2205eeb38":[1,0,7,16,34],
 "classCGAL_1_1Uncertain.html#ad8363cebaa1233b86b9dd30c327c8588":[1,0,7,16,63],
@@ -16,26 +24,26 @@ var NAVTREEINDEX2 =
 "classCGAL_1_1Uncertain.html#af665be6fa89854145710a5d141f8519c":[1,0,7,16,54],
 "classCGAL_1_1Uncertain.html#af6e4f6e332530e1591472e398c22eb15":[1,0,7,16,29],
 "classCGAL_1_1Uncertain.html#afb8bfd0ebc7f6ebdd63238b2ea623fe7":[1,0,7,16,25],
-"classDescriptor.html":[1,0,6,0],
-"classHashable.html":[1,0,6,1],
-"classIndex.html":[1,0,6,2],
-"classObjectWithEraseCounter.html":[1,0,6,3],
-"classObjectWithEraseCounter.html#a6059f4772ba8a8cbf414a3ae7375ffc8":[1,0,6,3,1],
-"classObjectWithEraseCounter.html#a6d07f3c6b7440bd578f2f1759bd5e89f":[1,0,6,3,0],
-"classObjectWithEraseCounter.html#af0c998511a51a5a399dbb083429e6a68":[1,0,6,3,2],
-"classProjectionObject.html":[1,0,6,4],
-"classProjectionObject.html#a429df2abb3336f26397dcf8f99fb799d":[1,0,6,4,3],
-"classProjectionObject.html#a897b5549df2ea09f3e0697e9543a680f":[1,0,6,4,1],
-"classProjectionObject.html#aa224850b85fde6e038378467bdd29602":[1,0,6,4,4],
-"classProjectionObject.html#ab507db0cd352fd04fe7b7f92fa7bb4dd":[1,0,6,4,0],
-"classProjectionObject.html#ac7e3e8d01f446472c8135f3acbb03cbe":[1,0,6,4,2],
-"classSurjectiveLockDataStructure.html":[1,0,6,5],
-"classSurjectiveLockDataStructure.html#a4ed08cb60942e923043c2899e3121047":[1,0,6,5,5],
-"classSurjectiveLockDataStructure.html#a734a1d77fccaa9aa3fe035f504bcfedc":[1,0,6,5,1],
-"classSurjectiveLockDataStructure.html#a7f449f8f7aef7991af60d7f3c56c5ece":[1,0,6,5,3],
-"classSurjectiveLockDataStructure.html#a8be4390119e3ff3c5269458ca1789bd3":[1,0,6,5,0],
-"classSurjectiveLockDataStructure.html#a9e89c82fdac27fbca1c7dde34a22900d":[1,0,6,5,2],
-"classSurjectiveLockDataStructure.html#ac0a0acb5759fe2b73894defb2d63c29c":[1,0,6,5,4],
+"classDescriptor.html":[1,0,6,1],
+"classHashable.html":[1,0,6,2],
+"classIndex.html":[1,0,6,3],
+"classObjectWithEraseCounter.html":[1,0,6,4],
+"classObjectWithEraseCounter.html#a6059f4772ba8a8cbf414a3ae7375ffc8":[1,0,6,4,1],
+"classObjectWithEraseCounter.html#a6d07f3c6b7440bd578f2f1759bd5e89f":[1,0,6,4,0],
+"classObjectWithEraseCounter.html#af0c998511a51a5a399dbb083429e6a68":[1,0,6,4,2],
+"classProjectionObject.html":[1,0,6,5],
+"classProjectionObject.html#a429df2abb3336f26397dcf8f99fb799d":[1,0,6,5,3],
+"classProjectionObject.html#a897b5549df2ea09f3e0697e9543a680f":[1,0,6,5,1],
+"classProjectionObject.html#aa224850b85fde6e038378467bdd29602":[1,0,6,5,4],
+"classProjectionObject.html#ab507db0cd352fd04fe7b7f92fa7bb4dd":[1,0,6,5,0],
+"classProjectionObject.html#ac7e3e8d01f446472c8135f3acbb03cbe":[1,0,6,5,2],
+"classSurjectiveLockDataStructure.html":[1,0,6,6],
+"classSurjectiveLockDataStructure.html#a4ed08cb60942e923043c2899e3121047":[1,0,6,6,5],
+"classSurjectiveLockDataStructure.html#a734a1d77fccaa9aa3fe035f504bcfedc":[1,0,6,6,1],
+"classSurjectiveLockDataStructure.html#a7f449f8f7aef7991af60d7f3c56c5ece":[1,0,6,6,3],
+"classSurjectiveLockDataStructure.html#a8be4390119e3ff3c5269458ca1789bd3":[1,0,6,6,0],
+"classSurjectiveLockDataStructure.html#a9e89c82fdac27fbca1c7dde34a22900d":[1,0,6,6,2],
+"classSurjectiveLockDataStructure.html#ac0a0acb5759fe2b73894defb2d63c29c":[1,0,6,6,4],
 "deprecated.html":[3],
 "examples.html":[6],
 "group__CompactContainer.html":[1,0,1],
@@ -103,12 +111,12 @@ var NAVTREEINDEX2 =
 "structCGAL_1_1Compact__container__traits.html":[1,0,1,3],
 "structCGAL_1_1Compact__container__traits.html#a5eab54c18c3a236b04bf76583511c93a":[1,0,1,3,0],
 "structCGAL_1_1Compact__container__traits.html#ad5f2026600e5c23041b070f52413640b":[1,0,1,3,1],
-"structCGAL_1_1Concurrent__compact__container__traits.html":[1,0,1,4],
 "structCGAL_1_1Concurrent__compact__container__traits.html":[1,0,10],
+"structCGAL_1_1Concurrent__compact__container__traits.html":[1,0,1,4],
 "structCGAL_1_1Concurrent__compact__container__traits.html#a7cc9b0a63f1c93f8644a8d4fcfc8f3cb":[1,0,1,4,1],
 "structCGAL_1_1Concurrent__compact__container__traits.html#a7cc9b0a63f1c93f8644a8d4fcfc8f3cb":[1,0,10,1],
-"structCGAL_1_1Concurrent__compact__container__traits.html#af0fcefcb537ab4f286a44500214b1b3d":[1,0,10,0],
 "structCGAL_1_1Concurrent__compact__container__traits.html#af0fcefcb537ab4f286a44500214b1b3d":[1,0,1,4,0],
+"structCGAL_1_1Concurrent__compact__container__traits.html#af0fcefcb537ab4f286a44500214b1b3d":[1,0,10,0],
 "structCGAL_1_1Construct__array.html":[5,0,13],
 "structCGAL_1_1Construct__array.html#aab60e4a438bf3506c697c5207275baa0":[5,0,13,0],
 "structCGAL_1_1Default.html":[1,0,11],
@@ -204,6 +212,9 @@ var NAVTREEINDEX2 =
 "structCGAL_1_1Project__vertex.html#ac2f56e086e6b48c3b5da9045978a504d":[1,0,2,13,1],
 "structCGAL_1_1Project__vertex.html#ad197839e42e2f7d85dcd615f5a254e44":[1,0,2,13,4],
 "structCGAL_1_1Sequential__tag.html":[1,0,7,7],
+"structCGAL_1_1Triangulation__simplex__base__with__time__stamp_1_1Rebind__TDS.html":[5,0,75,0],
+"structCGAL_1_1Triangulation__simplex__base__with__time__stamp_1_1Rebind__TDS.html#a0a9cad4563dd010d66d046642873e229":[5,0,75,0,1],
+"structCGAL_1_1Triangulation__simplex__base__with__time__stamp_1_1Rebind__TDS.html#ab2cd67ddd92ad3112cd93d7b28cd1dc4":[5,0,75,0,0],
 "structCGAL_1_1cpp11_1_1result__of.html":[1,0,15],
 "structCGAL_1_1cpp11_1_1result__of.html#a0116f3bad73d2c51520c134dffbf1449":[1,0,15,0],
 "structCGAL_1_1cpp98_1_1binary__function.html":[5,0,1,0],
@@ -215,10 +226,10 @@ var NAVTREEINDEX2 =
 "structCGAL_1_1cpp98_1_1unary__function.html#acfd736be060eca5afb6c940e2e37df32":[5,0,1,1,1],
 "structCGAL_1_1value__type__traits.html":[1,0,17],
 "structCGAL_1_1value__type__traits.html#ab0b4bb023b13374a48ded6600d0d0aa0":[1,0,17,0],
-"structCGAL_1_1value__type__traits_3_01std_1_1back__insert__iterator_3_01Container_01_4_01_4.html":[5,0,79],
-"structCGAL_1_1value__type__traits_3_01std_1_1back__insert__iterator_3_01Container_01_4_01_4.html#a3434a4f408d3dcf4cc78133e5b0079ed":[5,0,79,0],
-"structCGAL_1_1value__type__traits_3_01std_1_1front__insert__iterator_3_01Container_01_4_01_4.html":[5,0,80],
-"structCGAL_1_1value__type__traits_3_01std_1_1front__insert__iterator_3_01Container_01_4_01_4.html#a565970564060621a5cd3712e0a57b548":[5,0,80,0],
-"structCGAL_1_1value__type__traits_3_01std_1_1insert__iterator_3_01Container_01_4_01_4.html":[5,0,81],
-"structCGAL_1_1value__type__traits_3_01std_1_1insert__iterator_3_01Container_01_4_01_4.html#ad86b7570b39267087cb11d6f521269e5":[5,0,81,0]
+"structCGAL_1_1value__type__traits_3_01std_1_1back__insert__iterator_3_01Container_01_4_01_4.html":[5,0,80],
+"structCGAL_1_1value__type__traits_3_01std_1_1back__insert__iterator_3_01Container_01_4_01_4.html#a3434a4f408d3dcf4cc78133e5b0079ed":[5,0,80,0],
+"structCGAL_1_1value__type__traits_3_01std_1_1front__insert__iterator_3_01Container_01_4_01_4.html":[5,0,81],
+"structCGAL_1_1value__type__traits_3_01std_1_1front__insert__iterator_3_01Container_01_4_01_4.html#a565970564060621a5cd3712e0a57b548":[5,0,81,0],
+"structCGAL_1_1value__type__traits_3_01std_1_1insert__iterator_3_01Container_01_4_01_4.html":[5,0,82],
+"structCGAL_1_1value__type__traits_3_01std_1_1insert__iterator_3_01Container_01_4_01_4.html#ad86b7570b39267087cb11d6f521269e5":[5,0,82,0]
 };
