@@ -1,12 +1,12 @@
 var group__PkgShapeRegularizationRefConcepts =
 [
-    [ "ContourDirections", "classCGAL_1_1Shape__regularization_1_1ContourDirections.html", [
+    [ "CGAL::Shape_regularization::ContourDirections", "classCGAL_1_1Shape__regularization_1_1ContourDirections.html", [
       [ "orient", "classCGAL_1_1Shape__regularization_1_1ContourDirections.html#a07f23b0d134d1dfb32158f485aab15b8", null ]
     ] ],
-    [ "NeighborQuery", "classCGAL_1_1Shape__regularization_1_1NeighborQuery.html", [
+    [ "CGAL::Shape_regularization::NeighborQuery", "classCGAL_1_1Shape__regularization_1_1NeighborQuery.html", [
       [ "operator()", "classCGAL_1_1Shape__regularization_1_1NeighborQuery.html#afe9ac86f81427f217a72ee74523e4ade", null ]
     ] ],
-    [ "RegularizationType", "classCGAL_1_1Shape__regularization_1_1RegularizationType.html", [
+    [ "CGAL::Shape_regularization::RegularizationType", "classCGAL_1_1Shape__regularization_1_1RegularizationType.html", [
       [ "bound", "classCGAL_1_1Shape__regularization_1_1RegularizationType.html#a6425688d6368960b0aa5bfd0e6e13541", null ],
       [ "target", "classCGAL_1_1Shape__regularization_1_1RegularizationType.html#ac5bd68e930f080c0b619b3541c5fad9c", null ],
       [ "update", "classCGAL_1_1Shape__regularization_1_1RegularizationType.html#a5fa1b89221a8d2515acff817ceeb6946", null ]
