@@ -1,8 +1,8 @@
 var examples =
 [
     [ "Solver_interface/diagonalize_matrix.cpp", "Solver_interface_2diagonalize_matrix_8cpp-example.html", null ],
-    [ "Solver_interface/mixed_integer_program.cpp", "Solver_interface_2mixed_integer_program_8cpp-example.html", null ],
-    [ "Solver_interface/osqp_quadratic_program.cpp", "Solver_interface_2osqp_quadratic_program_8cpp-example.html", null ],
     [ "Solver_interface/singular_value_decomposition.cpp", "Solver_interface_2singular_value_decomposition_8cpp-example.html", null ],
-    [ "Solver_interface/sparse_solvers.cpp", "Solver_interface_2sparse_solvers_8cpp-example.html", null ]
+    [ "Solver_interface/sparse_solvers.cpp", "Solver_interface_2sparse_solvers_8cpp-example.html", null ],
+    [ "Solver_interface/mixed_integer_program.cpp", "Solver_interface_2mixed_integer_program_8cpp-example.html", null ],
+    [ "Solver_interface/osqp_quadratic_program.cpp", "Solver_interface_2osqp_quadratic_program_8cpp-example.html", null ]
 ];
\ No newline at end of file
