@@ -5,5 +5,5 @@ var classSearchTraits =
     [ "Dimension", "classSearchTraits.html#a0747aa4e30e20dd0a052d086e981ebe4", null ],
     [ "FT", "classSearchTraits.html#aa4641fbf5d2f1d4a55f2e7fa24c5da23", null ],
     [ "Point_d", "classSearchTraits.html#a6352b7ff783f425496c0b64757ad95bc", null ],
-    [ "construct_construct_cartesian_const_iterator_d_object", "classSearchTraits.html#aff5e9e2fe56452368cb7f43db822c362", null ]
+    [ "construct_cartesian_const_iterator_d_object", "classSearchTraits.html#a12fe10916a37b577aa606c08d5d11ba2", null ]
 ];
\ No newline at end of file
