@@ -5,10 +5,8 @@ var group__PkgStraightSkeleton2OffsetFunctions =
     [ "CGAL::convert_straight_skeleton_2", "group__PkgStraightSkeleton2OffsetFunctions.html#ga84423baa5902a7d6c2f8278f93d82f32", null ],
     [ "CGAL::create_exterior_skeleton_and_offset_polygons_2", "group__PkgStraightSkeleton2OffsetFunctions.html#gaee243d012e7f942b4d1365dc307546b8", null ],
     [ "CGAL::create_exterior_skeleton_and_offset_polygons_with_holes_2", "group__PkgStraightSkeleton2OffsetFunctions.html#ga7627d015c03abaea59b144576afebf70", null ],
-    [ "CGAL::create_exterior_weighted_skeleton_and_offset_polygons_with_holes_2", "group__PkgStraightSkeleton2OffsetFunctions.html#ga52736ea80b6df08be011d5d66e26a543", null ],
     [ "CGAL::create_interior_skeleton_and_offset_polygons_2", "group__PkgStraightSkeleton2OffsetFunctions.html#ga4baa6cdc2cc19c341be875742387254b", null ],
     [ "CGAL::create_interior_skeleton_and_offset_polygons_2", "group__PkgStraightSkeleton2OffsetFunctions.html#gaf0d0e8321d70cd97e6441b6ce77bdc89", null ],
     [ "CGAL::create_interior_skeleton_and_offset_polygons_with_holes_2", "group__PkgStraightSkeleton2OffsetFunctions.html#gabe025331b6e803f2f942305123a02306", null ],
-    [ "CGAL::create_interior_weighted_skeleton_and_offset_polygons_with_holes_2", "group__PkgStraightSkeleton2OffsetFunctions.html#gaee073b6bd62fb5722bad41528647ec30", null ],
     [ "CGAL::create_offset_polygons_2", "group__PkgStraightSkeleton2OffsetFunctions.html#ga36fe6fd001343f6cd0a3e8b06d1c325c", null ]
 ];
\ No newline at end of file
