@@ -1,6 +1,6 @@
 var group__PkgSurfaceMeshShortestPathTraitsClasses =
 [
-    [ "Surface_mesh_shortest_path_traits", "classCGAL_1_1Surface__mesh__shortest__path__traits.html", [
+    [ "CGAL::Surface_mesh_shortest_path_traits< K, TriangleMesh >", "classCGAL_1_1Surface__mesh__shortest__path__traits.html", [
       [ "Barycentric_coordinates", "classCGAL_1_1Surface__mesh__shortest__path__traits.html#a8655a743e2e312b1d364f4b953504d19", null ],
       [ "Kernel", "classCGAL_1_1Surface__mesh__shortest__path__traits.html#a6e24aae4d3841dca3613d25b778207d6", null ],
       [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__shortest__path__traits.html#a14b3f13aad4e88857fb5a9f63b6c3c30", null ]
