@@ -1,12 +1,12 @@
 var examples =
 [
+    [ "Surface_mesh_topology/shortest_noncontractible_cycle.cpp", "Surface_mesh_topology_2shortest_noncontractible_cycle_8cpp-example.html", null ],
     [ "Surface_mesh_topology/edgewidth_surface_mesh.cpp", "Surface_mesh_topology_2edgewidth_surface_mesh_8cpp-example.html", null ],
     [ "Surface_mesh_topology/facewidth.cpp", "Surface_mesh_topology_2facewidth_8cpp-example.html", null ],
-    [ "Surface_mesh_topology/open_path_homotopy.cpp", "Surface_mesh_topology_2open_path_homotopy_8cpp-example.html", null ],
     [ "Surface_mesh_topology/path_homotopy_double_torus.cpp", "Surface_mesh_topology_2path_homotopy_double_torus_8cpp-example.html", null ],
     [ "Surface_mesh_topology/path_homotopy_with_symbols.cpp", "Surface_mesh_topology_2path_homotopy_with_symbols_8cpp-example.html", null ],
     [ "Surface_mesh_topology/path_homotopy_with_symbols_2.cpp", "Surface_mesh_topology_2path_homotopy_with_symbols_2_8cpp-example.html", null ],
     [ "Surface_mesh_topology/path_simplicity_double_torus.cpp", "Surface_mesh_topology_2path_simplicity_double_torus_8cpp-example.html", null ],
     [ "Surface_mesh_topology/path_simplicity_double_torus_2.cpp", "Surface_mesh_topology_2path_simplicity_double_torus_2_8cpp-example.html", null ],
-    [ "Surface_mesh_topology/shortest_noncontractible_cycle.cpp", "Surface_mesh_topology_2shortest_noncontractible_cycle_8cpp-example.html", null ]
+    [ "Surface_mesh_topology/open_path_homotopy.cpp", "Surface_mesh_topology_2open_path_homotopy_8cpp-example.html", null ]
 ];
\ No newline at end of file
