@@ -1,6 +1,6 @@
 var group__PkgTriangulationsTraitsClasses =
 [
-    [ "Regular_triangulation_traits_adapter", "classCGAL_1_1Regular__triangulation__traits__adapter.html", [
+    [ "CGAL::Regular_triangulation_traits_adapter< RTTraits >", "classCGAL_1_1Regular__triangulation__traits__adapter.html", [
       [ "Base", "classCGAL_1_1Regular__triangulation__traits__adapter.html#a3d5508a607861655be35680a4cda46ce", null ],
       [ "Point_d", "classCGAL_1_1Regular__triangulation__traits__adapter.html#afc18cbe402862aa6184762f052a5e62b", null ],
       [ "Regular_triangulation_traits_adapter", "classCGAL_1_1Regular__triangulation__traits__adapter.html#aa8c1596d4f159bdad61bc15040c55a61", null ]
