@@ -67,14 +67,16 @@ var group__PkgTriangulation2TriangulationClasses =
       ] ],
       [ "Constraint_id", "classCGAL_1_1Constrained__triangulation__plus__2.html#a136e59f7ed41cac6f861ae614bba1f3d", null ],
       [ "Constraint_iterator", "classCGAL_1_1Constrained__triangulation__plus__2.html#a8de286842d93f3ed1a3a13305a46a598", null ],
-      [ "Constraints", "classCGAL_1_1Constrained__triangulation__plus__2.html#a49e8b829ca7199eb0b1ab18a29015eab", null ],
+      [ "Constraints", "classCGAL_1_1Constrained__triangulation__plus__2.html#a23f216dd9ebd11d5697494500cc1615b", null ],
       [ "Context_iterator", "classCGAL_1_1Constrained__triangulation__plus__2.html#aef6be20e8480b93efce170502f6978d8", null ],
       [ "Contexts", "classCGAL_1_1Constrained__triangulation__plus__2.html#a89d33a944c4d5e75a1072ee28f5ff747", null ],
       [ "Intersection_tag", "classCGAL_1_1Constrained__triangulation__plus__2.html#a97d7ccfccd324092d31586bf167b7274", null ],
       [ "Points_in_constraint_iterator", "classCGAL_1_1Constrained__triangulation__plus__2.html#ab375f52ab119f4c636371ea6daf7b128", null ],
       [ "Subconstraint", "classCGAL_1_1Constrained__triangulation__plus__2.html#aea74ca3e4d971d098f8debe10427cdd6", null ],
+      [ "Subconstraint_and_contexts_iterator", "classCGAL_1_1Constrained__triangulation__plus__2.html#ab265e6d4f4b3494ca35305924dae77ce", null ],
       [ "Subconstraint_iterator", "classCGAL_1_1Constrained__triangulation__plus__2.html#ab658142eecab7e14cd2bea9872a486e0", null ],
-      [ "Subconstraints", "classCGAL_1_1Constrained__triangulation__plus__2.html#affdf3afc591109f9f4a36c002769e355", null ],
+      [ "Subconstraints", "classCGAL_1_1Constrained__triangulation__plus__2.html#a161aa980f13071199ed6da29ab6faed6", null ],
+      [ "Subconstraints_and_contexts", "classCGAL_1_1Constrained__triangulation__plus__2.html#aa99af77a8e48fe575cbdc198f2c27eac", null ],
       [ "Triangulation", "classCGAL_1_1Constrained__triangulation__plus__2.html#ad56967b79e8788546c3ea5bd55653474", null ],
       [ "Vertices_in_constraint", "classCGAL_1_1Constrained__triangulation__plus__2.html#ac9e4a6b9d892bd683c36dc64ae0613e4", null ],
       [ "Vertices_in_constraint_iterator", "classCGAL_1_1Constrained__triangulation__plus__2.html#a0d38b6bac2db9859af3ff67c2226f3e8", null ],
@@ -108,6 +110,9 @@ var group__PkgTriangulation2TriangulationClasses =
       [ "simplify", "classCGAL_1_1Constrained__triangulation__plus__2.html#a3a285a8e838efb83df65876138b20646", null ],
       [ "split_subconstraint_graph_into_constraints", "classCGAL_1_1Constrained__triangulation__plus__2.html#adea77f5db5cd4dfae302e4502f1caa85", null ],
       [ "subconstraints", "classCGAL_1_1Constrained__triangulation__plus__2.html#af25114a7e1675194367f8f9de9de90d2", null ],
+      [ "subconstraints_and_contexts", "classCGAL_1_1Constrained__triangulation__plus__2.html#aa9fb63e060d1754bda255e57768166cd", null ],
+      [ "subconstraints_and_contexts_begin", "classCGAL_1_1Constrained__triangulation__plus__2.html#ac9184ecc28fbe1225d1fe77064d219ad", null ],
+      [ "subconstraints_and_contexts_end", "classCGAL_1_1Constrained__triangulation__plus__2.html#ac1845c5bafa9242d0bc7ea8a3dc5a44f", null ],
       [ "subconstraints_begin", "classCGAL_1_1Constrained__triangulation__plus__2.html#ad02088fd486bc5b753d8fc781e867630", null ],
       [ "subconstraints_end", "classCGAL_1_1Constrained__triangulation__plus__2.html#a0e0f1fb5f0490175516c2c82143a3a76", null ],
       [ "swap", "classCGAL_1_1Constrained__triangulation__plus__2.html#aae3aaf30f55fac735b56f5e545c75135", null ],
@@ -294,6 +299,8 @@ var group__PkgTriangulation2TriangulationClasses =
       [ "number_of_vertices", "classCGAL_1_1Triangulation__2.html#abb274869c3eac8fb775702bf68c4e8f1", null ],
       [ "operator=", "classCGAL_1_1Triangulation__2.html#a40701ad345813f8df044fd197d3c9d96", null ],
       [ "oriented_side", "classCGAL_1_1Triangulation__2.html#a01fbafc011677846a729a809b4b21a99", null ],
+      [ "point", "classCGAL_1_1Triangulation__2.html#a4c033e487fee9ead881374b52c10fb08", null ],
+      [ "point", "classCGAL_1_1Triangulation__2.html#a983cffc38d4dba054cfbbe8ae8791530", null ],
       [ "points", "classCGAL_1_1Triangulation__2.html#acae6c6bf678ec1a90b49498862bb7fa2", null ],
       [ "points_begin", "classCGAL_1_1Triangulation__2.html#a048beaadce99c9bdfeaa69dd68701c32", null ],
       [ "points_end", "classCGAL_1_1Triangulation__2.html#adb17161924b6d2b6e7ac537d6b760728", null ],
