@@ -1,6 +1,12 @@
 var NAVTREEINDEX1 =
 {
-"classCGAL_1_1Triangulation__2.html#a4b3389b24fe7bfe703151375d15a745a":[1,0,1,10,108],
+"classCGAL_1_1Triangulation__2.html#a433cff4ceaeaba390df1a968d93a4899":[1,0,1,10,98],
+"classCGAL_1_1Triangulation__2.html#a44461f8dc31540c015f24ee3d36870ab":[1,0,1,10,112],
+"classCGAL_1_1Triangulation__2.html#a4511afae77c0c2978b6412d9411e4fe2":[1,0,1,10,120],
+"classCGAL_1_1Triangulation__2.html#a48984e6735c075b17d7a956cb396d1f5":[1,0,1,10,25],
+"classCGAL_1_1Triangulation__2.html#a49fc8cd3cd899d0c0aa6bc0f20c72a0f":[1,0,1,10,46],
+"classCGAL_1_1Triangulation__2.html#a4b3389b24fe7bfe703151375d15a745a":[1,0,1,10,110],
+"classCGAL_1_1Triangulation__2.html#a4c033e487fee9ead881374b52c10fb08":[1,0,1,10,103],
 "classCGAL_1_1Triangulation__2.html#a4e201a26ae4f2593c8dd2607b333ff48":[1,0,1,10,59],
 "classCGAL_1_1Triangulation__2.html#a55aff11c6b56078d7384374a898bc1b9":[1,0,1,10,22],
 "classCGAL_1_1Triangulation__2.html#a5758b4f843e2d884d759f278e154ed87":[1,0,1,10,68],
@@ -14,7 +20,7 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__2.html#a6bd40af3800321a0d0d43f489b37fc2a":[1,0,1,10,50],
 "classCGAL_1_1Triangulation__2.html#a6c6a38b0ce694a47c2323834107fa758":[1,0,1,10,9],
 "classCGAL_1_1Triangulation__2.html#a6cfa7d3aaa375a25d217858b49e2eb07":[1,0,1,10,33],
-"classCGAL_1_1Triangulation__2.html#a6de738928cfecde1ae15bcbac16327ac":[1,0,1,10,121],
+"classCGAL_1_1Triangulation__2.html#a6de738928cfecde1ae15bcbac16327ac":[1,0,1,10,123],
 "classCGAL_1_1Triangulation__2.html#a6e43f49405b43057d1b911a9f6e39404":[1,0,1,10,32],
 "classCGAL_1_1Triangulation__2.html#a742d528593275c1fe119979b4ce74a90":[1,0,1,10,55],
 "classCGAL_1_1Triangulation__2.html#a78d0a3bd3637897ab1abe06389899b63":[1,0,1,10,54],
@@ -24,19 +30,20 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__2.html#a83de89d7d1c6e306b331b7158728bb57":[1,0,1,10,35],
 "classCGAL_1_1Triangulation__2.html#a843853eb19644389ba8d6024765eb4f7":[1,0,1,10,61],
 "classCGAL_1_1Triangulation__2.html#a84923815e1cfca537c93cee97c0ed24f":[1,0,1,10,15],
-"classCGAL_1_1Triangulation__2.html#a8b058b055ef24a4b6fc25bf110e46638":[1,0,1,10,117],
+"classCGAL_1_1Triangulation__2.html#a8b058b055ef24a4b6fc25bf110e46638":[1,0,1,10,119],
 "classCGAL_1_1Triangulation__2.html#a8bcea78e9ffd5cc836331c5021cd851a":[1,0,1,10,90],
-"classCGAL_1_1Triangulation__2.html#a8dc99f907cc125ce7a55024da5ddb4c0":[1,0,1,10,124],
+"classCGAL_1_1Triangulation__2.html#a8dc99f907cc125ce7a55024da5ddb4c0":[1,0,1,10,126],
 "classCGAL_1_1Triangulation__2.html#a8f4a1ca36147ac331db5be089e17a2a5":[1,0,1,10,76],
 "classCGAL_1_1Triangulation__2.html#a9213aedceda4c17381960d041d4f297a":[1,0,1,10,96],
 "classCGAL_1_1Triangulation__2.html#a93f4b88a11e455e4af2f5442e5d4824d":[1,0,1,10,38],
 "classCGAL_1_1Triangulation__2.html#a940567120751e7864c7b345eaf756642":[1,0,1,10,92],
 "classCGAL_1_1Triangulation__2.html#a94f47e3c6bdf5e36ae51180bcd013ad6":[1,0,1,10,18],
 "classCGAL_1_1Triangulation__2.html#a97deb44f4edfb6baa30c12a22f928dc7":[1,0,1,10,31],
+"classCGAL_1_1Triangulation__2.html#a983cffc38d4dba054cfbbe8ae8791530":[1,0,1,10,104],
 "classCGAL_1_1Triangulation__2.html#a997ed97a0ac906a0342ad18c91a1ec81":[1,0,1,10,8],
 "classCGAL_1_1Triangulation__2.html#a99d052d1f8a1f99c8defec48604192f5":[1,0,1,10,42],
-"classCGAL_1_1Triangulation__2.html#a9a215e702f4b5a03d77cc8c5e27a6b54":[1,0,1,10,120],
-"classCGAL_1_1Triangulation__2.html#a9a5dc75ed6ce4a645a5b61e5a8e88974":[1,0,1,10,107],
+"classCGAL_1_1Triangulation__2.html#a9a215e702f4b5a03d77cc8c5e27a6b54":[1,0,1,10,122],
+"classCGAL_1_1Triangulation__2.html#a9a5dc75ed6ce4a645a5b61e5a8e88974":[1,0,1,10,109],
 "classCGAL_1_1Triangulation__2.html#a9c54807a29595dc1116054cc4ac214fd":[1,0,1,10,95],
 "classCGAL_1_1Triangulation__2.html#aa47a446fc11809d30146fbcdb689a396":[1,0,1,10,58],
 "classCGAL_1_1Triangulation__2.html#aa7993454afb8684835b6ca96731a9eca":[1,0,1,10,29],
@@ -50,20 +57,20 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__2.html#ab97ce60b20674d0a7a4455e88c2eadb1":[1,0,1,10,94],
 "classCGAL_1_1Triangulation__2.html#abb274869c3eac8fb775702bf68c4e8f1":[1,0,1,10,100],
 "classCGAL_1_1Triangulation__2.html#abb3ae01ea08e705e49ced503e4a83026":[1,0,1,10,40],
-"classCGAL_1_1Triangulation__2.html#abc885b3d116e1d0b6943b211e750e472":[1,0,1,10,116],
-"classCGAL_1_1Triangulation__2.html#ac00496f74f7d05465407861f5a447768":[1,0,1,10,109],
-"classCGAL_1_1Triangulation__2.html#ac3beee6618a86505bfc03bcbfbb46a4a":[1,0,1,10,114],
+"classCGAL_1_1Triangulation__2.html#abc885b3d116e1d0b6943b211e750e472":[1,0,1,10,118],
+"classCGAL_1_1Triangulation__2.html#ac00496f74f7d05465407861f5a447768":[1,0,1,10,111],
+"classCGAL_1_1Triangulation__2.html#ac3beee6618a86505bfc03bcbfbb46a4a":[1,0,1,10,116],
 "classCGAL_1_1Triangulation__2.html#ac5e9bc8adef80dc01a0b31c2d0234545":[1,0,1,10,73],
-"classCGAL_1_1Triangulation__2.html#ac7351668deed7464974684ab3c7147ea":[1,0,1,10,123],
+"classCGAL_1_1Triangulation__2.html#ac7351668deed7464974684ab3c7147ea":[1,0,1,10,125],
 "classCGAL_1_1Triangulation__2.html#ac7519fb75001a53abba7e8d9127d22c5":[1,0,1,10,85],
-"classCGAL_1_1Triangulation__2.html#acae6c6bf678ec1a90b49498862bb7fa2":[1,0,1,10,103],
+"classCGAL_1_1Triangulation__2.html#acae6c6bf678ec1a90b49498862bb7fa2":[1,0,1,10,105],
 "classCGAL_1_1Triangulation__2.html#acf8596038ef09d0d3ffcba99e912d1da":[1,0,1,10,89],
 "classCGAL_1_1Triangulation__2.html#acf8e2ef548683138d8766b6c89794fbb":[1,0,1,10,87],
 "classCGAL_1_1Triangulation__2.html#ad28c6e0e0e65b8aaecb1ae76d8744b33":[1,0,1,10,7],
-"classCGAL_1_1Triangulation__2.html#ad43c112fe392ea9194b449e6116499c5":[1,0,1,10,112],
+"classCGAL_1_1Triangulation__2.html#ad43c112fe392ea9194b449e6116499c5":[1,0,1,10,114],
 "classCGAL_1_1Triangulation__2.html#ad720b1a9adc835ed1a27c228eea1e36c":[1,0,1,10,19],
 "classCGAL_1_1Triangulation__2.html#ad8a56f1fb051ce731a079671799010de":[1,0,1,10,77],
-"classCGAL_1_1Triangulation__2.html#adb17161924b6d2b6e7ac537d6b760728":[1,0,1,10,105],
+"classCGAL_1_1Triangulation__2.html#adb17161924b6d2b6e7ac537d6b760728":[1,0,1,10,107],
 "classCGAL_1_1Triangulation__2.html#adb9bbf3918a8081d21fc0c1de20b157e":[1,0,1,10,41],
 "classCGAL_1_1Triangulation__2.html#adbeb9736f9bfc588658316669cd7fb44":[1,0,1,10,81],
 "classCGAL_1_1Triangulation__2.html#addbcd86ae5679a10363f46080159d00d":[1,0,1,10,26],
@@ -82,7 +89,7 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__2.html#af61a05a0a53d009e111a3873c1796b52":[1,0,1,10,93],
 "classCGAL_1_1Triangulation__2.html#af70ca2702b9de4ae712b953f6a94b9a2":[1,0,1,10,13],
 "classCGAL_1_1Triangulation__2.html#af7f5d22e7244c73be90bec59a502e7aa":[1,0,1,10,12],
-"classCGAL_1_1Triangulation__2.html#afd84762f5a856ebdbd9786de8744feda":[1,0,1,10,113],
+"classCGAL_1_1Triangulation__2.html#afd84762f5a856ebdbd9786de8744feda":[1,0,1,10,115],
 "classCGAL_1_1Triangulation__2.html#afebc0e18dc93bce4b62b1e06944a6921":[1,0,1,10,64],
 "classCGAL_1_1Triangulation__2.html#afec203a9cabc1700b76a3f7d4b388840":[1,0,1,10,56],
 "classCGAL_1_1Triangulation__cw__ccw__2.html":[1,0,3,0],
@@ -242,12 +249,5 @@ var NAVTREEINDEX1 =
 "index.html#Subsection_2D_Triangulations_Delaunay_Terrain":[0,4,1],
 "index.html#Subsection_2D_Triangulations_Hierarchy_Examples":[0,9,1],
 "index.html#Subsection_2D_Triangulations_Polygon_triangulation":[0,7,3],
-"index.html#Subsection_2D_Triangulations_Regular_Description":[0,5,0],
-"index.html#Subsection_2D_Triangulations_Regular_Example":[0,5,3],
-"index.html#Subsection_2D_Triangulations_Voronoi":[0,4,2],
-"index.html#Subsection_Constrained_plus_avoids_cascacding":[0,8,1],
-"index.html#Subsection_Edges_and_Constraints":[0,8,0],
-"index.html#Subsubsection_2D_Triangulation_Basic_Geometric_Traits":[0,3,2],
-"index.html#Triangulation2Draw":[0,3,4],
-"index.html#Triangulation_2ACyclicDependency":[0,10,1]
+"index.html#Subsection_2D_Triangulations_Regular_Description":[0,5,0]
 };
