@@ -1,5 +1,10 @@
 var NAVTREEINDEX2 =
 {
+"index.html#Subsection_2D_Triangulations_Regular_Example":[0,5,3],
+"index.html#Subsection_2D_Triangulations_Voronoi":[0,4,2],
+"index.html#Subsection_Constrained_plus_avoids_cascacding":[0,8,1],
+"index.html#Subsection_Edges_and_Constraints":[0,8,0],
+"index.html#Subsubsection_2D_Triangulation_Basic_Geometric_Traits":[0,3,2],
 "index.html#Triangulation2Draw":[0,3,4],
 "index.html#Triangulation_2ACyclicDependency":[0,10,1],
 "index.html#Triangulation_2ARepresentationBasedonFaces":[0,1,1],
