@@ -83,36 +83,36 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__cell__base__with__info__3.html#a70db744cb0f0c94766fc3391e73f96c6":[1,0,3,6,0],
 "classCGAL_1_1Triangulation__cell__base__with__info__3.html#a880070c5deb5e6df980607d4c563538a":[1,0,3,6,1],
 "classCGAL_1_1Triangulation__simplex__3.html":[1,0,3,7],
-"classCGAL_1_1Triangulation__simplex__3.html#a025ad829a6ac87e7dfbafe912ea90f6d":[1,0,3,7,21],
-"classCGAL_1_1Triangulation__simplex__3.html#a080d9123d1cf85f4e7c9a6a0c067ddfa":[1,0,3,7,13],
-"classCGAL_1_1Triangulation__simplex__3.html#a1026ef5ff5743d36cfda8a84c74fa70b":[1,0,3,7,5],
-"classCGAL_1_1Triangulation__simplex__3.html#a15c49573f8ca5e2874772eaf2dbb088e":[1,0,3,7,10],
-"classCGAL_1_1Triangulation__simplex__3.html#a1fcde75660c947cca6616b68184c4dbf":[1,0,3,7,15],
-"classCGAL_1_1Triangulation__simplex__3.html#a2ea2851a05e057747ca759344e4e7f06":[1,0,3,7,28],
-"classCGAL_1_1Triangulation__simplex__3.html#a44107cf5aa84c17aa420021ab8dde0e8":[1,0,3,7,17],
-"classCGAL_1_1Triangulation__simplex__3.html#a4cb3669b9f663d865c22c59c15043eac":[1,0,3,7,8],
-"classCGAL_1_1Triangulation__simplex__3.html#a50cb8e097153f729d775ac9f4970769a":[1,0,3,7,1],
-"classCGAL_1_1Triangulation__simplex__3.html#a5e18f21dfa8f99951e5b1cb15cc4c326":[1,0,3,7,0],
-"classCGAL_1_1Triangulation__simplex__3.html#a61f25105ac5eaad55012a1076b4642a5":[1,0,3,7,16],
-"classCGAL_1_1Triangulation__simplex__3.html#a7c0d18c6dd2511ef2e939711ace40c09":[1,0,3,7,23],
-"classCGAL_1_1Triangulation__simplex__3.html#a7c951a4f5ca96a21125a9a5924b7f90e":[1,0,3,7,9],
-"classCGAL_1_1Triangulation__simplex__3.html#a842b53285b7e5388adc744d0230af23f":[1,0,3,7,18],
-"classCGAL_1_1Triangulation__simplex__3.html#a8affafacd90128d0ac110557c1e7e427":[1,0,3,7,12],
-"classCGAL_1_1Triangulation__simplex__3.html#a8b2d5cb3dac0d210112cb4fd7f1ae715":[1,0,3,7,25],
-"classCGAL_1_1Triangulation__simplex__3.html#a979426963f00a4d089322b0d534b307f":[1,0,3,7,24],
-"classCGAL_1_1Triangulation__simplex__3.html#a9f2daae81136d4d6a1adc477c0306b6c":[1,0,3,7,2],
-"classCGAL_1_1Triangulation__simplex__3.html#aa07f32d75d257f09676ef0eae1172cc8":[1,0,3,7,4],
-"classCGAL_1_1Triangulation__simplex__3.html#aa5cdfb3dfe37a7532d11218ecf35432a":[1,0,3,7,29],
-"classCGAL_1_1Triangulation__simplex__3.html#aaf3ef2e0a1fab37b3c1a5ca6a6c686aa":[1,0,3,7,3],
-"classCGAL_1_1Triangulation__simplex__3.html#ab4b62967a949443addf6610eef30f220":[1,0,3,7,7],
-"classCGAL_1_1Triangulation__simplex__3.html#ac059d0050c95cf6535cbef8ea49d1f00":[1,0,3,7,20],
-"classCGAL_1_1Triangulation__simplex__3.html#ac4be519ecb6e3fef7df7632bda973cae":[1,0,3,7,6],
-"classCGAL_1_1Triangulation__simplex__3.html#acc9a6c607f7c882967ecba8bb17e616a":[1,0,3,7,11],
-"classCGAL_1_1Triangulation__simplex__3.html#ae6232cf507c1c4adc371bf8325049689":[1,0,3,7,14],
-"classCGAL_1_1Triangulation__simplex__3.html#aedd9e5b986f10fedfaedff936e61c384":[1,0,3,7,27],
-"classCGAL_1_1Triangulation__simplex__3.html#af889cfad90c4de3c9337fb19a7f5957e":[1,0,3,7,26],
-"classCGAL_1_1Triangulation__simplex__3.html#afd1279cbe031c0be283ea15777e96548":[1,0,3,7,19],
-"classCGAL_1_1Triangulation__simplex__3.html#afff4021afdc397224be92c18ddc43f0c":[1,0,3,7,22],
+"classCGAL_1_1Triangulation__simplex__3.html#a0a2a72155e3c809e5a76b194ea7d8f19":[1,0,3,7,8],
+"classCGAL_1_1Triangulation__simplex__3.html#a21e22823afa1f0de9f8424dbd20b541d":[1,0,3,7,23],
+"classCGAL_1_1Triangulation__simplex__3.html#a25037377c6c1993446e6295dca3f7340":[1,0,3,7,10],
+"classCGAL_1_1Triangulation__simplex__3.html#a250516a3ce1aebc95653830c013a0316":[1,0,3,7,18],
+"classCGAL_1_1Triangulation__simplex__3.html#a27a55455659aa027f1d08fbc3bc77121":[1,0,3,7,24],
+"classCGAL_1_1Triangulation__simplex__3.html#a2e24727d479646d7fca2e5024cbeecaa":[1,0,3,7,15],
+"classCGAL_1_1Triangulation__simplex__3.html#a341e6e5e1c673753f7c9da9dc707f8fa":[1,0,3,7,17],
+"classCGAL_1_1Triangulation__simplex__3.html#a3e844028f5abb7318365e62d6bffcbaa":[1,0,3,7,16],
+"classCGAL_1_1Triangulation__simplex__3.html#a488a8ee2c9880e1c8f3a0d19e740aa94":[1,0,3,7,27],
+"classCGAL_1_1Triangulation__simplex__3.html#a50f4e4289d1c80de4cc05b95d8bfbbcb":[1,0,3,7,25],
+"classCGAL_1_1Triangulation__simplex__3.html#a56b6d0f036a5d8358369236724dee8e5":[1,0,3,7,3],
+"classCGAL_1_1Triangulation__simplex__3.html#a584935be19fa23d566b77b0b7b08e0ea":[1,0,3,7,28],
+"classCGAL_1_1Triangulation__simplex__3.html#a58cb3358fb0ea0f726e539253bcbce2b":[1,0,3,7,21],
+"classCGAL_1_1Triangulation__simplex__3.html#a59cef350089a89f8b5451c71cb691c7c":[1,0,3,7,19],
+"classCGAL_1_1Triangulation__simplex__3.html#a7c32a2c2d8b651e1db49efa4d07f49ef":[1,0,3,7,12],
+"classCGAL_1_1Triangulation__simplex__3.html#a7eee579454d0e9a4aa1f1c2adb155b9f":[1,0,3,7,22],
+"classCGAL_1_1Triangulation__simplex__3.html#a88120eec592f328352f4941d5901ee22":[1,0,3,7,20],
+"classCGAL_1_1Triangulation__simplex__3.html#a8838fb6d55a4273f4e38e97df0aff7cf":[1,0,3,7,14],
+"classCGAL_1_1Triangulation__simplex__3.html#a9226cfec8cb57acf26b0573236d44d0a":[1,0,3,7,4],
+"classCGAL_1_1Triangulation__simplex__3.html#aa32f5983a813d0e0ed280804bebbd1cd":[1,0,3,7,0],
+"classCGAL_1_1Triangulation__simplex__3.html#aa8ea702d758fb1c676d83348545bf618":[1,0,3,7,9],
+"classCGAL_1_1Triangulation__simplex__3.html#ab41b799c43610325cd478c8c71dbb5f6":[1,0,3,7,1],
+"classCGAL_1_1Triangulation__simplex__3.html#ab6cd2be0c17f61d73c452be52d928a42":[1,0,3,7,29],
+"classCGAL_1_1Triangulation__simplex__3.html#ab9e96c512774c262febb7ec43191b7dc":[1,0,3,7,13],
+"classCGAL_1_1Triangulation__simplex__3.html#abd36399e407fadd9af1455fa932738b3":[1,0,3,7,2],
+"classCGAL_1_1Triangulation__simplex__3.html#ac5eea769559158bde598a77b354e0862":[1,0,3,7,5],
+"classCGAL_1_1Triangulation__simplex__3.html#ad740214621072781bfbab455552b9a99":[1,0,3,7,26],
+"classCGAL_1_1Triangulation__simplex__3.html#adca22ececade0cf8a7aa47aeecc31eee":[1,0,3,7,6],
+"classCGAL_1_1Triangulation__simplex__3.html#af5c96b9decac6fb8a725967887c36e8d":[1,0,3,7,11],
+"classCGAL_1_1Triangulation__simplex__3.html#afb6c98d317fa54dfc12889c1734eb9fb":[1,0,3,7,7],
 "classCGAL_1_1Triangulation__vertex__base__3.html":[1,0,3,8],
 "classCGAL_1_1Triangulation__vertex__base__3.html#afe933467862407f26c4acf093cb2932c":[1,0,3,8,0],
 "classCGAL_1_1Triangulation__vertex__base__with__info__3.html":[1,0,3,9],
@@ -120,7 +120,7 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__vertex__base__with__info__3.html#a7e796efdf1cdf008de96bf00a47f9df4":[1,0,3,9,2],
 "classCGAL_1_1Triangulation__vertex__base__with__info__3.html#af8733e79f91a913771938750014f6dcf":[1,0,3,9,1],
 "classDelaunayTriangulationCellBase__3.html":[1,0,0,0],
-"classDelaunayTriangulationCellBase__3.html#a2d87229baef6bac08d5edc34f9a9c5cc":[1,0,0,0,1],
+"classDelaunayTriangulationCellBase__3.html#a78c0c596791211b17dd20b8bc04ef68d":[1,0,0,0,1],
 "classDelaunayTriangulationCellBase__3.html#ab3336a7ed69363288406841b3b5d25d6":[1,0,0,0,0],
 "classDelaunayTriangulationTraits__3.html":[1,0,0,1],
 "classDelaunayTriangulationTraits__3.html#a03904f260f62776e9523c516a703cd2f":[1,0,0,1,0],
@@ -239,15 +239,15 @@ var NAVTREEINDEX1 =
 "group__PkgTriangulation3VertexCellClasses.html":[1,0,3],
 "index.html":[0],
 "index.html":[],
-"index.html#Triangulation3Draw":[0,4,11],
-"index.html#Triangulation3exfastlocation":[0,4,5],
-"index.html#Triangulation3exsegmenttraverser":[0,4,6],
-"index.html#Triangulation3secRanges":[0,4,3],
-"index.html#Triangulation3secTraits":[0,3,0],
-"index.html#Triangulation3secclassRegulartriangulation":[0,2],
-"index.html#Triangulation3seccomplexity":[0,5],
-"index.html#Triangulation3secdesign":[0,3],
-"index.html#Triangulation3secexamples":[0,4],
-"index.html#Triangulation3secexamplescolor":[0,4,1,0],
-"index.html#Triangulation3secintro":[0,0]
+"index.html#Triangulation3Draw":[0,5,11],
+"index.html#Triangulation3exfastlocation":[0,5,5],
+"index.html#Triangulation3exsegmenttraverser":[0,5,6],
+"index.html#Triangulation3secRanges":[0,5,3],
+"index.html#Triangulation3secTraits":[0,4,0],
+"index.html#Triangulation3secclassRegulartriangulation":[0,3],
+"index.html#Triangulation3seccomplexity":[0,6],
+"index.html#Triangulation3secdef":[0,0],
+"index.html#Triangulation3secdesign":[0,4],
+"index.html#Triangulation3secexamples":[0,5],
+"index.html#Triangulation3secexamplescolor":[0,5,1,0]
 };
