@@ -1,6 +1,6 @@
 var group__PkgTriangulationOnSphere2TriangulationClasses =
 [
-    [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html", [
+    [ "CGAL::Delaunay_triangulation_on_sphere_2< Traits, TDS >", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html", [
       [ "Geom_traits", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aba2ab15d0e6b0c0f7f71a1767b5b5aca", null ],
       [ "Point", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a295dfed8bd54faa5c2404c09e30acdda", null ],
       [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aaf23cbd9fef31230bf4c2cbc6fc11f8e", null ],
@@ -8,15 +8,15 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a1fff40c879ca8ba44d14d354ecf2200b", null ],
       [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a74de0d03004d394d3d51c7def896c595", null ],
       [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad8b32d8bc75e9fb527e7069a0ced7a70", null ],
-      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a0b1d32e620b7522606670b0ed5858142", null ],
+      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad69bbc3e97aa9b346e87b9f1ae7fc3a0", null ],
       [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a917507c1f208bda4e103ff6e968311f8", null ],
       [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a714ebac8bf8ff3042644f84492f8d3fb", null ],
-      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad69bbc3e97aa9b346e87b9f1ae7fc3a0", null ],
-      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab67e4c0620b7c500e0d7629a6e256af7", null ],
+      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a0b1d32e620b7522606670b0ed5858142", null ],
+      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ac7403a86022a535d14d75ce3a0b84370", null ],
       [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab04c29d1196edf08823156ac4acfa3d7", null ],
       [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a6e74342e90b637989353e97658aaac85", null ],
-      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ac7403a86022a535d14d75ce3a0b84370", null ],
-      [ "get_conflicts_and_boundary", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aff9b8d2074cabf70b45f6940cdde48a9", null ],
+      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab67e4c0620b7c500e0d7629a6e256af7", null ],
+      [ "get_conflicts_and_boundary", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aea2f440a6add710a1aecee7e841b1013", null ],
       [ "insert", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a528b38fdbcf384953e90e3514fc398ac", null ],
       [ "insert", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a8a599356d6fb101aa7122b8fb88b168a", null ],
       [ "insert", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad4514b958d3e833cb77d1d288dc83b14", null ],
@@ -25,7 +25,7 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "remove", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a4ec4a8d0adec85a5e68eeb73951b901c", null ],
       [ "side_of_oriented_circle", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a34509a2547240f9234c76e941c842cce", null ]
     ] ],
-    [ "Delaunay_triangulation_on_sphere_traits_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html", [
+    [ "CGAL::Delaunay_triangulation_on_sphere_traits_2< LK, SK >", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html", [
       [ "Arc_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af8975d8dbc1d273b9070c8aebd8a72bd", null ],
       [ "Collinear_are_strictly_ordered_on_great_circle_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af58e88bce84c05a3428784e4313e2225", null ],
       [ "Compare_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#aeaab6ea8046f4a070eb0a3082b23a575", null ],
@@ -45,7 +45,7 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "are_points_too_close", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a7d9220bca8d0b95b4bd37767779e7336", null ],
       [ "is_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#ae0f10c1be572af5d813b897ea6251d71", null ]
     ] ],
-    [ "Projection_on_sphere_traits_3", "classCGAL_1_1Projection__on__sphere__traits__3.html", [
+    [ "CGAL::Projection_on_sphere_traits_3< LK, SK >", "classCGAL_1_1Projection__on__sphere__traits__3.html", [
       [ "Arc_on_sphere_2", "classCGAL_1_1Projection__on__sphere__traits__3.html#a423cc82220432d1ffedc48747a35ae5a", null ],
       [ "Equal_on_sphere_2", "classCGAL_1_1Projection__on__sphere__traits__3.html#a375e158bb5c306d216132f663f00d847", null ],
       [ "FT", "classCGAL_1_1Projection__on__sphere__traits__3.html#a0b0e6576e8d12b2ac505341557211d53", null ],
@@ -56,7 +56,7 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "are_points_too_close", "classCGAL_1_1Projection__on__sphere__traits__3.html#ac1b3f2510b150af5ee63c57a46b287e6", null ],
       [ "is_on_sphere", "classCGAL_1_1Projection__on__sphere__traits__3.html#ae331b210f14afa75e4d0707886bacf9d", null ]
     ] ],
-    [ "Triangulation_on_sphere_2", "classCGAL_1_1Triangulation__on__sphere__2.html", [
+    [ "CGAL::Triangulation_on_sphere_2< Traits, TDS >", "classCGAL_1_1Triangulation__on__sphere__2.html", [
       [ "All_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#a78b0e6bcf13d31f583f2dd80f7358508", null ],
       [ "All_edges_iterator", "classCGAL_1_1Triangulation__on__sphere__2.html#ad6e3450f964ef4ce9a201e8fa4e3c9ac", null ],
       [ "All_face_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#a5a7c4058b2a581af52820678a6d42c42", null ],
@@ -108,7 +108,7 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "all_faces_end", "classCGAL_1_1Triangulation__on__sphere__2.html#ac94b8b39af6976764fce6215a5077b42", null ],
       [ "clear", "classCGAL_1_1Triangulation__on__sphere__2.html#a55718ca8fcf8b7118f5c8e66a06c1609", null ],
       [ "dimension", "classCGAL_1_1Triangulation__on__sphere__2.html#a38d4d87e037ab84a86d40c8a58390801", null ],
-      [ "geom_traits", "classCGAL_1_1Triangulation__on__sphere__2.html#a48aada77bfdefc234a5761005c737cc0", null ],
+      [ "geom_traits", "classCGAL_1_1Triangulation__on__sphere__2.html#a4972d0047f71cad49f3e01dae5ea5788", null ],
       [ "incident_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#a0c4985cf6b2bbc22d150c2473860de09", null ],
       [ "incident_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#a46cf5fb66ea5d670fdf5d909b4ad614a", null ],
       [ "incident_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#a6fd7a0383a88681376e8f6d32fc5aae0", null ],
@@ -117,8 +117,8 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "is_edge", "classCGAL_1_1Triangulation__on__sphere__2.html#ad8d9c6bde74b4a2c346e9c3070bccc33", null ],
       [ "is_face", "classCGAL_1_1Triangulation__on__sphere__2.html#aca1455b13cb34a477aa901547b53f75e", null ],
       [ "is_face", "classCGAL_1_1Triangulation__on__sphere__2.html#ad8d8ed5aefab4009a5c04c9dd1e5a7bf", null ],
-      [ "is_ghost", "classCGAL_1_1Triangulation__on__sphere__2.html#a0b9f9b2a795d7cbe57f9148fd9134bb1", null ],
       [ "is_ghost", "classCGAL_1_1Triangulation__on__sphere__2.html#a78e3e0f198bd1fc017dfbc8599cd6fa8", null ],
+      [ "is_ghost", "classCGAL_1_1Triangulation__on__sphere__2.html#a0b9f9b2a795d7cbe57f9148fd9134bb1", null ],
       [ "is_valid", "classCGAL_1_1Triangulation__on__sphere__2.html#a8aaacdcdb77ede1d09af712a37664cb6", null ],
       [ "locate", "classCGAL_1_1Triangulation__on__sphere__2.html#a53acc07d925f00b4a66979c9dbc99f29", null ],
       [ "locate", "classCGAL_1_1Triangulation__on__sphere__2.html#a5e784cdf403691ccb7f33d6548dea6df", null ],
@@ -126,9 +126,9 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "number_of_ghost_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#a56f201bc7550eebf57c41a364f4afc7e", null ],
       [ "number_of_solid_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#ae7f0deae8f142f4ec03e33ea794a373c", null ],
       [ "number_of_vertices", "classCGAL_1_1Triangulation__on__sphere__2.html#aa7379e9213d72593fe5080f8e4407ebb", null ],
-      [ "operator=", "classCGAL_1_1Triangulation__on__sphere__2.html#a753d767e2e3799e2d732911b446b7ce9", null ],
-      [ "point", "classCGAL_1_1Triangulation__on__sphere__2.html#ac4216810300009ffd4d64d272ce6a8ca", null ],
-      [ "point", "classCGAL_1_1Triangulation__on__sphere__2.html#a71ce806a34ceddddaab0befbeed37b92", null ],
+      [ "operator=", "classCGAL_1_1Triangulation__on__sphere__2.html#ad23082a6839e0f7cabada1385928f4f3", null ],
+      [ "point", "classCGAL_1_1Triangulation__on__sphere__2.html#a221c8c618dad2d73c69c0ac6fd70a463", null ],
+      [ "point", "classCGAL_1_1Triangulation__on__sphere__2.html#a0b86fe9152f891272def95cacf6598bb", null ],
       [ "points", "classCGAL_1_1Triangulation__on__sphere__2.html#af60a99e81419bf43d457924d78697154", null ],
       [ "segment", "classCGAL_1_1Triangulation__on__sphere__2.html#a67bf1c3b2d51885487819d59622b4ef2", null ],
       [ "segment", "classCGAL_1_1Triangulation__on__sphere__2.html#a15b9150c44e9b2beb31c7d6af649b16c", null ],
@@ -144,7 +144,7 @@ var group__PkgTriangulationOnSphere2TriangulationClasses =
       [ "solid_faces_begin", "classCGAL_1_1Triangulation__on__sphere__2.html#aa7cdafb9d3e3a037867283ad5354be67", null ],
       [ "solid_faces_end", "classCGAL_1_1Triangulation__on__sphere__2.html#a75ae3c710864e895e56a33a324e7e217", null ],
       [ "swap", "classCGAL_1_1Triangulation__on__sphere__2.html#ad84dcc82df42f27cb53f87c076f306a5", null ],
-      [ "tds", "classCGAL_1_1Triangulation__on__sphere__2.html#a20aaf0d2b04f2167d7cc3bc19eeec723", null ],
+      [ "tds", "classCGAL_1_1Triangulation__on__sphere__2.html#a9d518722559720a863563385011bfa95", null ],
       [ "triangle", "classCGAL_1_1Triangulation__on__sphere__2.html#ac9af62da049168122f6fb8fec2be6b2c", null ],
       [ "vertex_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#a28294cf36820d583459bbaf8a912dea1", null ],
       [ "vertices_begin", "classCGAL_1_1Triangulation__on__sphere__2.html#a972d571584525af1ce6a9b8c1e0e7ff8", null ],
