@@ -1,13 +1,13 @@
 var NAVTREEINDEX0 =
 {
-"Triangulation_on_sphere_2_2triang_on_sphere_8cpp-example.html":[6,0],
-"Triangulation_on_sphere_2_2triang_on_sphere_exact_8cpp-example.html":[6,1],
-"Triangulation_on_sphere_2_2triang_on_sphere_proj_8cpp-example.html":[6,2],
-"Triangulation_on_sphere_2_2triang_on_sphere_range_8cpp-example.html":[6,3],
-"annotated.html":[5],
-"citelist.html":[4],
+"Triangulation_on_sphere_2_2triang_on_sphere_8cpp-example.html":[4,0],
+"Triangulation_on_sphere_2_2triang_on_sphere_exact_8cpp-example.html":[4,1],
+"Triangulation_on_sphere_2_2triang_on_sphere_proj_8cpp-example.html":[4,2],
+"Triangulation_on_sphere_2_2triang_on_sphere_range_8cpp-example.html":[4,3],
+"annotated.html":[3],
+"citelist.html":[2],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html":[1,0,1,0],
-"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a0b1d32e620b7522606670b0ed5858142":[1,0,1,0,7],
+"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a0b1d32e620b7522606670b0ed5858142":[1,0,1,0,10],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a176258dbf24328ac4d3fde54e5eb0b26":[1,0,1,0,20],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a1fff40c879ca8ba44d14d354ecf2200b":[1,0,1,0,4],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a295dfed8bd54faa5c2404c09e30acdda":[1,0,1,0,1],
@@ -21,15 +21,15 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a917507c1f208bda4e103ff6e968311f8":[1,0,1,0,8],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aaf23cbd9fef31230bf4c2cbc6fc11f8e":[1,0,1,0,2],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab04c29d1196edf08823156ac4acfa3d7":[1,0,1,0,12],
-"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab67e4c0620b7c500e0d7629a6e256af7":[1,0,1,0,11],
+"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab67e4c0620b7c500e0d7629a6e256af7":[1,0,1,0,14],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aba2ab15d0e6b0c0f7f71a1767b5b5aca":[1,0,1,0,0],
-"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ac7403a86022a535d14d75ce3a0b84370":[1,0,1,0,14],
+"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ac7403a86022a535d14d75ce3a0b84370":[1,0,1,0,11],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad4514b958d3e833cb77d1d288dc83b14":[1,0,1,0,18],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad4cb73f08b56a1ca41c9734a37a6dbf9":[1,0,1,0,19],
-"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad69bbc3e97aa9b346e87b9f1ae7fc3a0":[1,0,1,0,10],
+"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad69bbc3e97aa9b346e87b9f1ae7fc3a0":[1,0,1,0,7],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad8b32d8bc75e9fb527e7069a0ced7a70":[1,0,1,0,6],
+"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aea2f440a6add710a1aecee7e841b1013":[1,0,1,0,15],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#afa69966c7ebbb4fe172d962d4d38ff67":[1,0,1,0,3],
-"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aff9b8d2074cabf70b45f6940cdde48a9":[1,0,1,0,15],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html":[1,0,1,1],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a0382911b98a55b2ee4bdb2ac493961a0":[1,0,1,1,12],
 "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a21eb6038d4b9418605495ac5b05b9005":[1,0,1,1,6],
@@ -63,7 +63,8 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Triangulation__on__sphere__2.html#a045d9f92f669be1723600f8454a82da0":[1,0,1,3,37],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a09817eec2b69440e23dd95409fd6a18e":[1,0,1,3,31],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a0a5e73e02746d5805cd66ddbe8666b1f":[1,0,1,3,48],
-"classCGAL_1_1Triangulation__on__sphere__2.html#a0b9f9b2a795d7cbe57f9148fd9134bb1":[1,0,1,3,52],
+"classCGAL_1_1Triangulation__on__sphere__2.html#a0b86fe9152f891272def95cacf6598bb":[1,0,1,3,63],
+"classCGAL_1_1Triangulation__on__sphere__2.html#a0b9f9b2a795d7cbe57f9148fd9134bb1":[1,0,1,3,53],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a0c4985cf6b2bbc22d150c2473860de09":[1,0,1,3,44],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a10da4cc8bf560a04e12e88e707c0b80f":[1,0,1,3,14],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368":[1,0,1,3,29],
@@ -79,8 +80,8 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Triangulation__on__sphere__2.html#a17cf0e76976af979a0f2590317a5ef81":[1,0,1,3,35],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a1c66dcccc58c3e12e14ae675d2cb5030":[1,0,1,3,27],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a1d5958f1f28264f515e0592906482a36":[1,0,1,3,25],
-"classCGAL_1_1Triangulation__on__sphere__2.html#a20aaf0d2b04f2167d7cc3bc19eeec723":[1,0,1,3,79],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a211810561992740f2350f7f0c5cd8a8a":[1,0,1,3,69],
+"classCGAL_1_1Triangulation__on__sphere__2.html#a221c8c618dad2d73c69c0ac6fd70a463":[1,0,1,3,62],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a28294cf36820d583459bbaf8a912dea1":[1,0,1,3,81],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a2a9ceda7b558cb8543b76da093774536":[1,0,1,3,13],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a2d8b7777e2d52d559c2d852f022f4c15":[1,0,1,3,10],
@@ -90,7 +91,7 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Triangulation__on__sphere__2.html#a38ab81aa3d0471998c8095f585ebc6f0":[1,0,1,3,17],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a38d4d87e037ab84a86d40c8a58390801":[1,0,1,3,42],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a46cf5fb66ea5d670fdf5d909b4ad614a":[1,0,1,3,45],
-"classCGAL_1_1Triangulation__on__sphere__2.html#a48aada77bfdefc234a5761005c737cc0":[1,0,1,3,43],
+"classCGAL_1_1Triangulation__on__sphere__2.html#a4972d0047f71cad49f3e01dae5ea5788":[1,0,1,3,43],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a4a921522cb870d1204cc6ea1632d5ff8":[1,0,1,3,15],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a53acc07d925f00b4a66979c9dbc99f29":[1,0,1,3,55],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a55718ca8fcf8b7118f5c8e66a06c1609":[1,0,1,3,41],
@@ -104,11 +105,9 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Triangulation__on__sphere__2.html#a70648c8f333f770bf281fbed6610cfe3":[1,0,1,3,47],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a71262c6f8154440c0a46b35874743307":[1,0,1,3,23],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a713c3c5ecb019409d2fa5e18ff76a0ba":[1,0,1,3,7],
-"classCGAL_1_1Triangulation__on__sphere__2.html#a71ce806a34ceddddaab0befbeed37b92":[1,0,1,3,63],
-"classCGAL_1_1Triangulation__on__sphere__2.html#a753d767e2e3799e2d732911b446b7ce9":[1,0,1,3,61],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a75ae3c710864e895e56a33a324e7e217":[1,0,1,3,77],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a78b0e6bcf13d31f583f2dd80f7358508":[1,0,1,3,0],
-"classCGAL_1_1Triangulation__on__sphere__2.html#a78e3e0f198bd1fc017dfbc8599cd6fa8":[1,0,1,3,53],
+"classCGAL_1_1Triangulation__on__sphere__2.html#a78e3e0f198bd1fc017dfbc8599cd6fa8":[1,0,1,3,52],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a79b3ccccb787702a803099dbb8d153c9":[1,0,1,3,8],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a7d140a659c5fae73282a9f1ac4923e68":[1,0,1,3,73],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a7ea02bf43866228055fbb8a97adde8d1":[1,0,1,3,28],
@@ -116,6 +115,7 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Triangulation__on__sphere__2.html#a83cedc161f4fedc83790de4a5f1c8b66":[1,0,1,3,11],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a8aaacdcdb77ede1d09af712a37664cb6":[1,0,1,3,54],
 "classCGAL_1_1Triangulation__on__sphere__2.html#a972d571584525af1ce6a9b8c1e0e7ff8":[1,0,1,3,82],
+"classCGAL_1_1Triangulation__on__sphere__2.html#a9d518722559720a863563385011bfa95":[1,0,1,3,79],
 "classCGAL_1_1Triangulation__on__sphere__2.html#aa7379e9213d72593fe5080f8e4407ebb":[1,0,1,3,60],
 "classCGAL_1_1Triangulation__on__sphere__2.html#aa77bff97e3bd3adc78bb6efbd1a60c10":[1,0,1,3,33],
 "classCGAL_1_1Triangulation__on__sphere__2.html#aa7cdafb9d3e3a037867283ad5354be67":[1,0,1,3,76],
@@ -125,10 +125,10 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Triangulation__on__sphere__2.html#ab190d3933b157fcc4dab06ba7967e4c8":[1,0,1,3,75],
 "classCGAL_1_1Triangulation__on__sphere__2.html#abb242907b37f4ee1bc02ce8ddbd91a41":[1,0,1,3,70],
 "classCGAL_1_1Triangulation__on__sphere__2.html#abb251d75397d86feb4b29c520722a448":[1,0,1,3,30],
-"classCGAL_1_1Triangulation__on__sphere__2.html#ac4216810300009ffd4d64d272ce6a8ca":[1,0,1,3,62],
 "classCGAL_1_1Triangulation__on__sphere__2.html#ac94b8b39af6976764fce6215a5077b42":[1,0,1,3,40],
 "classCGAL_1_1Triangulation__on__sphere__2.html#ac9af62da049168122f6fb8fec2be6b2c":[1,0,1,3,80],
 "classCGAL_1_1Triangulation__on__sphere__2.html#aca1455b13cb34a477aa901547b53f75e":[1,0,1,3,50],
+"classCGAL_1_1Triangulation__on__sphere__2.html#ad23082a6839e0f7cabada1385928f4f3":[1,0,1,3,61],
 "classCGAL_1_1Triangulation__on__sphere__2.html#ad2b2c32e7ab6f41b27fe94589514398b":[1,0,1,3,34],
 "classCGAL_1_1Triangulation__on__sphere__2.html#ad6e3450f964ef4ce9a201e8fa4e3c9ac":[1,0,1,3,1],
 "classCGAL_1_1Triangulation__on__sphere__2.html#ad7264cfa113ca9cad9022cf68e00c3c9":[1,0,1,3,72],
@@ -160,7 +160,9 @@ var NAVTREEINDEX0 =
 "classDelaunayTriangulationOnSphereTraits__2.html#aab07b36d171f773d2745a9cfc4ea4e51":[1,0,0,0,1],
 "classDelaunayTriangulationOnSphereTraits__2.html#ac9631aa2e4f6d34ef8b299a9681da6ff":[1,0,0,0,2],
 "classTriangulationOnSphereFaceBase__2.html":[1,0,0,1],
-"classTriangulationOnSphereFaceBase__2.html#a6d4bd41e4848d65f826488f3619a930c":[1,0,0,1,1],
+"classTriangulationOnSphereFaceBase__2.html#a4b96ba868ac4e3eb26a6ea2a7ffe57fb":[1,0,0,1,1],
+"classTriangulationOnSphereFaceBase__2.html#a6d4bd41e4848d65f826488f3619a930c":[1,0,0,1,3],
+"classTriangulationOnSphereFaceBase__2.html#a793bf7ff535a925ce755a27436e3392b":[1,0,0,1,2],
 "classTriangulationOnSphereFaceBase__2.html#afd01ca6f33579d6f8bae5cbb6b26c27e":[1,0,0,1,0],
 "classTriangulationOnSphereTraits__2.html":[1,0,0,2],
 "classTriangulationOnSphereTraits__2.html#a06b96068e1ef464447c8ae7f33ece934":[1,0,0,2,18],
@@ -196,20 +198,19 @@ var NAVTREEINDEX0 =
 "classTriangulationOnSphereTraits__2.html#afb850a8f2d2a75cb47ddbe25f15d6665":[1,0,0,2,14],
 "classTriangulationOnSphereTraits__2.html#afd2b488c9d27c9de48c0d4bb27202b11":[1,0,0,2,1],
 "classTriangulationOnSphereVertexBase__2.html":[1,0,0,3],
-"classTriangulationOnSphereVertexBase__2.html#a0c43226dc65d94d4608609f63b93b246":[1,0,0,3,4],
 "classTriangulationOnSphereVertexBase__2.html#a259571ec551badb044db4084d1ce77ce":[1,0,0,3,0],
 "classTriangulationOnSphereVertexBase__2.html#a28712600502a69c98a8bff0bea5762e3":[1,0,0,3,3],
 "classTriangulationOnSphereVertexBase__2.html#a5f5376bf14e89536dc3aac2490903b25":[1,0,0,3,7],
 "classTriangulationOnSphereVertexBase__2.html#a799485c9be0e7df245141c294144796d":[1,0,0,3,2],
 "classTriangulationOnSphereVertexBase__2.html#a86962fd1a1aa4b624fcadf18e869c4ac":[1,0,0,3,6],
+"classTriangulationOnSphereVertexBase__2.html#a9071bd6f4f5d7b8bd929f0cc84b80063":[1,0,0,3,5],
+"classTriangulationOnSphereVertexBase__2.html#ac70b36a15bb1e779b5b07fc4742d800c":[1,0,0,3,4],
 "classTriangulationOnSphereVertexBase__2.html#ac74a14d8067dc85377196f733981afa8":[1,0,0,3,1],
-"classTriangulationOnSphereVertexBase__2.html#acf3ba3d2b389ae2e3405a9609f4d3cb2":[1,0,0,3,5],
-"examples.html":[6],
+"examples.html":[4],
 "group__PkgTriangulationOnSphere2Concepts.html":[1,0,0],
 "group__PkgTriangulationOnSphere2Ref.html":[1,0],
 "group__PkgTriangulationOnSphere2TriangulationClasses.html":[1,0,1],
 "group__PkgTriangulationOnSphere2VertexFaceClasses.html":[1,0,2],
-"hasModels.html":[3],
 "index.html":[],
 "index.html":[0],
 "index.html#Section_2D_ToS_Definitions":[0,0],
@@ -225,8 +226,6 @@ var NAVTREEINDEX0 =
 "index.html#Section_2D_ToS_Imprecision":[0,0,0],
 "index.html#Section_2D_ToS_Lowdim":[0,1,2],
 "index.html#Section_2D_ToS_Traits":[0,1,1],
-"models.html":[2],
 "modules.html":[1],
-"namespaceCGAL.html":[5,0],
 "pages.html":[]
 };
