@@ -1,10 +1,10 @@
 var group__PkgWeightsRefBarycentricMeanValueWeights =
 [
-    [ "Mean_value_weights_2", "classCGAL_1_1Weights_1_1Mean__value__weights__2.html", [
+    [ "CGAL::Weights::Mean_value_weights_2< VertexRange, GeomTraits, PointMap >", "classCGAL_1_1Weights_1_1Mean__value__weights__2.html", [
       [ "FT", "classCGAL_1_1Weights_1_1Mean__value__weights__2.html#ad567decd06b4d8d70870615deeef5d11", null ],
       [ "Point_2", "classCGAL_1_1Weights_1_1Mean__value__weights__2.html#a42ec858d2aff6c6392d41748f00deadc", null ],
       [ "Mean_value_weights_2", "classCGAL_1_1Weights_1_1Mean__value__weights__2.html#a5b0d493427e710b4ae1b78f86f64a26b", null ],
       [ "operator()", "classCGAL_1_1Weights_1_1Mean__value__weights__2.html#a3f8df37999ecf5478d0ba81d7169df53", null ]
     ] ],
-    [ "mean_value_weights_2", "group__PkgWeightsRefBarycentricMeanValueWeights.html#gab34915e98769a1c328190a78bbc9b3e8", null ]
+    [ "CGAL::Weights::mean_value_weights_2", "group__PkgWeightsRefBarycentricMeanValueWeights.html#gab34915e98769a1c328190a78bbc9b3e8", null ]
 ];
\ No newline at end of file
